@@ -35,7 +35,7 @@
 #include "EmpathMailbox.h"
 #include "EmpathMailboxList.h"
 //#include "EmpathMailboxPOP3.h"
-//#include "EmpathMailboxIMAP4.h"
+#include "EmpathMailboxIMAP4.h"
 #include "EmpathMailboxMaildir.h"
 #include "EmpathDefines.h"
 
@@ -81,6 +81,13 @@ EmpathMailboxList::loadConfig()
 
     QDict<EmpathMailbox>::clear();
 
+    EmpathMailbox * m = createNew(EmpathMailbox::Maildir);
+
+    m->setName(i18n("Local"));
+    empathDebug("Created local mailbox");
+
+    m->init();
+
     KConfig * c(KGlobal::config());
 
     c->setGroup("General");
@@ -94,20 +101,24 @@ EmpathMailboxList::loadConfig()
 
     for (; it != l.end() ; ++it) {
 
+        empathDebug("Looking at group " + *it);
+
         c->setGroup("Mailbox_" + *it);
 
         mailboxType =
             static_cast<EmpathMailbox::Type>(c->readUnsignedNumEntry("Type"));
 
+        empathDebug("Type == " + QString::number(mailboxType));
+
         EmpathMailbox * m = createNew(mailboxType);
 
-        m->setName(*it);
-
-        if (m == 0) {
+        if (0 == m) {
             empathDebug("Couldn't create mailbox !");
             continue;
         }
 
+        m->setName(*it);
+
         m->init();
     }
 }
@@ -120,6 +131,8 @@ EmpathMailboxList::saveConfig() const
     QStringList l;
 
     for (; it.current(); ++it) {
+        if (it.current()->name() == i18n("Local")) // FIXME
+            continue;
         l << it.current()->name();
         it.current()->saveConfig();
     }
@@ -171,11 +184,11 @@ EmpathMailboxList::createNew(EmpathMailbox::Type t)
         case EmpathMailbox::POP3:
             m = new EmpathMailboxPOP3(uniqueName());
             break;
+#endif
 
         case EmpathMailbox::IMAP4:
             m = new EmpathMailboxIMAP4(uniqueName());
             break;
-#endif
 
         default:
             break;
