@@ -73,7 +73,7 @@ main(int argc, char ** argv)
     );
 
     aboutData.addAuthor(
-        "kraftw",
+        "qwertz",
         I18N_NOOP("Empath logo")
     );
  
@@ -95,14 +95,22 @@ main(int argc, char ** argv)
 
 #endif
     
+    cerr << "Creating Empath." << endl;
+
     // Create the kernel.
     Empath::start();
+
+    cerr << "Creating user interface." << endl;
     
     // Create the user interface.
     EmpathUI::instance();
 
+    cerr << "Initialising empath." << endl;
+
     // Initialise the kernel.
     empath->init();
+
+    cerr << "Empath initialisation complete. Entering event loop." << endl;
     
     // Enter the event loop.
     int retval = app.exec();
