@@ -20,10 +20,6 @@
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
 
-#ifdef __GNUG__
-# pragma implementation "EmpathSetupWizard.h"
-#endif
-
 // System includes
 #include <sys/utsname.h>
 #include <sys/types.h>
