@@ -1,7 +1,7 @@
 /* CalPrinter.cpp
  * Copyright (c) 1998 Preston Brown
  *
- * $Id: calprinter.cpp,v 1.40 2000/08/09 21:16:37 bieker Exp $
+ * $Id: calprinter.cpp,v 1.43 2001/02/09 13:17:41 cschumac Exp $
  */
 
 #include <math.h>
@@ -17,8 +17,9 @@
 #include <kdateedit.h>
 #include <kmessagebox.h>
 #include <kapp.h>
+#include <kdebug.h>
 
-#include "kooptionsdialog.h"
+#include "koprefsdialog.h"
 #include "koprefs.h"
 
 #include "calprinter.h"
@@ -47,7 +48,8 @@ CalPrinter::~CalPrinter()
 
 void CalPrinter::setupPrinter()
 {
-  KOOptionsDialog *optionsDlg = new KOOptionsDialog;
+  KOPrefsDialog *optionsDlg = new KOPrefsDialog;
+  optionsDlg->readConfig();
   optionsDlg->showPrinterTab();
   connect(optionsDlg, SIGNAL(configChanged()),
 	  parent, SLOT(updateConfig()));
@@ -409,14 +411,14 @@ void CalPrinter::drawHeader(QPainter &p, const QDate &fd, const QDate &td,
 			    int width, int height, PrintType pt)
 {
   KLocale *local = KGlobal::locale();
-
+  QFont font("helvetica", 18, QFont::Bold);
   p.drawRect(0, 0, width, height);
   p.fillRect(1, 1, 
 	     width-2, 
 	     height-2, 
-	     QBrush(Dense3Pattern));
+	     QBrush(Dense4Pattern));
 
-  p.setFont(QFont("helvetica", 24, QFont::Bold));
+  p.setFont(font);
   int lineSpacing = p.fontMetrics().lineSpacing();
   QString title;
   QString myOwner(calendar->getOwner());
@@ -661,32 +663,28 @@ void CalPrinter::drawWeek(QPainter &p, const QDate &qd, int width, int height)
 void CalPrinter::drawMonth(QPainter &p, const QDate &qd,
 			   int width, int height)
 {
-  bool firstCol = TRUE;
+  int weekdayCol;
   int offset = headerHeight+5+subHeaderHeight;
   int cellWidth = width/7;
   int cellHeight = (height-offset) / 5;
   QDate monthDate(QDate(qd.year(), qd.month(), 1));
-  int month = monthDate.month();
-
-  for (int row = 0; row < 5; row++) {
+ 
+  if (KGlobal::locale()->weekStartsMonday())
+    weekdayCol = monthDate.dayOfWeek() - 1;
+  else
+    weekdayCol = monthDate.dayOfWeek() % 7;
+  monthDate = monthDate.addDays(-weekdayCol);
+ 
+  for (int row = 0; row < (weekdayCol + qd.daysInMonth() - 1 )/7 + 1; row++) {
     for (int col = 0; col < 7; col++) {
-      if (monthDate.month() != month)
-	break;
-      if (firstCol) {
-	firstCol = FALSE;
-	if (KGlobal::locale()->weekStartsMonday())
-	  col = monthDate.dayOfWeek() - 1;
-	else
-	  col = monthDate.dayOfWeek() % 7;
-      }
-      drawDayBox(p, monthDate, 
-		 col*cellWidth, offset+row*cellHeight,
-		 cellWidth, cellHeight);
+      drawDayBox(p, monthDate, col*cellWidth, offset+row*cellHeight,
+                 cellWidth, cellHeight);
       monthDate = monthDate.addDays(1);
     }
   }
 }
 
+
 void CalPrinter::drawSmallMonth(QPainter &p, const QDate &qd, 
 				int x, int y, int width, int height)
 {
@@ -715,9 +713,10 @@ void CalPrinter::drawSmallMonth(QPainter &p, const QDate &qd,
     monthDate2 = monthDate.addDays(-(monthDate.dayOfWeek()%7)); 
 
   // draw days of week
+   p.setFont(QFont("helvetica", 8, QFont::Bold));
   for (int col = 0; col < 7; col++) {
     // tmpStr.sprintf("%c",(const char*)monthDate2.dayName(monthDate2.dayOfWeek()));
-    tmpStr=local->weekDayName(monthDate2.dayOfWeek());
+    tmpStr=local->weekDayName(monthDate2.dayOfWeek())[0].upper();
     p.drawText(x+col*cellWidth, y+height/4, cellWidth, cellHeight,
 	       AlignCenter, tmpStr);
     monthDate2 = monthDate2.addDays(1);
