@@ -1,4 +1,4 @@
-// 	$Id: catdlg.h,v 1.7 2000/05/16 20:11:55 cschumac Exp $
+// 	$Id: catdlg.h,v 1.9 2000/08/10 08:55:47 bieker Exp $
 
 #ifndef _CATDLG_H
 #define _CATDLG_H
@@ -6,7 +6,7 @@
 #include <qstrlist.h>
 #include <kdialogbase.h>
 
-class QStrList;
+class QStringList;
 class KButtonBox;
 class QListBox;
 class QPushButton;
@@ -22,7 +22,7 @@ public:
   virtual ~CategoryDialog();
 
 public slots:
-  void setSelected(const QStrList &selList);
+  void setSelected(const QStringList &selList);
 
 protected slots:
   void accept();
@@ -31,6 +31,7 @@ protected slots:
 
 signals:
   void categoriesSelected(QString);
+  void categoryConfigChanged();
 
 protected:
   QListBox* catListBox, *selCatListBox;
