@@ -2,7 +2,7 @@
   ExportWebDialog is a class that provides the dialog and functions to export a
   calendar as web page.
 
-  $Id: exportwebdialog.h,v 1.3 2000/05/11 01:22:21 cschumac Exp $  
+  $Id: exportwebdialog.h,v 1.5 2000/07/15 16:33:02 cschumac Exp $  
 */
 
 #ifndef _EXPORTWEBDIALOG_H
@@ -18,6 +18,7 @@ class QCheckBox;
 class QLineEdit;
 class QTextStream;
 class KOEvent;
+class KConfig;
 
 class ExportWebDialog : public KDialogBase
 {
@@ -31,23 +32,32 @@ class ExportWebDialog : public KDialogBase
 
     void browseOutputFile();
     void slotResult(KIO::Job *);
+
   protected slots:
  
   signals:
 
   protected:
     void setupGeneralPage();
+    void setupEventPage();
     void setupTodoPage();
     void setupAdvancedPage();
 
     void createHtmlEventList (QTextStream *ts);
     void createHtmlTodoList (QTextStream *ts);
     void createHtmlTodo (QTextStream *ts,KOEvent *todo);
-    void createHtmlEvent (QTextStream *ts,KOEvent *event);
+    void createHtmlEvent (QTextStream *ts,KOEvent *event,QDate date);
 
+    void formatHtmlCategories (QTextStream *ts,KOEvent *event);
+    void formatHtmlAttendees (QTextStream *ts,KOEvent *event);
+
+  private:
     CalObject *mCalendar;
+
+    KConfig *mConfig;
   
     QFrame *mGeneralPage;
+    QFrame *mEventPage;
     QFrame *mTodoPage;
     QFrame *mAdvancedPage;
   
@@ -56,10 +66,12 @@ class ExportWebDialog : public KDialogBase
     QCheckBox *mCbEvent;
     QCheckBox *mCbTodo;
     QCheckBox *mCbDueDates;
-    QCheckBox *mCbAttendees;
+    QCheckBox *mCbCategoriesTodo;
+    QCheckBox *mCbCategoriesEvent;
+    QCheckBox *mCbAttendeesTodo;
+    QCheckBox *mCbAttendeesEvent;
     QCheckBox *mCbHtmlFragment;
     QLineEdit *mOutputFileEdit;
-
 };
 
 #endif // _EXPORTWEBDIALOG_H
