@@ -1,6 +1,6 @@
 #ifndef KOAGENDAITEM_H
 #define KOAGENDAITEM_H
-// $Id: koagendaitem.h,v 1.4 2000/07/12 22:55:56 cschumac Exp $
+// $Id: koagendaitem.h,v 1.5 2000/11/02 01:02:35 cschumac Exp $
 
 #include <qframe.h>
 #include <qlabel.h>
@@ -66,6 +66,7 @@ class KOAgendaItem : public QFrame
 
   public slots:
     void updateIcons();
+    void select(bool=true);
 
   private:
     int mCellX;
@@ -90,6 +91,8 @@ class KOAgendaItem : public QFrame
     QLabel *mIconAlarm,*mIconRecur,*mIconReadonly;
     
     static QToolTipGroup *mToolTipGroup;
+
+    bool mSelected;
 };
 
 #endif // KOAGENDAITEM_H
