@@ -1,4 +1,4 @@
-// $Id: koagendaview.h,v 1.13 2000/07/29 21:18:58 cschumac Exp $
+// $Id: koagendaview.h,v 1.15 2001/01/02 22:50:57 cschumac Exp $
 //
 // KOAgendaView is the agenda-like view used to display events in an one or
 // multi-day view.
@@ -6,16 +6,7 @@
 #ifndef KOAGENDAVIEW_H 
 #define KOAGENDAVIEW_H
 
-//#include <qlabel.h>
-//include <qframe.h>
-//#include <qdatetm.h>
-//#include <qlistbox.h>
-//#include <qlayout.h>
-//#include <qintdict.h>
-
-//#include <kapp.h>
-
-#include "kobaseview.h"
+#include "koeventview.h"
 
 #include <qscrollview.h>
 #include <qdatetime.h>
@@ -57,10 +48,6 @@ class TimeLabels : public QScrollView {
     int mRows;
     int mCellHeight;
 
-    /** 12 = am/pm
-        24 = military time */
-    int mTimeFormat;
-
     /**  */
     KOAgenda* mAgenda;
 };
@@ -88,7 +75,7 @@ class EventIndicator : public QFrame {
     QArray<bool> mEnabled;
 };
 
-class KOAgendaView : public KOBaseView {
+class KOAgendaView : public KOEventView {
     Q_OBJECT
   public:
     KOAgendaView(CalObject *cal,QWidget *parent = 0,const char *name = 0);
@@ -114,8 +101,8 @@ class KOAgendaView : public KOBaseView {
     /** Remove all events from view */
     void clearView();
 
-   virtual void printPreview(CalPrinter *calPrinter,
-                             const QDate &, const QDate &);
+    virtual void printPreview(CalPrinter *calPrinter,
+                              const QDate &, const QDate &);
     
   public slots:
     virtual void updateView();
@@ -136,6 +123,9 @@ class KOAgendaView : public KOBaseView {
 
     void startDrag(KOEvent *);
 
+    void readSettings();
+    void writeSettings();
+
   signals:
     void editEventSignal(KOEvent *);  // From KOBaseView
     void showEventSignal(KOEvent *);
@@ -159,6 +149,11 @@ class KOAgendaView : public KOBaseView {
     /** Set type of agenda view. See also the definitions above. */
     void setView( int ViewType );
 
+    /**
+      Set the masks on the agenda widgets indicating, which days are holidays.
+    */
+    void setHolidayMasks();
+
   protected slots:
 
     /** Move TimeLabels, so that its positions correspond to the agenda. */
@@ -183,6 +178,7 @@ class KOAgendaView : public KOBaseView {
     KOAgenda *mAgenda;
     TimeLabels *mTimeLabels;
     QWidget *mDummyAllDayLeft;
+    QSplitter *mSplitterAgenda;
 
     QDate mStartDate;  // Date of first event displayed
     QDateList mSelectedDates;  // List of dates to be displayed
@@ -199,6 +195,8 @@ class KOAgendaView : public KOBaseView {
     
     QArray<int> mMinY;
     QArray<int> mMaxY;
+    
+    QArray<bool> mHolidayMask;
 };
 
 #endif  // KOAGENDAVIEW_H
