@@ -1,4 +1,4 @@
-// 	$Id: koeditorrecurrence.cpp,v 1.10 2000/09/07 16:37:57 faure Exp $	
+// 	$Id: koeditorrecurrence.cpp,v 1.13 2001/02/08 09:45:46 cschumac Exp $	
 
 #include <qtooltip.h>
 #include <qfiledialog.h>
@@ -16,6 +16,7 @@
 #include <kstddirs.h>
 #include <kbuttonbox.h>
 #include <kabapi.h>
+#include <kdebug.h>
 
 #include "koevent.h"
 #include "koprefs.h"
@@ -146,7 +147,7 @@ void KOEditorRecurrence::initMain()
 //  rangeButtonGroup->setExclusive(true);
 
   startDateLabel = new QLabel(i18n("Begin On:"), rangeButtonGroup);
-  startDateEdit = new KDateEdit(rangeButtonGroup);
+//  startDateEdit = new KDateEdit(rangeButtonGroup);
   noEndDateButton = new QRadioButton(i18n("No Ending Date"), rangeButtonGroup);
   endDurationButton = new QRadioButton(i18n("End after"), rangeButtonGroup);
   endDurationEdit = new QLineEdit(rangeButtonGroup);
@@ -157,10 +158,12 @@ void KOEditorRecurrence::initMain()
   // Construct layout for recurrence range box
   QBoxLayout *layoutRange = new QVBoxLayout(rangeButtonGroup,5);
     
-  QBoxLayout *layoutStart = new QHBoxLayout;
-  layoutRange->addLayout(layoutStart);
-  layoutStart->addWidget(startDateLabel);
-  layoutStart->addWidget(startDateEdit,AlignVCenter);
+//  QBoxLayout *layoutStart = new QHBoxLayout;
+//  layoutRange->addLayout(layoutStart);
+//  layoutStart->addWidget(startDateLabel);
+//  layoutStart->addWidget(startDateEdit,AlignVCenter);
+
+  layoutRange->addWidget(startDateLabel);
 
   layoutRange->addWidget(noEndDateButton);
   
@@ -431,6 +434,8 @@ void KOEditorRecurrence::initYearly()
 
 void KOEditorRecurrence::initExceptions()
 {
+  mExceptionDates.setAutoDelete(true);
+
   // Create the exceptions group box, which holds controls for
   // specifying dates which are exceptions to the rule specified on
   // this tab.
@@ -508,24 +513,29 @@ void KOEditorRecurrence::setEnabled(bool enabled)
 
 void KOEditorRecurrence::addException()
 {
-  QDate tmpDate;
-
-  tmpDate = exceptionDateEdit->getDate();
+  QDate tmpDate = exceptionDateEdit->getDate();
   exceptionList->insertItem(KGlobal::locale()->formatDate(tmpDate));
+  mExceptionDates.append(new QDate(tmpDate));
 }
 
 void KOEditorRecurrence::changeException()
 {
-  QDate tmpDate;
-  tmpDate = exceptionDateEdit->getDate();
-
-  exceptionList->changeItem(KGlobal::locale()->formatDate(tmpDate),
-			    exceptionList->currentItem());
+  int pos = exceptionList->currentItem();
+  if (pos < 0) return;
+  
+  QDate tmpDate = exceptionDateEdit->getDate();
+  mExceptionDates.remove(pos);
+  mExceptionDates.insert(pos,new QDate(tmpDate));
+  exceptionList->changeItem(KGlobal::locale()->formatDate(tmpDate),pos);
 }
 
 void KOEditorRecurrence::deleteException()
 {
-  exceptionList->removeItem(exceptionList->currentItem());
+  int pos = exceptionList->currentItem();
+  if (pos < 0) return;
+
+  mExceptionDates.remove(pos);
+  exceptionList->removeItem(pos);
 }
 
 void KOEditorRecurrence::unsetAllCheckboxes()
@@ -634,6 +644,9 @@ void KOEditorRecurrence::setDefaults(QDateTime from, QDateTime to,bool)
   unsetAllCheckboxes();
 
   setDateTimes(from,to);
+
+  startDateLabel->setText(i18n("Begins On: %1")
+                          .arg(KGlobal::locale()->formatDate(from.date())));
   
   noEndDateButton->setChecked(true);
   weeklyButton->setChecked(true);
@@ -646,7 +659,7 @@ void KOEditorRecurrence::setDefaults(QDateTime from, QDateTime to,bool)
   nthDayEntry->setCurrentItem(from.date().day()-1);
   nMonthsEntry->setText("1");
   yearDayButton->setChecked(true);
-  nYearsEntry->setText(QString::number(from.date().dayOfYear()));
+  nYearsEntry->setText("1");
 }
 
 void KOEditorRecurrence::readEvent(KOEvent *event)
@@ -716,7 +729,11 @@ void KOEditorRecurrence::readEvent(KOEvent *event)
     break;
   }
 
+  startDateLabel->setText(i18n("Begins On: %1")
+      .arg(KGlobal::locale()->formatDate(event->getDtStart().date())));
+
   if (event->doesRecur()) {
+
     // get range information
     if (event->getRecursDuration() == -1)
       noEndDateButton->setChecked(true);
@@ -747,8 +764,10 @@ void KOEditorRecurrence::readEvent(KOEvent *event)
   QDate *curDate;
   exceptionDateEdit->setDate(QDate::currentDate());
   for (curDate = exDates.first(); curDate;
-       curDate = exDates.next())
+       curDate = exDates.next()) {
     exceptionList->insertItem(KGlobal::locale()->formatDate(*curDate));
+    mExceptionDates.append(new QDate(*curDate));
+  }
 }
 
 void KOEditorRecurrence::writeEvent(KOEvent *event)
@@ -777,7 +796,7 @@ void KOEditorRecurrence::writeEvent(KOEvent *event)
       rDuration = 0;
       rEndDate = endDateEdit->getDate();
     }
-    
+
     // check for daily recurrence
     if (dailyButton->isChecked()) {
       int rFreq;
@@ -874,13 +893,16 @@ void KOEditorRecurrence::writeEvent(KOEvent *event)
     event->unsetRecurs();
 
   QDateList exDates;
-  for (i = 0; i < exceptionList->count(); i++)
-    exDates.inSort(dateFromText(exceptionList->text(i)));
-
+  for (i = 0; i < exceptionList->count(); i++) {
+    exDates.inSort(new QDate(*(mExceptionDates.at(i))));
+  }
+  
   event->setExDates(exDates);
   exDates.clear();
 }
 
+// obsolete
+#if 0
 QDate *KOEditorRecurrence::dateFromText(QString text)
 {
   QString tmpStr = text;
@@ -923,6 +945,7 @@ QDate *KOEditorRecurrence::dateFromText(QString text)
   
   return new QDate(y,m,d);
 }
+#endif
 
 void KOEditorRecurrence::setDateTimeStr(const QString &str)
 {
