@@ -1,6 +1,6 @@
 #ifndef _KOEDITORRECURRENCE_H
 #define _KOEDITORRECURRENCE_H
-// $Id: koeditorrecurrence.h,v 1.5 2000/07/23 23:38:34 cschumac Exp $
+// $Id: koeditorrecurrence.h,v 1.7 2000/11/23 22:07:24 cschumac Exp $
 
 #include <qframe.h>
 #include <qlabel.h>
@@ -72,7 +72,7 @@ class KOEditorRecurrence : public QWidget
     void initLayout();
 
   private:
-    QDate *dateFromText(QString text);
+//    QDate *dateFromText(QString text);
     
     /* stuff to hold the appointment time setting widgets. */
     QGroupBox* timeGroupBox;
@@ -141,7 +141,7 @@ class KOEditorRecurrence : public QWidget
     QGroupBox*    rangeGroupBox;
     QButtonGroup* rangeButtonGroup;
     QLabel*       startDateLabel;
-    KDateEdit*    startDateEdit;
+//    KDateEdit*    startDateEdit;
     QRadioButton* noEndDateButton;
     QRadioButton* endDurationButton;
     QLineEdit*    endDurationEdit;
@@ -157,6 +157,7 @@ class KOEditorRecurrence : public QWidget
     QPushButton* deleteExceptionButton;
     QPushButton* exceptionDateButton;
     QListBox *exceptionList;
+    QList<QDate> mExceptionDates;
 
     // current start and end date and time
     QDateTime currStartDateTime;
