@@ -1,13 +1,12 @@
 #ifndef KOEVENTVIEWER_H
 #define KOEVENTVIEWER_H
-// $Id: koeventviewer.h,v 1.2 2000/05/21 12:32:08 cschumac Exp $
+// $Id: koeventviewer.h,v 1.4 2000/07/29 21:18:58 cschumac Exp $
 //
-// Viewer widget and dialog for events.
+// Viewer widget for events.
 //
 
 #include <qtextview.h>
 
-#include <kdialogbase.h>
 
 class KOEvent;
 
@@ -22,29 +21,21 @@ class KOEventViewer : public QTextView {
     void setTodo(KOEvent *event);
     
     void appendEvent(KOEvent *event);
+    void appendTodo(KOEvent *event);
     
     void clearEvents(bool now=false);
     
   protected:
     void addTag(const QString & tag,const QString & text);
 
+    void formatCategories(KOEvent *event);
+    void formatAttendees(KOEvent *event);
+    void formatReadOnly(KOEvent *event);
+
   private:
     QTextView *mEventTextView;
 
     QString mText;    
 };
 
-class KOEventViewerDialog : public KDialogBase {
-    Q_OBJECT
-  public:
-    KOEventViewerDialog(QWidget *parent=0,const char *name=0);
-    virtual ~KOEventViewerDialog();
-
-    void setEvent(KOEvent *event);
-    void setTodo(KOEvent *event);
-    
-  private:
-    KOEventViewer *mEventViewer;
-};
-
 #endif
