@@ -1,4 +1,4 @@
-/* $Id: kotodoview.h,v 1.16 2000/05/24 22:28:54 cschumac Exp $ */
+/* $Id: kotodoview.h,v 1.19 2001/01/02 22:50:57 cschumac Exp $ */
 #ifndef _KOTODOVIEW_H
 #define _KOTODOVIEW_H
 
@@ -16,12 +16,13 @@
 
 #include "calobject.h"
 #include "koevent.h"
+#include "kobaseview.h"
 
 /**
  * This class provides a way of displaying a single KOEvent of Todo-Type in a
  * KTodoView.
  *
- * @author Cornelius Schumacher <schumacher@asic.uni-heidelberg.de>
+ * @author Cornelius Schumacher <schumacher@kde.org>
  * @see KOTodoView
  */
 class KOTodoViewItem : public QCheckListItem
@@ -69,6 +70,7 @@ class KOTodoListView : public QListView
     void contentsMousePressEvent(QMouseEvent *);
     void contentsMouseMoveEvent(QMouseEvent *);
     void contentsMouseReleaseEvent(QMouseEvent *);
+    void contentsMouseDoubleClickEvent(QMouseEvent *);
 
   private:
     CalObject *mCalendar;
@@ -83,20 +85,44 @@ class KOTodoListView : public QListView
  * This class provides a multi-column list view of todo events.
  *
  * @short multi-column list view of todo events.
- * @author Cornelius Schumacher <schumacher@asic.uni-heidelberg.de>
+ * @author Cornelius Schumacher <schumacher@kde.org>
  */
-class KOTodoView : public QWidget
+class KOTodoView : public KOBaseView
 {
     Q_OBJECT
   public:
     KOTodoView(CalObject *, QWidget* parent=0, const char* name=0 );
     ~KOTodoView() {}
 
+    QList<KOEvent> getSelected();
+
+    /** Return number of shown dates. TodoView does not show dates, */
+    int currentDateCount() { return 0; }
+
+    void printPreview(CalPrinter *calPrinter, const QDate &fd, const QDate &td);
+
   public slots:
     void updateView();
     void updateConfig();
-    KOEvent *getSelected();
+
+    void changeEventDisplay(KOEvent *, int);
+  
+    /**
+     * selects the dates specified in the list.  If the view cannot support
+     * displaying all the dates requested, or it needs to change the dates
+     * in some manner, it may call @see datesSelected.
+     * @param dateList is the list of dates to try and select.
+     */
+    void selectDates(const QDateList dateList);
+  
+    /**
+     * Select events visible in the current display
+     * @param eventList a list of events to select.
+     */
+    void selectEvents(QList<KOEvent> eventList);
+
     void editItem(QListViewItem *item);
+    void showItem(QListViewItem *item);
     void popupMenu(QListViewItem *item,const QPoint &,int);
     void newTodo();
     void newSubTodo();
@@ -118,8 +144,6 @@ class KOTodoView : public QWidget
     QMap<KOEvent *,KOTodoViewItem *>::ConstIterator
       insertTodoItem(KOEvent *todo);
 
-    CalObject *mCalendar;
-    
     KOTodoListView *mTodoListView;
     QPopupMenu *mItemPopupMenu;
     QPopupMenu *mPopupMenu;
