@@ -1,46 +1,68 @@
-// popmail-conduit.cc
-//
-// Copyright (C) 1998,1999,2000 Dan Pilone
-// Copyright (C) 1999,2000 Michael Kropfberger
-//
-// This file is distributed under the Gnu General Public Licence (GPL).
-// The GPL should have been included with this file in a file called
-// COPYING. 
-//
-// $Revision: 1.7 $
+/* popmail-conduit.cc			KPilot
+**
+** Copyright (C) 1998-2001 Dan Pilone
+** Copyright (C) 1999,2000 Michael Kropfberger
+**
+** This file is part of the popmail conduit, a conduit for KPilot that
+** synchronises the Pilot's email application with the outside world,
+** which currently means:
+**	-- sendmail or SMTP for outgoing mail
+**	-- POP or mbox for incoming mail
+*/
 
-// Note that there are still some internationalisation issues
-// in the messages sent to the pilot as part of the log.
-//
-//
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, 
+** MA 02139, USA.
+*/
 
-// This is an old trick so you can determine what revisions
-// make up a binary distribution.
-//
-//
-static const char *id=
-	"$Id: popmail-conduit.cc,v 1.7 2000/09/05 07:13:57 adridg Exp $";
+/*
+** Bug reports and questions can be sent to adridg@cs.kun.nl
+*/
 
 
+
+static const char *popmail_conduit_id=
+	"$Id: popmail-conduit.cc,v 1.15.2.1 2001/03/05 15:04:41 adridg Exp $";
+
+
+#include "options.h"
+
+#ifndef HAVE_GETDOMAINNAME
+#include <sys/utsname.h>
+#endif
+
 #include <sys/types.h>
 #include <sys/socket.h> 
 #include <ctype.h>
+#include <iostream.h>
 
 #include <qdir.h>
 #include <qtextstream.h>
 
-#include <iostream.h>
 #include <kapp.h>
 #include <kconfig.h>
 #include <kmessagebox.h>
 #include <ksock.h>
 #include <kiconloader.h>
 #include <kdebug.h>
+#include <kaboutdata.h>
 
 #include "conduitApp.h"
-#include "pi-source.h"
-#include "pi-mail.h"
-#include "pi-dlp.h"
+#include <pi-source.h>
+#include <pi-mail.h>
+#include <pi-dlp.h>
 #include "passworddialog.h"
 #include "popmail-conduit.h"
 #include "setupDialog.h"
@@ -55,7 +77,7 @@ extern time_t parsedate(char * p);
 // belong in the class interface]
 //
 //
-void showMessage(QString message)
+void showMessage(const QString &message)
 { 
   KMessageBox::error(0L, message, i18n("Error retrieving mail"));
 }
@@ -86,28 +108,28 @@ void showMessage(QString message)
 void showResponseResult(int const ret,
 	const char *message,
 	const char *buffer,
-	const char *fname)
+	const char *func)
 {
 	QString msg(i18n(message));
 
 	if (ret==TIMEOUT)
 	{
 		msg.append(i18n(" (Timed out)"));
-		kdDebug() << fname
+		DEBUGCONDUIT << func
 			<< ": " << message
 			<< endl;
 	}
 	if (ret==PERROR)
 	{
-		kdDebug() << fname
+		kdWarning() << func
 			<< ": " << message
+			<< perror
 			<< endl ;
-		perror(fname);
 	}
 
 	if (ret>=0)
 	{
-		kdDebug() << fname
+		DEBUGCONDUIT << func
 			<< ": " << message
 			<< endl;
 
@@ -118,7 +140,7 @@ void showResponseResult(int const ret,
 		{
 			msg.append("\n");
 			msg.append(buffer);
-			kdDebug() << fname
+			DEBUGCONDUIT << func
 				<< ": " << buffer
 				<< endl;
 		}
@@ -179,7 +201,7 @@ static int getPOPResponse(KSocket *s,const char *message,
 
 	if (ret==TIMEOUT)
 	{
-		showResponseResult(ret,message,buffer,fname);
+		showResponseResult(ret,message,buffer,__FUNCTION__);
 		return TIMEOUT;
 	}
 
@@ -199,7 +221,7 @@ static int getPOPResponse(KSocket *s,const char *message,
 	//
 	if(buffer[i] != '+')
 	{
-		showResponseResult(ret,message,buffer+i,fname);
+		showResponseResult(ret,message,buffer+i,__FUNCTION__);
 		return BADPOP;
 	}
 
@@ -255,29 +277,33 @@ PopMailConduit::doSync()
 {
 	FUNCTIONSETUP;
 
-	KConfig* config = KPilotLink::getConfig(PopMailOptions::PopGroup);
+	KConfig& config = KPilotLink::getConfig(PopMailOptions::PopGroup);
 	int mode=0;
 	int sent_count=0,received_count=0;
 
 	addSyncLogMessage("Mail ");
 
-	mode=config->readNumEntry("SyncOutgoing");
+	mode=config.readNumEntry("SyncOutgoing");
 	if(mode)
 	{
+#ifdef DEBUG
 		if (debug_level)
 		{
 			kdDebug() << fname << ": Sending pending mail" << endl;
 		}
+#endif
 		sent_count=sendPendingMail(mode);
 	}
 
-	mode=config->readNumEntry("SyncIncoming");
+	mode=config.readNumEntry("SyncIncoming");
 	if(mode)
 	{
+#ifdef DEBUG
 		if (debug_level)
 		{
 			kdDebug() << fname << ": Querying pop server." << endl;
 		}
+#endif
 		received_count=retrieveIncoming(mode);
 	}
 
@@ -315,8 +341,6 @@ PopMailConduit::doSync()
 		addSyncLogMessage(" ] ");
 	}
 	addSyncLogMessage("OK\n");
-
-	delete config;
 }
 
 QWidget*
@@ -341,12 +365,14 @@ int PopMailConduit::sendPendingMail(int mode)
 		count=sendViaSendmail();
 	}
 
+#ifdef DEBUG
 	if (debug_level & SYNC_MINOR)
 	{
 		kdDebug() << fname << ": Sent "
 			<< count << " messages"
 			<< endl;
 	}
+#endif
 
 	return count;
 }
@@ -380,17 +406,18 @@ int PopMailConduit::sendViaSMTP()
   int i = 0;
   struct Mail theMail;
   QString smtpSrv;
-  int smtpPort;
+  int smtpPort=25;
   QString currentDest, msg;
   PilotRecord* pilotRec;
   KSocket* smtpSocket;
   char buffer[0xffff];
   int ret;
   
-  KConfig* config = KPilotLink::getConfig(PopMailOptions::PopGroup);
-  smtpSrv = config->readEntry("SMTPServer","localhost");
-  smtpPort = config->readNumEntry("SMTPPort",25);
+  KConfig& config = KPilotLink::getConfig(PopMailOptions::PopGroup);
+  smtpSrv = config.readEntry("SMTPServer","localhost");
+  smtpPort = config.readNumEntry("SMTPPort",25);
   
+#ifdef DEBUG
 	if (debug_level & SYNC_MINOR)
 	{
 		kdDebug() << fname
@@ -398,13 +425,14 @@ int PopMailConduit::sendViaSMTP()
 			<< smtpSrv << " on port " << smtpPort
 			<< endl;
 	}
+#endif
 
 	smtpSocket = new KSocket(smtpSrv.latin1(),smtpPort); 
 	CHECK_PTR(smtpSocket);
 	if(smtpSocket->socket() < 0)
 	{
 		showResponseResult(PERROR,"Cannot connect to SMTP server",
-			0L,fname);
+			0L,__FUNCTION__);
 		delete smtpSocket;
 		return -1;
 	}
@@ -417,12 +445,13 @@ int PopMailConduit::sendViaSMTP()
 	if ((ret<0) || (strstr(buffer,"220")==0L))
 	{
 		showResponseResult(ret,"SMTP server failed to announce itself",
-			buffer,fname);
+			buffer,__FUNCTION__);
 		delete smtpSocket;
 		return -1;
 	}
 
 
+#ifdef HAVE_GETDOMAINNAME
 	// Now we're going to do some yucky things with
 	// buffer -- one part will be used to hold the domain 
 	// name and the other will be used to hold the
@@ -437,18 +466,28 @@ int PopMailConduit::sendViaSMTP()
 	//
 	getdomainname(buffer+1024,1024);
 	sprintf(buffer, "EHLO %s\r\n",buffer+1024);
+#else
+	{
+		struct utsname u;
+		(void) uname(&u);
+		sprintf(buffer,"EHLO %s\r\n",u.nodename);
+	}
+#endif
+
+#ifdef DEBUG
 	if (debug_level & SYNC_MINOR)
 	{
 		kdDebug() << fname
 			<< ": " << buffer
 			;
 	}
+#endif
 	write(smtpSocket->socket(), buffer, strlen(buffer));
 	ret=getResponse(smtpSocket,buffer,1024);
 	if ((ret < 0 ) || (strstr(buffer,"Hello")==0L))
 	{
 		showResponseResult(ret,"Couldn't EHLO to SMTP server",
-			buffer,fname);
+			buffer,__FUNCTION__);
 		//
 		// Should we QUIT from SMTP server?
 		//
@@ -479,7 +518,7 @@ int PopMailConduit::sendViaSMTP()
 	  currentDest += theMail.to;
 
 
-          QString fromAddress = config->readEntry("EmailAddress");
+          QString fromAddress = config.readEntry("EmailAddress");
         sprintf(buffer,"MAIL FROM: %s\r\n",fromAddress.latin1());
           write(smtpSocket->socket(), buffer, strlen(buffer));
 
@@ -543,8 +582,8 @@ int PopMailConduit::sendViaSMTP()
                write(smtpSocket->socket(), buffer, strlen(buffer));
 	  }
           //insert the real signature file from disk
-          if(!config->readEntry("Signature").isEmpty()) {
-             QFile f(config->readEntry("Signature"));
+          if(!config.readEntry("Signature").isEmpty()) {
+             QFile f(config.readEntry("Signature"));
              if ( f.open(IO_ReadOnly) ) {    // file opened successfully
                 sprintf(buffer,"\r\n-- \r\n");
                 write(smtpSocket->socket(), buffer, strlen(buffer));
@@ -606,9 +645,9 @@ int PopMailConduit::sendViaSendmail()
   QString currentDest;
   PilotRecord* pilotRec;
   
-  KConfig* config = KPilotLink::getConfig(PopMailOptions::PopGroup);
+  KConfig& config = KPilotLink::getConfig(PopMailOptions::PopGroup);
 
-  sendmailCmd = config->readEntry("SendmailCmd");
+  sendmailCmd = config.readEntry("SendmailCmd");
   
 //   pilotLink->addSyncLogEntry("Reading outgoing mail...");
 
@@ -618,27 +657,33 @@ int PopMailConduit::sendViaSendmail()
     {
       FILE* sendf; // for talking to sendmail
 
+#ifdef DEBUG
 	if (debug_level & SYNC_TEDIOUS)
 	{
 		kdDebug() << fname << ": Reading " << i << "th message" << endl;
 	}
+#endif
       pilotRec = readNextRecordInCategory(1);
 	if(pilotRec == 0L)
 	{
+#ifdef DEBUG
 		if (debug_level)
 		{
 			kdDebug() << fname << ": Got a NULL record from "
 				"readNextRecord" << endl;
 		}
+#endif
 		break;
 	}
       if((pilotRec->getAttrib() & dlpRecAttrDeleted) 
                || (pilotRec->getAttrib() & dlpRecAttrArchived))
 	{
+#ifdef DEBUG
 		if (debug_level & SYNC_TEDIOUS )
 		{
 			kdDebug() << fname << ": Skipping deleted record." << endl;
 		}
+#endif
 		delete pilotRec;
 	}
       else
@@ -650,9 +695,9 @@ int PopMailConduit::sendViaSendmail()
 	    {
  	      KMessageBox::error(0L, "Cannot talk to sendmail!",
 				   "Error Sending Mail");
-		kdDebug() << fname 
+		kdWarning() << __FUNCTION__ 
 			<< ": Could not start sendmail.\n"
-			<< fname << ": " << count 
+			<< __FUNCTION__ << ": " << count 
 			<< " messages sent OK"
 			<< endl ;
 	      return -1;
@@ -673,11 +718,13 @@ int PopMailConduit::sendViaSendmail()
     }
 //   free_MailAppInfo(&mailAppInfo);
 
+#ifdef DEBUG
 	if (debug_level & SYNC_MAJOR)
 	{
 		kdDebug() << fname << ": Sent " << count << " messages"
 			<< endl;
 	}
+#endif
 
 	return count;
 }
@@ -690,10 +737,10 @@ PopMailConduit::sendMessage(FILE* sendf, struct Mail& theMail)
 {
 	FUNCTIONSETUP;
 
-	KConfig *config=KPilotLink::getConfig(PopMailOptions::PopGroup); 
+	KConfig& config=KPilotLink::getConfig(PopMailOptions::PopGroup); 
   QTextStream mailPipe(sendf, IO_WriteOnly);
   
-  QString fromAddress = config->readEntry("EmailAddress");
+  QString fromAddress = config.readEntry("EmailAddress");
   mailPipe << "From: " << fromAddress << "\r\n";
   mailPipe << "To: " << theMail.to << "\r\n";
   if(theMail.cc)
@@ -708,29 +755,35 @@ PopMailConduit::sendMessage(FILE* sendf, struct Mail& theMail)
   mailPipe << "\r\n";
 
 
+#ifdef DEBUG
 	if (debug_level & SYNC_MINOR)
 	{
 		kdDebug() << fname << ": To: " << theMail.to << endl;
 	}
+#endif
 
 
 	if(theMail.body)
 	{
+#ifdef DEBUG
 		if (debug_level & SYNC_MINOR)
 		{
 			kdDebug() << fname << ": Sent body." << endl;
 		}
+#endif
 		mailPipe << theMail.body << "\r\n";
 	}
 
   //insert the real signature file from disk
-  if(!config->readEntry("Signature").isEmpty()) {
+  if(!config.readEntry("Signature").isEmpty()) {
+#ifdef DEBUG
 	if (debug_level & SYNC_MINOR)
 	{
 		kdDebug() << fname << ": Reading signature" << endl;
 	}
+#endif
 
-      QFile f(config->readEntry("Signature"));
+      QFile f(config.readEntry("Signature"));
       if ( f.open(IO_ReadOnly) ) {    // file opened successfully
          mailPipe << "-- \r\n";
          QTextStream t( &f );        // use a text stream
@@ -742,10 +795,12 @@ PopMailConduit::sendMessage(FILE* sendf, struct Mail& theMail)
    }
     mailPipe << "\r\n";
 
+#ifdef DEBUG
 	if (debug_level & SYNC_MINOR)
 	{
 		kdDebug() << fname << ": Done" << endl;
 	}
+#endif
 }
 
 /* static */ char*
@@ -887,6 +942,7 @@ void PopMailConduit::retrievePOPMessages(KSocket *popSocket,int const msgcount,
 
 		sscanf(buffer+ret, "%*s %*d %d", &len);
 
+#ifdef DEBUG
 		if (debug_level & SYNC_TEDIOUS)
 		{
 			kdDebug() << fname
@@ -894,10 +950,11 @@ void PopMailConduit::retrievePOPMessages(KSocket *popSocket,int const msgcount,
 				<< " is " << len << " bytes long"
 				<< endl;
 		}
+#endif
 
 		if (len > 16000) 
 		{
-			kdDebug() << fname
+			kdWarning() << __FUNCTION__
 				<< ": Skipped long message " << i
 				<< endl;
 			continue; 
@@ -1017,7 +1074,7 @@ int PopMailConduit::doPopQuery()
 	FUNCTIONSETUP;
 
 	KSocket* popSocket;
-	KConfig* config = KPilotLink::getConfig(PopMailOptions::PopGroup); 
+	KConfig& config = KPilotLink::getConfig(PopMailOptions::PopGroup); 
 	char buffer[0xffff];
 	int offset;
 	int flags=0;
@@ -1028,28 +1085,30 @@ int PopMailConduit::doPopQuery()
 	// the config file.
 	//
 	//
-	if (config->readNumEntry("LeaveMail") == 0)
+	if (config.readNumEntry("LeaveMail") == 0)
 	{
 		flags |= POP_DELE ;
 	}
 
-	popSocket = new KSocket(config->readEntry("PopServer").latin1(),
-		config->readNumEntry("PopPort")); 
+	popSocket = new KSocket(config.readEntry("PopServer").latin1(),
+		config.readNumEntry("PopPort")); 
 	CHECK_PTR(popSocket);
 
+#ifdef DEBUG
 	if (debug_level & SYNC_MAJOR)
 	{
 		kdDebug() << fname 
 			<< ": Attempted to connect to POP3 server "
-			<< config->readEntry("PopServer")
+			<< config.readEntry("PopServer")
 			<< endl;
 	}
+#endif
 
 	if(popSocket->socket() < 0)
 	{
 		showResponseResult(PERROR,
 			"Cannot connect to POP server -- no socket",
-			0L,fname);
+			0L,__FUNCTION__);
 		delete popSocket;
 		return -1;
 	}
@@ -1059,6 +1118,7 @@ int PopMailConduit::doPopQuery()
 	popSocket->enableRead(true);
 	popSocket->enableWrite(true);
 
+#ifdef DEBUG
 	if (debug_level & SYNC_TEDIOUS)
 	{
 		kdDebug() << fname 
@@ -1066,6 +1126,7 @@ int PopMailConduit::doPopQuery()
 			<< popSocket->socket()
 			<< endl ;
 	}
+#endif
 
 	// The following code is based _HEAVILY_ :) 
 	// on pilot-mail.c by Kenneth Albanowski
@@ -1080,7 +1141,7 @@ int PopMailConduit::doPopQuery()
 	}
 
 
-	sprintf(buffer, "USER %s\r\n", config->readEntry("PopUser").latin1());
+	sprintf(buffer, "USER %s\r\n", config.readEntry("PopUser").latin1());
 	write(popSocket->socket(), buffer, strlen(buffer));
 	if (getPOPResponse(popSocket,"USER command to POP server failed",
 		buffer,1024)<0)
@@ -1089,17 +1150,19 @@ int PopMailConduit::doPopQuery()
 		return -1;
 	}
 
-	if(config->readNumEntry("StorePass", 0))
+	if(config.readNumEntry("StorePass", 0))
 	{
+#ifdef DEBUG
 		if (debug_level & SYNC_TEDIOUS)
 		{
 			kdDebug() << fname 
 				<< ": Reading password from config."
 				<< endl;
 		}
+#endif
 
 		sprintf(buffer, "PASS %s\r\n", 
-			config->readEntry("PopPass").latin1());
+			config.readEntry("PopPass").latin1());
 	}
 	else
 	{
@@ -1117,9 +1180,11 @@ int PopMailConduit::doPopQuery()
 		}
 		else
 		{
+#ifdef DEBUG
 			kdDebug() << fname
 				<< ": Password dialog was canceled." 
 				<< endl;
+#endif
 			delete passDialog;
 			disconnectPOP(popSocket);
 			delete popSocket;
@@ -1156,7 +1221,7 @@ int PopMailConduit::doPopQuery()
 	// [ The standard says otherwise ]
 	//
 	QString msg(buffer+offset);
-	if (msg.find( config->readEntry("PopUser")) != -1) // with username
+	if (msg.find( config.readEntry("PopUser")) != -1) // with username
 	{
 		sscanf(buffer+offset, "%*s %*s %*s %d %*s", &msgcount);
 	}
@@ -1165,6 +1230,7 @@ int PopMailConduit::doPopQuery()
 		sscanf(buffer+offset, "%*s %d %*s", &msgcount);
 	}
 
+#ifdef DEBUG
 	if (debug_level & SYNC_TEDIOUS)
 	{
 		kdDebug() << fname
@@ -1176,6 +1242,7 @@ int PopMailConduit::doPopQuery()
 			<< msgcount << " messages."
 			<< endl;
 	}
+#endif
 
 	if(msgcount < 1)
 	{
@@ -1207,10 +1274,12 @@ int PopMailConduit::doPopQuery()
 	while (!feof(f))
 	{
 		if (fgets(buffer,buffersize,f)==0L) break;
+#ifdef DEBUG
 		if (debug_level & SYNC_TEDIOUS)
 		{
 			kdDebug() <<  fname << ": Got line " << buffer ;
 		}
+#endif
 
 		s=buffer;
 		while (isspace(*s)) s++;
@@ -1245,34 +1314,41 @@ int PopMailConduit::doPopQuery()
 	//
 	if (expectFrom)
 	{
+#ifdef DEBUG
 		if (debug_level & SYNC_TEDIOUS)
 		{
 			kdDebug() << fname << ": Looking for From line." << endl;
 		}
+#endif
 
 		skipBlanks(f,line,LINESIZE);
 		if (strncmp(line,"From ",5))
 		{
-			kdDebug() << fname << ": No leading From line." << endl;
+			kdWarning() << __FUNCTION__
+				<< ": No leading From line." << endl;
 			return 0;
 		}
 
+#ifdef DEBUG
 		if (debug_level & SYNC_TEDIOUS)
 		{
 			kdDebug() << fname << ": Found it." << endl;
 		}
+#endif
 	}
 
 	while ((skipBlanks(f,line,LINESIZE)==0) && !feof(f))
 	{
 		if ((line[0]=='.') && (line[1]=='\n') && (line[2] == 0))
 		{
+#ifdef DEBUG
 			if (debug_level & SYNC_TEDIOUS)
 			{
 				kdDebug() << fname << ": Found end-of-headers " 
 					"and end-of-message."
 					<< endl;
 			}
+#endif
 			// End of message *and* end-of headers.
 			return -count;
 		}
@@ -1284,11 +1360,13 @@ int PopMailConduit::doPopQuery()
 		//
 		if (line[0]=='\n')
 		{
+#ifdef DEBUG
 			if (debug_level & SYNC_TEDIOUS)
 			{
 				kdDebug() << fname << ": Found end-of-headers" 
 					<< endl;
 			}
+#endif
 			// End of headers
 			header(t,0);
 			return count;
@@ -1298,11 +1376,13 @@ int PopMailConduit::doPopQuery()
 		count++;
 	}
 
+#ifdef DEBUG
 	if (debug_level & SYNC_TEDIOUS)
 	{
 		kdDebug() << fname << ": Read " << count << " lines." << endl;
 	}
-	strcpy(buf,line);
+#endif
+	strncpy(buf,line,bufsiz);
 	return count;
 }
 
@@ -1313,10 +1393,12 @@ int PopMailConduit::doPopQuery()
 	int count=0;
 	int linelen=0;
 
+#ifdef DEBUG
 	if (debug_level & SYNC_TEDIOUS)
 	{
 		kdDebug() << fname << ": Buffer @" << (int) buf << endl;
 	}
+#endif
 
 	while(!feof(f) && (bufsize > 80))
 	{
@@ -1329,6 +1411,7 @@ int PopMailConduit::doPopQuery()
 			return count;
 		}
 
+#ifdef DEBUG
 		if (debug_level & SYNC_TEDIOUS)
 		{
 			kdDebug() << fname << ": Got line ["  
@@ -1336,6 +1419,7 @@ int PopMailConduit::doPopQuery()
 				<< ']'
 				<< buf;
 		}
+#endif
 
 		if ((buf[0]=='.') && ((buf[1]=='\n') || (buf[1]=='\r')))
 		{
@@ -1382,7 +1466,8 @@ int PopMailConduit::doPopQuery()
 	messageLength=readHeaders(mailbox,buffer,bufferSize,&t,1);
 	if (messageLength == 0)
 	{
-		kdDebug() << fname << ": Bad headers in message." << endl;
+		kdWarning() << __FUNCTION__ 
+			<< ": Bad headers in message." << endl;
 		return 0;
 	}
 
@@ -1390,6 +1475,7 @@ int PopMailConduit::doPopQuery()
 	if (messageLength>0)
 	{
 		messageLength=strlen(buffer);
+#ifdef DEBUG
 		if (debug_level & SYNC_TEDIOUS)
 		{
 			kdDebug() << fname << ": Message so far:" << endl
@@ -1399,12 +1485,14 @@ int PopMailConduit::doPopQuery()
 			kdDebug() << fname << ": Buffer @" << (int) buffer 
 				<< endl;
 		}
+#endif
 
 		if (readBody(mailbox,
 			buffer+messageLength,
 			bufferSize-messageLength) < 0)
 		{
-			kdDebug() << fname << ": Bad body for message." << endl;
+			kdWarning() << __FUNCTION__
+				<< ": Bad body for message." << endl;
 			return 0;
 		}
 	}
@@ -1444,38 +1532,42 @@ int PopMailConduit::doUnixStyle()
 	PilotRecord *pilotRec=0L;
 
 	{
-		KConfig *config=KPilotLink::getConfig(PopMailOptions::PopGroup); 
+		KConfig& config=KPilotLink::getConfig(PopMailOptions::PopGroup); 
 	
-		filename=config->readEntry("UNIX Mailbox");
+		filename=config.readEntry("UNIX Mailbox");
 		if (filename.isEmpty()) return 0;
 
+#ifdef DEBUG
 		if (debug_level & SYNC_MINOR)
 		{
 			kdDebug() << fname << ": Trying to read mailbox "
 				<< filename << endl;
 		}
+#endif
 
 		QFileInfo info(filename);
 		if (!info.exists()) 
 		{
-			kdDebug() << fname << ": Mailbox doesn't exist."
+			kdWarning() << __FUNCTION__ << ": Mailbox doesn't exist."
 				<< endl;
 			return -1;
 		}
 
+#ifdef DEBUG
 		if (debug_level & SYNC_MINOR)
 		{
 			kdDebug() << fname << ": Mailbox found." << endl;
 		}
+#endif
 
-		delete config;
 	}
 
 	mailbox=fopen(filename.latin1(),"r");
 	if (mailbox==0L)
 	{
-		kdDebug() << fname << ": Can't open mailbox." << endl;
-		perror(fname);
+		kdWarning() << __FUNCTION__ << ": Can't open mailbox:" 
+			<< perror
+			<< endl;
 		return -1;
 	}
 
@@ -1485,16 +1577,18 @@ int PopMailConduit::doUnixStyle()
 		if  (pilotRec && writeRecord(pilotRec)>0)
 		{
 			messageCount++;
+#ifdef DEBUG
 			if (debug_level & SYNC_MAJOR)
 			{
 				kdDebug() << fname << ": Read message "
 					<< messageCount << " from mailbox." 
 					<< endl;
 			}
+#endif
 		}
 		else
 		{
-			kdDebug() << fname << ": Message "
+			kdWarning() << __FUNCTION__ << ": Message "
 				<< messageCount << " couldn't be written."
 				<< endl;
 			showMessage(i18n("Error writing mail message to Pilot"));
@@ -1502,6 +1596,7 @@ int PopMailConduit::doUnixStyle()
 		delete pilotRec;
 	}
 
+#ifdef DEBUG
 	if (debug_level & SYNC_MAJOR)
 	{
 		kdDebug() << fname << ": Wrote "
@@ -1509,39 +1604,44 @@ int PopMailConduit::doUnixStyle()
 			<< " messages to pilot." 
 			<< endl;
 	}
+#endif
 
 	return messageCount;
 }
 #undef BUFFERSIZE
 
-/* virtual */ QPixmap *PopMailConduit::icon() const
+/* virtual */ QPixmap PopMailConduit::icon() const
 {
 	FUNCTIONSETUP;
 
-	QPixmap *p=new QPixmap;
-	*p = KGlobal::iconLoader()->loadIcon("kbiff", KIcon::Desktop);
+	QPixmap p=KGlobal::iconLoader()->loadIcon("kmail", KIcon::Desktop);
 	return p;
 }
 
-#include <kaboutdata.h>
 
 int main(int argc, char* argv[])
 {
-#ifdef KDE2
 	ConduitApp a(argc,argv,"popmail-conduit",
 		I18N_NOOP("POP Mail Conduit"),
 		"4.0b");
-#else
-	ConduitApp a(argc, argv, "popmail-conduit",
-		"\t\tPopmail-Conduit -- A conduit for KPilot\n"
-		"Copyright (C) 1998,1999 Dan Pilone, Michael Kropfberger\n"
-		"Copyright (C) 2000 Adriaan de Groot");
-
-#endif
 	a.addAuthor("Michael Kropfberger","POP3 code");
+	a.addAuthor("Adriaan de Groot","KDE2 port");
 
 	PopMailConduit conduit(a.getMode());
 	a.setConduit(&conduit);
 
 	return a.exec();
 }
+
+
+
+// $Log: popmail-conduit.cc,v $
+// Revision 1.15.2.1  2001/03/05 15:04:41  adridg
+// Solaris 8 compile fixes
+//
+// Revision 1.15  2001/02/09 15:59:28  habenich
+// replaced "char *id" with "char *<filename>_id", because of --enable-final in configure
+//
+// Revision 1.14  2001/02/07 15:46:31  adridg
+// Updated copyright headers for source release. Added CVS log. No code change.
+//
