@@ -1,20 +1,42 @@
-// popmail-conduit.h
-//
-// Copyright (C) 1998,1999 Dan Pilone
-//
-// This file is distributed under the Gnu General Public Licence (GPL).
-// The GPL should have been included with this file in a file called
-// COPYING. 
-//
-// $Revision: 1.5 $
+/* popmail-conduit.h			KPilot
+**
+** Copyright (C) 1998,1999,2000 Dan Pilone
+** Copyright (C) 1999,2000 Michael Kropfberger
+**
+** This file is part of the popmail conduit, a conduit for KPilot that
+** synchronises the Pilot's email application with the outside world,
+** which currently means:
+**	-- sendmail or SMTP for outgoing mail
+**	-- POP or mbox for incoming mail
+*/
 
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, 
+** MA 02139, USA.
+*/
+
+/*
+** Bug reports and questions can be sent to adridg@cs.kun.nl
+*/
 
 
 #ifndef _POPMAIL_CONDUIT_H
 #define _POPMAIL_CONDUIT_H
 
 #include "baseConduit.h"
-#include "pi-mail.h"
+#include <pi-mail.h>
 
 class PilotRecord;
 
@@ -29,7 +51,7 @@ public:
 
   virtual const char* dbInfo() { return "MailDB"; }
 
-	virtual QPixmap *icon() const;
+	virtual QPixmap icon() const;
 
 	/**
 	* Returns a string describing the version of
@@ -120,3 +142,9 @@ private:
 };
 
 #endif
+
+
+// $Log: popmail-conduit.h,v $
+// Revision 1.8  2001/02/07 15:46:31  adridg
+// Updated copyright headers for source release. Added CVS log. No code change.
+//
