@@ -1,19 +1,40 @@
-// setupDialog.cc
-//
-// Copyright (C) 1998,1999,2000 Dan Pilone
-//
-// This file is distributed under the Gnu General Public Licence (GPL).
-// The GPL should have been included with this file in a file called
-// COPYING. 
-//
-// $Revision: 1.7 $
+/* setupDialog.cc			KPilot
+**
+** Copyright (C) 1998-2001 Dan Pilone
+**
+** This file is part of the popmail conduit, a conduit for KPilot that
+** synchronises the Pilot's email application with the outside world,
+** which currently means:
+**	-- sendmail or SMTP for outgoing mail
+**	-- POP or mbox for incoming mail
+*/
 
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, 
+** MA 02139, USA.
+*/
+
+/*
+** Bug reports and questions can be sent to adridg@cs.kun.nl
+*/
 // This is an old trick so you can determine what revisions
 // make up a binary distribution.
 //
 //
-static const char *id=
-	"$Id: setupDialog.cc,v 1.7 2000/09/05 07:13:57 adridg Exp $";
+static const char *setupDialog_id=
+	"$Id: setupDialog.cc,v 1.13 2001/02/09 15:59:28 habenich Exp $";
 
 
 
@@ -39,8 +60,8 @@ static const char *id=
 #include "setupDialog.moc"
 #include "kpilot.h"
 
-PopMailSendPage::PopMailSendPage(setupDialog *parent,KConfig *config) :
-	setupDialogPage(i18n("Sending Mail"),parent,config)
+PopMailSendPage::PopMailSendPage(setupDialog *parent,KConfig& config) :
+	setupDialogPage(i18n("Sending Mail"),parent)
 {
 	FUNCTIONSETUP;
 	QGridLayout *grid=new QGridLayout(this,6,3,SPACING);
@@ -73,7 +94,7 @@ PopMailSendPage::PopMailSendPage(setupDialog *parent,KConfig *config) :
 			    this);
 
 	fEmailFrom = new QLineEdit(this);
-	fEmailFrom->setText(config->readEntry("EmailAddress", "$USER"));
+	fEmailFrom->setText(config.readEntry("EmailAddress", "$USER"));
 	fEmailFrom->resize(200, fEmailFrom->height());
 
 	grid->addWidget(currentLabel,1,0);
@@ -84,7 +105,7 @@ PopMailSendPage::PopMailSendPage(setupDialog *parent,KConfig *config) :
 	currentLabel->adjustSize();
 
 	fSignature = new QLineEdit(this);
-	fSignature->setText(config->readEntry("Signature", ""));
+	fSignature->setText(config.readEntry("Signature", ""));
 	fSignature->resize(200, fSignature->height());
 	
 	fSignatureBrowse=new QPushButton(i18n("Browse"),this);
@@ -101,7 +122,7 @@ PopMailSendPage::PopMailSendPage(setupDialog *parent,KConfig *config) :
 	currentLabel->adjustSize();
 	
 	fSendmailCmd = new QLineEdit(this);
-	fSendmailCmd->setText(config->readEntry("SendmailCmd", 
+	fSendmailCmd->setText(config.readEntry("SendmailCmd", 
 		"/usr/lib/sendmail -t -i"));
 	fSendmailCmd->resize(300, fSendmailCmd->height());
 
@@ -112,7 +133,7 @@ PopMailSendPage::PopMailSendPage(setupDialog *parent,KConfig *config) :
 	currentLabel->adjustSize();
 	
 	fSMTPServer = new QLineEdit(this);
-	fSMTPServer->setText(config->readEntry("SMTPServer", "mail"));
+	fSMTPServer->setText(config.readEntry("SMTPServer", "mail"));
 	fSMTPServer->resize(200, fSendmailCmd->height());
 
 	grid->addWidget(currentLabel,6,0);
@@ -122,17 +143,17 @@ PopMailSendPage::PopMailSendPage(setupDialog *parent,KConfig *config) :
 	currentLabel->adjustSize();
 	
 	fSMTPPort = new QLineEdit(this);
-	fSMTPPort->setText(config->readEntry("SMTPPort", "25"));
+	fSMTPPort->setText(config.readEntry("SMTPPort", "25"));
 	fSMTPPort->resize(200, fSendmailCmd->height());
 
 	grid->addWidget(currentLabel,7,0);
 	grid->addWidget(fSMTPPort,7,1);
 
-	setMode(PopMailConduit::SendMode(config->readNumEntry("SyncOutgoing",
+	setMode(PopMailConduit::SendMode(config.readNumEntry("SyncOutgoing",
 		PopMailConduit::SEND_NONE)));
 }
 
-/* virtual */ int PopMailSendPage::commitChanges(KConfig *config)
+/* virtual */ int PopMailSendPage::commitChanges(KConfig& config)
 {
 	FUNCTIONSETUP;
 
@@ -140,17 +161,17 @@ PopMailSendPage::PopMailSendPage(setupDialog *parent,KConfig *config) :
 	if (parentSetup->queryFile(i18n("Signature File %1 is missing."),
 		fSignature->text())!=KMessageBox::No)
 	{
-		config->writeEntry("Signature", fSignature->text());
+		config.writeEntry("Signature", fSignature->text());
 	}
 
-	config->writeEntry("EmailAddress", fEmailFrom->text());
+	config.writeEntry("EmailAddress", fEmailFrom->text());
 
 
-	config->writeEntry("SendmailCmd", fSendmailCmd->text());
-	config->writeEntry("SMTPServer", fSMTPServer->text());
-	config->writeEntry("SMTPPort", fSMTPPort->text());
+	config.writeEntry("SendmailCmd", fSendmailCmd->text());
+	config.writeEntry("SMTPServer", fSMTPServer->text());
+	config.writeEntry("SMTPPort", fSMTPPort->text());
 
-	config->writeEntry("SyncOutgoing", (int)getMode());
+	config.writeEntry("SyncOutgoing", (int)getMode());
 
 	return 0;
 }
@@ -188,7 +209,7 @@ void PopMailSendPage::setMode(PopMailConduit::SendMode m)
 		fNoSend->setChecked(true);
 		break;
 	default :
-		cerr << fname 
+		cerr << __FUNCTION__
 			<< ": Unknown mode " << (int) m
 			<< endl;
 		return;
@@ -206,11 +227,13 @@ void PopMailSendPage::browseSignature()
 
 	QString filename=fSignature->text();
 
+#ifdef DEBUG
 	if (debug_level & UI_TEDIOUS)
 	{
 		kdDebug() << fname << ": Signature currently "
 			<< fSignature->text() << endl;
 	}
+#endif
 
 	if (filename.isEmpty()) 
 	{
@@ -223,11 +246,13 @@ void PopMailSendPage::browseSignature()
 
 	filename = QFileDialog::getOpenFileName(filename,"*");
 
+#ifdef DEBUG
 	if (debug_level & UI_MINOR)
 	{
 		kdDebug() << fname << ": Signature selected "
 			<< filename << endl;
 	}
+#endif
 
 	if (!filename.isEmpty())
 	{
@@ -238,8 +263,8 @@ void PopMailSendPage::browseSignature()
 
 
 PopMailReceivePage::PopMailReceivePage(setupDialog *parent,
-	KConfig *config) :
-	setupDialogPage(i18n("Receiving Mail"),parent,config)
+	KConfig& config) :
+	setupDialogPage(i18n("Receiving Mail"),parent)
 {
 	FUNCTIONSETUP;
 	QLabel *currentLabel;
@@ -289,7 +314,7 @@ PopMailReceivePage::PopMailReceivePage(setupDialog *parent,
 		defaultMailbox=QString("/var/spool/mail/")+QString(u);
 	}
 	fMailbox=new QLineEdit(this);
-	fMailbox->setText(config->readEntry("UNIX Mailbox",defaultMailbox));
+	fMailbox->setText(config.readEntry("UNIX Mailbox",defaultMailbox));
 	fMailbox->resize(200,fMailbox->height());
 	}
 	fMailboxBrowse=new QPushButton(i18n("Browse"),this);
@@ -311,7 +336,7 @@ PopMailReceivePage::PopMailReceivePage(setupDialog *parent,
 	currentLabel->adjustSize();
 	
 	fPopServer = new QLineEdit(this);
-	fPopServer->setText(config->readEntry("PopServer", "pop"));
+	fPopServer->setText(config.readEntry("PopServer", "pop"));
 	fPopServer->resize(200, fPopServer->height());
 	
 	grid->addWidget(currentLabel,3,0);
@@ -321,7 +346,7 @@ PopMailReceivePage::PopMailReceivePage(setupDialog *parent,
 	currentLabel->adjustSize();
 	
 	fPopPort = new QLineEdit(this);
-	fPopPort->setText(config->readEntry("PopPort", "110"));
+	fPopPort->setText(config.readEntry("PopPort", "110"));
 	fPopPort->resize(200, fPopPort->height());
 	
 	grid->addWidget(currentLabel,4,0);
@@ -331,7 +356,7 @@ PopMailReceivePage::PopMailReceivePage(setupDialog *parent,
 	currentLabel->adjustSize();
 	
 	fPopUser = new QLineEdit(this);
-	fPopUser->setText(config->readEntry("PopUser", "$USER"));
+	fPopUser->setText(config.readEntry("PopUser", "$USER"));
 	fPopUser->resize(200, fPopUser->height());
 	
 	grid->addWidget(currentLabel,5,0);
@@ -339,7 +364,7 @@ PopMailReceivePage::PopMailReceivePage(setupDialog *parent,
 
 	fLeaveMail = new QCheckBox(i18n("&Leave mail on server."), this);
 	fLeaveMail->adjustSize();
-	fLeaveMail->setChecked(config->readNumEntry("LeaveMail", 1));
+	fLeaveMail->setChecked(config.readNumEntry("LeaveMail", 1));
 	
 	grid->addWidget(fLeaveMail,6,1);
 
@@ -348,10 +373,10 @@ PopMailReceivePage::PopMailReceivePage(setupDialog *parent,
 	
 	fPopPass = new QLineEdit(this);
 	fPopPass->setEchoMode(QLineEdit::Password);
-	fPopPass->setText(config->readEntry("PopPass", ""));
+	fPopPass->setText(config.readEntry("PopPass", ""));
 	fPopPass->resize(200, fPopPass->height());
 	
-	fPopPass->setEnabled(config->readNumEntry("StorePass", 0));
+	fPopPass->setEnabled(config.readNumEntry("StorePass", 0));
 
 	grid->addWidget(currentLabel,7,0);
 	grid->addWidget(fPopPass,7,1);
@@ -360,27 +385,27 @@ PopMailReceivePage::PopMailReceivePage(setupDialog *parent,
 	fStorePass = new QCheckBox(i18n("Save &Pop password."), this);
 	connect(fStorePass, SIGNAL(clicked()), this, SLOT(togglePopPass()));
 	fStorePass->adjustSize();
-	fStorePass->setChecked(config->readNumEntry("StorePass", 0));
+	fStorePass->setChecked(config.readNumEntry("StorePass", 0));
 	togglePopPass();
 	
 	grid->addWidget(fStorePass,8,1);
 
 	setMode(PopMailConduit::RetrievalMode(
-		config->readNumEntry("SyncIncoming",
+		config.readNumEntry("SyncIncoming",
 			PopMailConduit::RECV_NONE)));
 }
 
-/* virtual */ int PopMailReceivePage::commitChanges(KConfig *config)
+/* virtual */ int PopMailReceivePage::commitChanges(KConfig& config)
 {
 	FUNCTIONSETUP;
-	config->writeEntry("UNIX Mailbox", fMailbox->text());
+	config.writeEntry("UNIX Mailbox", fMailbox->text());
 
-	config->writeEntry("PopServer", fPopServer->text().latin1());
-	config->writeEntry("PopPort", atoi(fPopPort->text().latin1()));
-	config->writeEntry("PopUser", fPopUser->text().latin1());
-	config->writeEntry("LeaveMail", (int)fLeaveMail->isChecked());
-	config->writeEntry("StorePass", (int)fStorePass->isChecked());
-	config->sync(); 
+	config.writeEntry("PopServer", fPopServer->text().latin1());
+	config.writeEntry("PopPort", atoi(fPopPort->text().latin1()));
+	config.writeEntry("PopUser", fPopUser->text().latin1());
+	config.writeEntry("LeaveMail", (int)fLeaveMail->isChecked());
+	config.writeEntry("StorePass", (int)fStorePass->isChecked());
+	config.sync(); 
 	//
 	// Make sure permissions are safe (still not a good idea)
 	//
@@ -388,15 +413,15 @@ PopMailReceivePage::PopMailReceivePage(setupDialog *parent,
 	{
 		chmod(KGlobal::dirs()->findResource("config", "kpilotrc")
 			.latin1(), 0600);
-		config->writeEntry("PopPass", fPopPass->text().latin1());
+		config.writeEntry("PopPass", fPopPass->text().latin1());
 	}
 	else
 	{
-		config->writeEntry("PopPass",QString::null);
+		config.writeEntry("PopPass",QString::null);
 	}
 
-	config->writeEntry("SyncIncoming", (int)getMode());
-	config->sync();
+	config.writeEntry("SyncIncoming", (int)getMode());
+	config.sync();
 
 	return 0;
 }
@@ -445,7 +470,7 @@ void PopMailReceivePage::setMode(PopMailConduit::RetrievalMode m)
 		fReceiveUNIX->setChecked(true);
 		break;
 	default :
-		cerr << fname 
+		cerr << __FUNCTION__
 			<< ": Unknown mode " << (int) m
 			<< endl;
 		return;
@@ -460,11 +485,13 @@ void PopMailReceivePage::setMode(PopMailConduit::RetrievalMode m)
 
 	QString filename=fMailbox->text();
 
+#ifdef DEBUG
 	if (debug_level & UI_TEDIOUS)
 	{
 		kdDebug() << fname << ": Mailbox currently "
 			<< fMailbox->text() << endl;
 	}
+#endif
 
 	if (filename.isEmpty()) 
 	{
@@ -477,11 +504,13 @@ void PopMailReceivePage::setMode(PopMailConduit::RetrievalMode m)
 
 	filename = QFileDialog::getOpenFileName(filename,"*");
 
+#ifdef DEBUG
 	if (debug_level & UI_MINOR)
 	{
 		kdDebug() << fname << ": Mailbox selected "
 			<< filename << endl;
 	}
+#endif
 
 	if (!filename.isEmpty())
 	{
@@ -532,11 +561,23 @@ PopMailOptions::setupWidget()
 {
 	FUNCTIONSETUP;
 
-	KConfig* config = KPilotLink::getConfig();
-	config->setGroup(PopGroup);
+	KConfig& config = KPilotLink::getConfig();
+	config.setGroup(PopGroup);
 
 
 	addPage(new PopMailSendPage(this,config));
 	addPage(new PopMailReceivePage(this,config));
 	addPage(new setupInfoPage(this));
 }
+
+
+// $Log: setupDialog.cc,v $
+// Revision 1.13  2001/02/09 15:59:28  habenich
+// replaced "char *id" with "char *<filename>_id", because of --enable-final in configure
+//
+// Revision 1.12  2001/02/07 15:46:31  adridg
+// Updated copyright headers for source release. Added CVS log. No code change.
+//
+// Revision 1.11  2001/01/03 00:05:13  adridg
+// Administrative
+//
