@@ -1,13 +1,34 @@
-// setupDialog.h
-//
-// Copyright (C) 1998,1999 Dan Pilone
-//
-// This file is distributed under the Gnu General Public Licence (GPL).
-// The GPL should have been included with this file in a file called
-// COPYING. 
-//
-// $Revision: 1.5 $
+/* setupDialog.h			KPilot
+**
+** Copyright (C) 1998-2001 Dan Pilone
+**
+** This file is part of the popmail conduit, a conduit for KPilot that
+** synchronises the Pilot's email application with the outside world,
+** which currently means:
+**	-- sendmail or SMTP for outgoing mail
+**	-- POP or mbox for incoming mail
+*/
 
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, 
+** MA 02139, USA.
+*/
+
+/*
+** Bug reports and questions can be sent to adridg@cs.kun.nl
+*/
 
 #ifndef __POPMAIL_SETUP_H
 #define __POPMAIL_SETUP_H
@@ -33,8 +54,8 @@ class PopMailSendPage : public setupDialogPage
 	Q_OBJECT
 
 public:
-	PopMailSendPage(setupDialog *parent,KConfig *);
-	virtual int commitChanges(KConfig *);
+	PopMailSendPage(setupDialog *parent,KConfig& );
+	virtual int commitChanges(KConfig& );
 
 public slots:
 	/**
@@ -78,8 +99,8 @@ class PopMailReceivePage : public setupDialogPage
 	Q_OBJECT
 
 public:
-	PopMailReceivePage(setupDialog *,KConfig *);
-	virtual int commitChanges(KConfig *);
+	PopMailReceivePage(setupDialog *,KConfig& );
+	virtual int commitChanges(KConfig& );
 
 public slots:
 	void browseMailbox();
@@ -128,3 +149,9 @@ protected:
 } ;
 
 #endif
+
+
+// $Log: setupDialog.h,v $
+// Revision 1.7  2001/02/07 15:46:31  adridg
+// Updated copyright headers for source release. Added CVS log. No code change.
+//
