@@ -1,9 +1,39 @@
-// Conduit for KPilot <--> KOrganizer for Todo Items
-// (c) 1998, 1999, 2000 Preston Brown
+/* todo-conduit.cc			KPilot
+**
+** Copyright (C) 1998-2001 Dan Pilone
+** Copyright (C) 1998-2000 Preston Brown
+** Copyright (C) 1998 Herwin-Jan Steehouwer
+**
+** This file is part of the todo conduit, a conduit for KPilot that
+** synchronises the Pilot's todo application with the outside world,
+** which currently means KOrganizer.
+*/
 
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, 
+** MA 02139, USA.
+*/
+
+/*
+** Bug reports and questions can be sent to adridg@cs.kun.nl
+*/
 // I have noticed that this is full of memory leaks, but since it is
 // short lived, it shouldn't matter so much. -- PGB
 
+#include "options.h"
+
 #include <sys/types.h>
 #include <signal.h>
 #include <iostream.h>
@@ -28,7 +58,6 @@
 #include "todo-setup.h"
 #include "conduitApp.h"
 
-#include "options.h"
 
 // globals
 bool first = TRUE;
@@ -72,15 +101,14 @@ void TodoConduit::getCalendar()
 {
 	FUNCTIONSETUP;
 
-	KConfig* config = KPilotLink::getConfig(TodoSetup::TodoGroup);
+	KConfig& config = KPilotLink::getConfig(TodoSetup::TodoGroup);
 
-	calName = config->readEntry("CalFile");
-	first = config->readBoolEntry("FirstTime", TRUE);
+	calName = config.readEntry("CalFile");
+	first = getFirstTime(config);
 
-	delete config;
 
-	if ((fMode == BaseConduit::HotSync) || 
-		(fMode == BaseConduit::Backup)) 
+	if ((getMode() == BaseConduit::HotSync) || 
+		(getMode() == BaseConduit::Backup)) 
 	{
 		fCalendar = Parse_MIME_FromFileName((char*)calName.latin1());
 
@@ -94,14 +122,14 @@ void TodoConduit::getCalendar()
 			KMessageBox::error(0,
 				message.arg(calName),
 				i18n("Todo Conduit Fatal Error"));
-			exit(-1);
+			exit(ConduitMisconfigured);
 		}
 	}
 	else
 	{
 		kdDebug() << fname
 			<< ": Called in mode "
-			<< (int) fMode
+			<< (int) getMode()
 			<< " where it makes no sense."
 			<< endl;
 	}
@@ -327,8 +355,8 @@ void TodoConduit::saveTodo()
 {
 	FUNCTIONSETUP;
 
-	KConfig* config = KPilotLink::getConfig(TodoSetup::TodoGroup);
-	QString calName = config->readEntry("CalFile");
+	KConfig& config = KPilotLink::getConfig(TodoSetup::TodoGroup);
+	QString calName = config.readEntry("CalFile");
 
 	if (fCalendar)
 	{
@@ -532,9 +560,6 @@ void TodoConduit::doLocalSync()
 					       text.latin1(), "&Insert","&Delete",
 					       "Insert &All",0);
 	   switch(response) {
-	   case 0:
-	     updateVObject(rec);
-	     break;
 	   case 1:
 	     deletedList.append(new int(rec->getID()));
 	     break;
@@ -542,6 +567,10 @@ void TodoConduit::doLocalSync()
 	     insertall = 1;
 	     updateVObject(rec);
 	     break;
+	   case 0:
+	   default:
+	     updateVObject(rec);
+	     break;
 	   }
 	 } else {
 	   // all records are to be inserted.
@@ -560,6 +589,9 @@ void TodoConduit::doLocalSync()
      delete rec;
    }
    deletedList.clear();
+
+	KConfig& config = KPilotLink::getConfig(TodoSetup::TodoGroup);
+	setFirstTime(config,false);
 }
 
 /*
@@ -657,3 +689,9 @@ int TodoConduit::numFromDay(const QString &day)
   return -1; // something bad happened. :)
 } 
 
+
+
+// $Log: todo-conduit.cc,v $
+// Revision 1.11  2001/02/07 15:46:32  adridg
+// Updated copyright headers for source release. Added CVS log. No code change.
+//
