@@ -1,10 +1,42 @@
-// Conduit for KPilot <--> KOrganizer
-// (c) 1998, 1999, 2000  Preston Brown, Herwin Jan Steehouwer, and Dan Pilone
+/* vcal-conduit.cc		VCalendar Conduit
+**
+** Copyright (C) 1998-2000 by Dan Pilone, Preston Brown, and
+**	Herwin Jan Steehouwer
+**
+** A program to synchronize KOrganizer's date book with the Palm
+** Pilot / KPilot. This program is part of KPilot.
+*/
+
+
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, 
+** MA 02139, USA.
+*/
+
+/*
+** Bug reports and questions can be sent to adridg@cs.kun.nl
+*/
+
 
 // I have noticed that this is full of memory leaks, but since it is
 // short lived, it shouldn't matter so much. -- PGB
 
-// $Revision: 1.7 $
+// $Revision: 1.24.2.1 $
+
+#define DEBUG
+#include "options.h"
 
 #include <sys/types.h>
 #include <signal.h>
@@ -19,7 +51,6 @@
 #include <qmsgbox.h>
 
 #include <kconfig.h>
-/* #include <kapp.h> */
 #include <kdebug.h>
 
 #include "kpilotlink.h"
@@ -33,24 +64,32 @@
 #include "kpilot.h"
 
 static const char *id=
-	"$Id: vcal-conduit.cc,v 1.7 2000/09/05 07:13:57 adridg Exp $";
+	"$Id: vcal-conduit.cc,v 1.24.2.1 2001/03/07 17:38:37 adridg Exp $";
 
 
 // globals
 bool first = TRUE;
 
+
 int main(int argc, char* argv[])
 {
   ConduitApp a(argc, argv, "vcal_conduit",
   	"Calendar / Organizer conduit",
-	"4.0");
+	"4.0b2");
   a.addAuthor("Preston Brown",I18N_NOOP("Organizer author"));
+	a.addAuthor("Adriaan de Groot",I18N_NOOP("Maintainer"));
   VCalConduit conduit(a.getMode());
   a.setConduit(&conduit);
-  return a.exec();
+  return a.exec(false,true);
+
+	/* NOTREACHED */
+	(void) id;
 }
 
-VCalConduit::VCalConduit(eConduitMode mode)
+
+
+
+VCalConduit::VCalConduit(BaseConduit::eConduitMode mode)
   : BaseConduit(mode)
 {
 	FUNCTIONSETUP;
@@ -67,10 +106,6 @@ VCalConduit::~VCalConduit()
   }
 }
 
-/* static */ const char *VCalConduit::version()
-{
-	return "VCal Conduit v2.0";
-}
 
 void VCalConduit::getCalendar()
 {
@@ -78,54 +113,105 @@ void VCalConduit::getCalendar()
 
 	if (fCalendar)
 	{
-		kdDebug() << fname
+		kdWarning() << __FUNCTION__
 			<< ": Already have a calendar file."
 			<< endl;
 		return;
 	}
 
-	KConfig* config = KPilotLink::getConfig(VCalSetup::VCalGroup);
-	QString calName = config->readEntry("CalFile");
-	first = config->readBoolEntry("FirstTime", TRUE);
+	KConfig& config = KPilotLink::getConfig(VCalSetup::VCalGroup);
+	(void) getDebugLevel(config);
+	QString calName = config.readEntry("CalFile");
+	first = getFirstTime(config);
 
-	if ((fMode == BaseConduit::HotSync) || 
-		(fMode == BaseConduit::Backup)) 
+	DEBUGCONDUIT << fname
+		<< ": Calendar file is " << calName
+		<< ( first ? " (first time!)" : "" )
+		<< endl;
+
+#ifdef DEBUG
+	// This (and the next debug message) need the #ifdefs
+	// because they use the debugging functions qstringExpansion
+	// and charExpansion.
+	//
+	//
+	DEBUGCONDUIT << fname
+		<< ": Using calendar name:"
+		<< endl;
+	DEBUGCONDUIT << fname
+		<< qstringExpansion(calName)
+		<< endl;
+#endif
+	QCString s=QFile::encodeName(calName);
+
+#ifdef DEBUG
+	DEBUGCONDUIT << fname
+		<< ": Encoded calendar name:"
+		<< endl;
+	DEBUGCONDUIT << fname
+		<< charExpansion(s)
+		<< endl;
+#endif
+	fCalendar = Parse_MIME_FromFileName((const char*)s);
+
+	if(fCalendar == 0L) 
 	{
-		fCalendar = Parse_MIME_FromFileName((char*)calName.latin1());
+		QString message = i18n(
+			"The VCalConduit could not open the file `%1'. "
+			"Please configure the conduit with the correct "
+			"filename and try again.")
+			.arg(calName);
 
-		if(fCalendar == 0L) 
-		{
-			QString message(i18n(
-				"The VCalConduit could not open the file `%1'. "
-				"Please configure the conduit with the correct "
-				"filename and try again."));
-			KMessageBox::error(0, "vCalendar Conduit Fatal Error",
-			    message.arg(calName));                                                 
-			exit(-1);
-		}
+		kdError() << __FUNCTION__
+			<< ": Couldn't open "
+			<< calName
+			<< endl;
+
+		KMessageBox::error(0, message,"vCalendar Conduit Fatal Error");
+		exit(ConduitMisconfigured);
+	}
+	else
+	{
+		DEBUGCONDUIT << fname
+			<< ": Got calendar!"
+			<< endl;
 	}
 }
 
 void VCalConduit::doBackup()
 {
+	FUNCTIONSETUP;
   PilotRecord* rec;
   int index = 0;
   
 	getCalendar();
-  rec = readRecordByIndex(index++);
-  
-  // Get ALL entries from Pilot
-  while (rec) {
-    if (rec->getAttrib() & dlpRecAttrDeleted) { // tagged for deletion
-      deleteVObject(rec);
-    } else {
-       updateVObject(rec);
-    }    
-    delete rec;
-    rec = readRecordByIndex(index++);
-  }
-  // save the vCalendar
-  saveVCal();
+
+#ifdef DEBUG
+	if(debug_level & SYNC_MAJOR)
+	{
+		kdDebug() << fname
+			<< ": Performing full backup"
+			<< endl;
+	}
+#endif
+
+	// Get ALL entries from Pilot
+	//
+	//
+	while ((rec=readRecordByIndex(index++)))
+	{
+		if (rec->isDeleted()) 
+		{
+			deleteVObject(rec);
+		} 
+		else 
+		{
+			updateVObject(rec);
+		}
+		delete rec;
+	}
+
+	saveVCal();
 }
 
 void VCalConduit::doSync()
@@ -133,29 +219,57 @@ void VCalConduit::doSync()
 	FUNCTIONSETUP;
 
    PilotRecord* rec;
+	int recordcount=0;
 
 	getCalendar();
-   rec = readNextModifiedRecord();
+	if (fCalendar==0L)
+	{
+		kdError() << __FUNCTION__ << ": No calendar to sync with."
+			<< endl;
+		return;
+	}
 
-   // get only MODIFIED entries from Pilot, compared with the above (doBackup),
-   // which gets ALL entries
-   while (rec) {
-     if(rec->getAttrib() & dlpRecAttrDeleted) {
-       deleteVObject(rec);
-     } else {
-       bool pilotRecModified = (rec->getAttrib() & dlpRecAttrDirty);
-       if (pilotRecModified) {
-	 updateVObject(rec);
-       } else {
-		kdDebug() << fname
-			<< "weird! we asked for a modified record and got one that wasn't.\n";
-       }
-     }
-     
-     delete rec;
-     rec = readNextModifiedRecord();
-   }
+	// get only MODIFIED entries from Pilot, compared with 
+	// the above (doBackup), which gets ALL entries
+	//
+	//
+	while ((rec=readNextModifiedRecord())) 
+	{
+		recordcount++;
+		if (rec->isDeleted())
+		{
+			deleteVObject(rec);
+		} 
+		else 
+		{
+			bool pilotRecModified = 
+				(rec->getAttrib() & dlpRecAttrDirty);
+			if (pilotRecModified) 
+			{
+				updateVObject(rec);
+			} 
+			else 
+			{
+				kdWarning() << __FUNCTION__
+					<< "weird! we asked for a modified "
+					   "record and got one that wasn't"
+					<< endl;
+			}
+		}
+		delete rec;
+	}
    
+#ifdef DEBUG
+	if (debug_level & SYNC_MINOR)
+	{
+		kdDebug() << fname
+			<< ": Read a total of "
+			<< recordcount
+			<< " record from the pilot."
+			<< endl;
+	}
+#endif
+
    // now, all the stuff that was modified/new on the pilot should be
    // added to the vCalendar.  We now need to add stuff to the pilot
    // that is modified/new in the vCalendar (the opposite).	  
@@ -165,6 +279,77 @@ void VCalConduit::doSync()
    saveVCal();
 }
 
+void VCalConduit::repeatForever(
+	PilotDateEntry *dateEntry,
+	int rFreq,
+	VObject *vevent)
+{
+	FUNCTIONSETUP;
+
+	const char *s = "<no description>";
+
+	if (vevent)
+	{
+		VObject *vo = isAPropertyOf(vevent, VCSummaryProp);
+		if (vo != 0L)
+		{
+			s=fakeCString(vObjectUStringZValue(vo));
+		}
+	}
+
+
+	dateEntry->setRepeatFrequency(rFreq);
+	dateEntry->setRepeatForever();
+	kdWarning() << __FUNCTION__
+		<< ": repeat duration is forever for "
+		<< s
+		<< endl;
+}
+
+void VCalConduit::repeatUntil(
+	PilotDateEntry *dateEntry,
+	struct tm *start,
+	int rFreq,
+	int rDuration,
+	PeriodConstants period)
+{
+	FUNCTIONSETUP;
+	time_t end_time = mktime(start);
+	struct tm rEnd = *start;
+
+	switch(period)
+	{
+	case DailyPeriod:
+	case WeeklyPeriod:
+		// Calculate the end time by adding the right number of
+		// repeat periods.
+		//
+		//
+		end_time += rFreq * (rDuration-1) * (int) period;
+
+		dateEntry->setRepeatFrequency(rFreq);
+		dateEntry->setRepeatEnd(*localtime(&end_time));
+		break;
+	case MonthlyByDayPeriod:
+	case MonthlyByPosPeriod:
+		dateEntry->setRepeatFrequency(rFreq);
+		rEnd.tm_mon += rFreq * (rDuration - 1);
+		rEnd.tm_year += rEnd.tm_mon / 12;
+		rEnd.tm_mon %= 12;
+		dateEntry->setRepeatEnd(rEnd);
+		break;
+	case YearlyByDayPeriod:
+		dateEntry->setRepeatFrequency(rFreq);
+		rEnd.tm_year += rFreq * (rDuration - 1);
+		dateEntry->setRepeatEnd(rEnd);
+		break;
+	default:
+		kdWarning() << __FUNCTION__
+			<< ": Unknown repeat period "
+			<< (int) period
+			<< endl;
+	}
+}
 
 /*****************************************************************************/
 
@@ -206,8 +391,26 @@ void VCalConduit::updateVObject(PilotRecord *rec)
   }
   
   // determine whether the vobject has been modified since the last sync
+  bool vcalRecModified = true ;
   vo = isAPropertyOf(vevent, KPilotStatusProp);
-  bool vcalRecModified = (atol(fakeCString(vObjectUStringZValue(vo))) == 1);
+  if (vo)
+  {
+	const wchar_t *vp = 0;
+	const char *s = 0;
+	int status = 1;
+
+  	vp = vObjectUStringZValue(vo);
+	if (vp)
+	{
+		s = fakeCString(vp);
+	}
+	if (s)
+	{
+		status=atol(s);
+	}
+
+	vcalRecModified = (status==1);
+  }
   
   if (vcalRecModified) {
     // we don't want to modify the vobject with pilot info, because it has
@@ -218,6 +421,15 @@ void VCalConduit::updateVObject(PilotRecord *rec)
   // otherwise, the vObject hasn't been touched.  Updated it with the
   // info from the PilotRec.
   
+#ifdef DEBUG
+	if (debug_level & SYNC_TEDIOUS)
+	{
+		kdDebug() << fname
+			<< ": Updating start time"
+			<< endl;
+	}
+#endif
+
   // START TIME //
   vo = isAPropertyOf(vevent, VCDTstartProp);
   
@@ -257,13 +469,29 @@ void VCalConduit::updateVObject(PilotRecord *rec)
 		addPropValue(vevent, VCDTstartProp, dateString.latin1());
 	}
 }
+
+#ifdef DEBUG
+	if (debug_level & SYNC_TEDIOUS)
+	{
+		kdDebug() << fname
+			<< ": Updating end time"
+			<< endl;
+	}
+#endif
   
   // END TIME //
   vo = isAPropertyOf(vevent, VCDTendProp);
   
-  bool multiDay = (dateEntry.getRepeatType() == repeatDaily);
+  // Patch by Heiko
+  //
+  //
+  bool multiDay = ( (dateEntry.getRepeatType() == repeatDaily) &&
+		dateEntry.getEvent() );
 
   if (multiDay) {
+  	// I honestly don't know what was supposed to go here
+	//
+	//
   }
 
   QDateTime endDT;
@@ -321,6 +549,14 @@ void VCalConduit::updateVObject(PilotRecord *rec)
   }
 
   
+#ifdef DEBUG
+	if (debug_level & SYNC_TEDIOUS)
+	{
+		kdDebug() << fname
+			<< ": Updating alarms"
+			<< endl;
+	}
+#endif
   // ALARM(s) //
   vo = isAPropertyOf(vevent, VCDAlarmProp);
   if (dateEntry.getAlarm()) {
@@ -371,33 +607,50 @@ void VCalConduit::updateVObject(PilotRecord *rec)
       }
   }
    
-
+#ifdef DEBUG
+	if (debug_level & SYNC_TEDIOUS)
+	{
+		kdDebug() << fname
+			<< ": Updating recurrence"
+			<< endl;
+	}
+#endif
   // RECURRENCE(S) //
   vo = isAPropertyOf(vevent, VCRRuleProp);
   // pilot entries that repeat daily are not what we consider daily
   // repeating events in vCalendar/KOrganizer.  It is actually a multi-day
-  // appointment.  We need to conver it to this sort of thing (done above).
+  // appointment.  We need to convert it to multi-day (done above).
   if (dateEntry.getRepeatType() != repeatNone &&
-      dateEntry.getRepeatType() != repeatDaily) {
+		!multiDay) {
     tmpStr = "";
     switch(dateEntry.getRepeatType()) {
+	case repeatDaily:
+		tmpStr.sprintf("D%i ", dateEntry.getRepeatFrequency());
+		break;
     case repeatWeekly:
+	{
+	const int *days = dateEntry.getRepeatDays();
+
+	DEBUGCONDUIT << fname
+		<< ": Got repeat-weekly entry, by-days="
+		<< days[0] << " "
+		<< days[1] << " "
+		<< days[2] << " "
+		<< days[4] << " "
+		<< days[5] << " "
+		<< days[6] << " "
+		<< endl;
+
       tmpStr.sprintf("W%i ", dateEntry.getRepeatFrequency());
-      if (dateEntry.getRepeatDays()[0])
-	tmpStr.append("SU ");
-      else if (dateEntry.getRepeatDays()[1])
-	tmpStr.append("MO ");
-      else if (dateEntry.getRepeatDays()[2])
-	tmpStr.append("TU ");
-      else if (dateEntry.getRepeatDays()[3])
-	tmpStr.append("WE ");
-      else if (dateEntry.getRepeatDays()[4])
-	tmpStr.append("TH ");
-      else if (dateEntry.getRepeatDays()[5])
-	tmpStr.append("FR ");
-      else if (dateEntry.getRepeatDays()[6])
-	tmpStr.append("SA ");
+      if (days[0]) tmpStr.append("SU ");
+      if (days[1]) tmpStr.append("MO ");
+      if (days[2]) tmpStr.append("TU ");
+      if (days[3]) tmpStr.append("WE ");
+      if (days[4]) tmpStr.append("TH ");
+      if (days[5]) tmpStr.append("FR ");
+      if (days[6]) tmpStr.append("SA ");
       break;
+    }
     case repeatMonthlyByDay: {
       tmpStr.sprintf("MP%i %d+ ",dateEntry.getRepeatFrequency(),
 		     (dateEntry.getRepeatDay() / 7) + 1);
@@ -447,12 +700,27 @@ void VCalConduit::updateVObject(PilotRecord *rec)
   }
 
 
+#ifdef DEBUG
+	if (debug_level & SYNC_TEDIOUS)
+	{
+		kdDebug() << fname
+			<< ": Updating exceptions"
+			<< endl;
+	}
+#endif
   // EXCEPTION(S) //
+	if (multiDay && dateEntry.getExceptionCount())
+	{
+		kdDebug() << fname
+			<< ": WARNING Exceptions ignored for multi-day event "
+			<< dateEntry.getDescription()
+			<< endl ;
+	}
   vo = isAPropertyOf(vevent, VCExDateProp);
-  tmpStr = "";
+  tmpStr = QString::null ;
   if (dateEntry.getExceptionCount()) {
     for (int i = 0; i < dateEntry.getExceptionCount(); i++) {
-      tmpStr = TmToISO(dateEntry.getExceptions()[i]);
+      tmpStr += TmToISO(dateEntry.getExceptions()[i]);
       tmpStr += ";";
     }
     tmpStr.truncate(tmpStr.length()-1);
@@ -466,56 +734,146 @@ void VCalConduit::updateVObject(PilotRecord *rec)
   }
 
 
-  // SUMMARY //
-  vo = isAPropertyOf(vevent, VCSummaryProp);
-  tmpStr = dateEntry.getDescription();
-  // the following should take care of the multi-line summary bug.
-  tmpStr = tmpStr.simplifyWhiteSpace();
-  
-  // the vCalendar parser doesn't handle empty summaries very well...
-  if (!tmpStr.isEmpty()) {
-    if (vo)
-      setVObjectUStringZValue_(vo, fakeUnicode(tmpStr.latin1(), 0));
-    else
-      addPropValue(vevent, VCSummaryProp, tmpStr.latin1());
-  }
+	// The remainder of the updates are in individual methods
+	//
+	//
+	setSummary(vevent,dateEntry.getDescription());
+	setNote(vevent,dateEntry.getNote());
+	setSecret(vevent,(rec->getAttrib() & dlpRecAttrSecret));
+	setStatus(vevent,0);
 
-  
-  // DESCRIPTION (NOTE) //
-  vo = isAPropertyOf(vevent, VCDescriptionProp);
-  if (dateEntry.getNote() != 0L && strlen(dateEntry.getNote()) != 0) {
-    if (vo)
-      setVObjectUStringZValue_(vo, fakeUnicode(dateEntry.getNote(), 0));
-    else
-      vo = addPropValue(vevent, VCDescriptionProp, dateEntry.getNote());
-    // if the description takes up more than one line, we need
-    // to add the Quoted-Printable property.
-    if (strchr(dateEntry.getNote(), '\n') &&
-	!isAPropertyOf(vo, VCQuotedPrintableProp))
-      addProp(vo, VCQuotedPrintableProp);
-  } else {
-    if (vo)
-      addProp(vo, KPilotSkipProp);
-  }
+#ifdef DEBUG
+	if (debug_level & SYNC_TEDIOUS)
+	{
+		kdDebug() << fname
+			<< ": Done updating"
+			<< endl;
+	}
+#endif
+}
 
-  // CLASS (SECRECY) //
-  vo = isAPropertyOf(vevent, VCClassProp);
-  (rec->getAttrib() & dlpRecAttrSecret) ?
-    tmpStr = "PRIVATE" : tmpStr = "PUBLIC";
-  if (vo)
-    setVObjectUStringZValue_(vo, fakeUnicode(tmpStr.latin1(), 0));
-  else
-    addPropValue(vevent, VCClassProp, tmpStr.latin1());
-  
-  // PILOT STATUS //
-  vo = isAPropertyOf(vevent, KPilotStatusProp);
-  // TURN OFF MODIFIED
-  if (vo) {
-    int voStatus = atol(fakeCString(vObjectUStringZValue(vo)));
-    setVObjectUStringZValue_(vo, fakeUnicode("0", 0));
-  } else
-  {
-    addPropValue(vevent, KPilotStatusProp, "0");
+void VCalConduit::setSummary(VObject *vevent,const char *summary)
+{
+	FUNCTIONSETUP;
+
+	VObject *vo = isAPropertyOf(vevent, VCSummaryProp);
+	QString qsummary (summary);
+	qsummary = qsummary.simplifyWhiteSpace();
+	if (qsummary.isEmpty())
+	{
+		// We should probably update (empty) the
+		// summary in the VObject if there
+		// is one.
+		//
+		//
+	}
+	else
+	{
+		if (vo)
+		{
+			setVObjectUStringZValue_(vo, 
+				fakeUnicode(qsummary.latin1(), 0));
+		}
+		else
+		{
+			addPropValue(vevent, VCSummaryProp, 
+				qsummary.latin1());
+		}
+	}
+}
+
+void VCalConduit::setNote(VObject *vevent,const char *s)
+{
+	FUNCTIONSETUP;
+
+	VObject *vo = isAPropertyOf(vevent, VCDescriptionProp);
+
+	if (s && *s)
+	{
+		// There is a note for this event
+		//
+		//
+		if (vo)
+		{
+			setVObjectUStringZValue_(vo, fakeUnicode(s,0));
+		}
+		else
+		{
+			vo = addPropValue(vevent, VCDescriptionProp,s);
+		}
+
+		// vo now certainly (?) points to the note property.
+		//
+		//
+		if (!vo)
+		{
+			kdError() << __FUNCTION__
+				<< ": No object for note property."
+				<< endl;
+			return;
+		}
+
+		if (strchr(s,'\n') && 
+			!isAPropertyOf(vo, VCQuotedPrintableProp))
+		{
+			// Note takes more than one line so we need
+			// to add the Quoted-Printable property
+			//
+			//
+			addProp(vo,VCQuotedPrintableProp);
+		}
+	}
+	else
+	{
+		// No note at all
+		//
+		//
+		if (vo)
+		{
+			// So skip existing note
+			//
+			//
+			addProp(vo,KPilotSkipProp);
+		}
+	}
+}
+
+void VCalConduit::setSecret(VObject *vevent,bool secret)
+{
+	FUNCTIONSETUP;
+
+	VObject *vo = isAPropertyOf(vevent, VCClassProp);
+	const char *s = secret ? "PRIVATE" : "PUBLIC" ;
+
+	if (vo)
+	{
+		setVObjectUStringZValue_(vo,fakeUnicode(s,0));
+	}
+	else
+	{	
+		addPropValue(vevent,VCClassProp,s);
+	}
+}
+
+void VCalConduit::setStatus(VObject *vevent,int status)
+{
+	FUNCTIONSETUP;
+
+	VObject *vo = isAPropertyOf(vevent, KPilotStatusProp);
+	char buffer[2+4*sizeof(int)];	// One byte produces at most 3 digits
+					// in decimal, add some slack and 
+					// space for a -
+
+	sprintf(buffer,"%d",status);
+
+	if (vo)
+	{
+
+		setVObjectUStringZValue_(vo,fakeUnicode(buffer,0));
+	}
+	else
+	{
+		addPropValue(vevent,KPilotStatusProp,buffer);
 	}
 }
 
@@ -546,14 +904,81 @@ void VCalConduit::saveVCal()
 {
 	FUNCTIONSETUP;
 
-	KConfig* config = KPilotLink::getConfig(VCalSetup::VCalGroup);
-	QString calName = config->readEntry("CalFile");
+	KConfig& config = KPilotLink::getConfig(VCalSetup::VCalGroup);
+	QString calName = config.readEntry("CalFile");
 	if (fCalendar)
 	{
 		writeVObjectToFile((char*)calName.latin1(), fCalendar);  
 	}
 }
 
+int VCalConduit::getTimeZone() const
+{
+	FUNCTIONSETUP;
+
+	VObject *vo = isAPropertyOf(fCalendar, VCTimeZoneProp);
+
+	if (!vo)
+	{
+		return 0;
+	}
+  
+	bool neg = FALSE;
+	int hours, minutes;
+	char *s;
+
+	QString tmpStr(s = fakeCString(vObjectUStringZValue(vo)));
+#ifdef DEBUG
+	if (debug_level & SYNC_MINOR)
+	{
+		kdDebug() << fname
+			<< ": Got time zone string "
+			<< s
+			<< endl;
+	}
+#endif
+	deleteStr(s);
+
+	if (tmpStr.left(1) == "-")
+	{
+		neg = TRUE;
+	}
+	if (tmpStr.left(1) == "-" || tmpStr.left(1) == "+")
+	{
+		tmpStr.remove(0, 1);
+	}
+
+	hours = tmpStr.left(2).toInt();
+	if (tmpStr.length() > 2)
+	{
+		minutes = tmpStr.right(2).toInt();
+	}
+	else
+	{
+		minutes = 0;
+	}
+
+
+	int timeZone = (60*hours+minutes);
+	if (neg)
+	{
+		timeZone = -timeZone;
+	}
+
+#ifdef DEBUG
+	if (debug_level & SYNC_MINOR)
+	{
+		kdDebug() << fname
+			<< ": Calculated TZ offset "
+			<< timeZone
+			<< endl;
+	}
+#endif
+
+
+	return timeZone;
+}
+
 void VCalConduit::doLocalSync()
 {
 	FUNCTIONSETUP;
@@ -582,51 +1007,71 @@ void VCalConduit::doLocalSync()
 	if (first)
 	{
 		LocalOverridesPilot=true;
+#ifdef DEBUG
+		kdDebug() << fname
+			<< ": This is the first time the vcal conduit is run"
+			<< endl;
+#endif
 	}
 	else
 	{
 		// We need one of KPilot's global 
 		// settings.
 		//
-		KConfig *config=KPilotLink::getConfig();
-		config->setGroup(0L);
-		LocalOverridesPilot=config->readNumEntry("OverwriteRemote",0);
-		delete config;
+		KConfig& config=KPilotLink::getConfig();
+		LocalOverridesPilot=config.readNumEntry("OverwriteRemote",0);
 	}
 
+#ifdef DEBUG
+	if (debug_level & SYNC_MAJOR)
+	{
+		kdDebug() << fname << ": Performing local sync."
+			<< endl;
+	}
   
-  vo = isAPropertyOf(fCalendar, VCTimeZoneProp);
+	if (debug_level & SYNC_MINOR)
+	{
+		kdDebug() << fname << ": Getting timezone."
+			<< endl;
+	}
+#endif
+
+	timeZone = getTimeZone();
+
   
-  // deal with time zone offset
-  if (vo) {
-    bool neg = FALSE;
-    int hours, minutes;
-    QString tmpStr(s = fakeCString(vObjectUStringZValue(vo)));
-    deleteStr(s);
-    
-    if (tmpStr.left(1) == "-")
-      neg = TRUE;
-    if (tmpStr.left(1) == "-" || tmpStr.left(1) == "+")
-      tmpStr.remove(0, 1);
-    hours = tmpStr.left(2).toInt();
-    if (tmpStr.length() > 2)
-      minutes = tmpStr.right(2).toInt();
-    else
-      minutes = 0;
-    timeZone = (60*hours+minutes);
-    if (neg)
-      timeZone = -timeZone;
-  }
+#ifdef DEBUG
+	if (debug_level & SYNC_MINOR)
+	{
+		kdDebug() << fname << ": Initializing iterator."
+			<< endl;
+	}
+#endif
+	initPropIterator(&i, fCalendar);
   
-  initPropIterator(&i, fCalendar);
-  
-  // go through the whole vCalendar.  If the event has the dirty (modified)
-  // flag set, make a new pilot record and add it.
-  // we only take events that have KPilotStatusProp as a property.  If
-  // this property isn't present, ignore the event.
-  while (moreIteration(&i)) {
-    vevent = nextVObject(&i);
-    vo = isAPropertyOf(vevent, KPilotStatusProp);
+	int recordcount=0;
+
+	  // go through the whole vCalendar.  If the event has the 
+	  // dirty (modified)
+	  // flag set, make a new pilot record and add it.
+	  // we only take events that have KPilotStatusProp as a property.  If
+	  // this property isn't present, ignore the event.
+	  //
+	  //
+	while (moreIteration(&i)) 
+	{
+		recordcount++;
+		vevent = nextVObject(&i);
+		vo = isAPropertyOf(vevent, KPilotStatusProp);
+
+#ifdef DEBUG
+		if (debug_level & SYNC_TEDIOUS)
+		{
+			kdDebug() << fname
+				<< ": Read the following calendar entry:"
+				<< endl;
+			printVObject(stderr,vevent);
+		}
+#endif
     
     if (vo && (strcmp(vObjectName(vevent), VCEventProp) == 0)) {
       status = 0;
@@ -773,11 +1218,27 @@ void VCalConduit::doLocalSync()
 				 dateEntry->getEventEnd().tm_min,
 				 dateEntry->getEventEnd().tm_sec));
 
-	if (tmpDtStart.daysTo(tmpDtEnd)) {
+	if (tmpDtStart.daysTo(tmpDtEnd) &&
+		dateEntry->getEventStart().tm_hour == 0 &&
+		dateEntry->getEventStart().tm_min == 0 &&
+		dateEntry->getEventStart().tm_sec == 0)
+	{
 	  // multi day event
 	  dateEntry->setRepeatType(repeatDaily);
 	  dateEntry->setRepeatFrequency(1);
 	  dateEntry->setRepeatEnd(dateEntry->getEventEnd());
+		if (isAPropertyOf(vevent, VCExDateProp) != 0L) 
+		{
+			char *s=0L;
+			vo = isAPropertyOf(vevent, VCSummaryProp);
+			if (vo) s = fakeCString(vObjectUStringZValue(vo)) ;
+
+			kdDebug() << fname
+				<< ": WARNING: exceptions ignored "
+				   "for multi-day event "
+				<< s
+				<< endl ;
+		}
 	  struct tm thing = dateEntry->getEventEnd();
 	}
 
@@ -808,8 +1269,8 @@ void VCalConduit::doLocalSync()
 	      } else {
 		// we could calculate an end date here, but too lazy right now.
 		// pilot doesn't understand concept of repeat n times.
-		dateEntry->setRepeatFrequency(rFreq);
-		dateEntry->setRepeatForever(); // modify me to fix
+		// repeatForever(dateEntry,rFreq,vevent);
+		repeatUntil(dateEntry,&start,rFreq,rDuration,DailyPeriod);
 	      }
 	    }
 	  }
@@ -847,8 +1308,7 @@ void VCalConduit::doLocalSync()
 		dateEntry->setRepeatFrequency(rFreq);
 		dateEntry->setRepeatForever();
 	      } else {
-		dateEntry->setRepeatFrequency(rFreq);
-		dateEntry->setRepeatForever(); // again, modify to fix
+		repeatUntil(dateEntry,&start,rFreq,rDuration,WeeklyPeriod);
 	      }
 	    }
 	  }
@@ -898,8 +1358,8 @@ void VCalConduit::doLocalSync()
 		dateEntry->setRepeatFrequency(rFreq);
 		dateEntry->setRepeatForever();
 	      } else {
-		dateEntry->setRepeatFrequency(rFreq);
-		dateEntry->setRepeatForever(); // again, modify me to fix
+			repeatUntil(dateEntry,&start,rFreq,rDuration,
+				MonthlyByPosPeriod);
 	      }
 	    }
 	    
@@ -936,8 +1396,8 @@ void VCalConduit::doLocalSync()
 		dateEntry->setRepeatFrequency(rFreq);
 		dateEntry->setRepeatForever();
 	      } else {
-		dateEntry->setRepeatFrequency(rFreq);
-		dateEntry->setRepeatForever(); // again, modify me to fix
+			repeatUntil(dateEntry,&start,rFreq,rDuration,
+				MonthlyByDayPeriod);
 	      }
 	    }
 	  }
@@ -969,8 +1429,8 @@ void VCalConduit::doLocalSync()
 		dateEntry->setRepeatFrequency(rFreq);
 		dateEntry->setRepeatForever();
 	      } else {
-		dateEntry->setRepeatFrequency(rFreq);
-		dateEntry->setRepeatForever(); // again, modify me to fix
+			repeatUntil(dateEntry,&start,rFreq,rDuration,
+				YearlyByDayPeriod);
 	      }
 	    }
 	  }
@@ -1030,7 +1490,8 @@ void VCalConduit::doLocalSync()
 	  deleteStr(s3);
 
 	// write the id we got from writeRecord back to the vObject
-	if (id > 0) {
+	if (id > 0) 
+	{
 	  QString tmpStr;
 	  tmpStr.setNum(id);
 	  vo = isAPropertyOf(vevent, KPilotIdProp);
@@ -1039,13 +1500,25 @@ void VCalConduit::doLocalSync()
 	  vo = isAPropertyOf(vevent, KPilotStatusProp);
 	  tmpStr = "0"; // no longer a modified event.
 	  setVObjectUStringZValue_(vo, fakeUnicode(tmpStr.latin1(), 0));
-
-
-	} else {
+	} 
+	else 
+	{
 	}
       }
     }
   }
+
+#ifdef DEBUG
+	if (debug_level & SYNC_MAJOR)
+	{
+		kdDebug() << fname
+			<< ": Read "
+			<< recordcount
+			<< " records total."
+			<< endl;
+	}
+#endif
+
   // anything that is left on the pilot but that is not found in the
   // vCalendar has to be deleted.  We know this because we have added
   // everything to the vCalendar from the pilot that had the modified
@@ -1062,36 +1535,83 @@ void VCalConduit::doLocalSync()
 	  //
   PilotRecord *rec;
   int index=0, response, insertall=0;
-  QList<int> deletedList;
-  deletedList.setAutoDelete(TRUE);
+  QValueList<int> deletedList;
   
   
   //  Get all entries from Pilot
-  while ((rec = readRecordByIndex(index++)) != 0) {
-    dateEntry = new PilotDateEntry(rec); // convert to date structure
-    vevent = findEntryInCalendar(rec->getID());
-    if (vevent == 0L) {
+  while ((rec = readRecordByIndex(index++)) != 0) 
+  {
+	DEBUGCONDUIT << fname
+		<< ": Got record "
+		<< index-1
+		<< " @"
+		<< (int) rec
+		<< endl;
 
-      if (first == FALSE) {
-		// add event to list of pilot events to delete
-		deletedList.append(new int(rec->getID()));
+    dateEntry = new PilotDateEntry(rec); // convert to date structure
+
+	if (dateEntry)
+	{
+		DEBUGCONDUIT << fname
+			<< ": Created date entry @"
+			<< (int) dateEntry
+			<< " with id "
+			<< rec->getID()
+			<< endl;
+	}
+	else
+	{
+		kdWarning() << __FUNCTION__
+			<< ": No dateentry!"
+			<< endl;
+		continue;
+	}
+
+    vevent = findEntryInCalendar(rec->getID());
+    if (vevent == 0L) 
+    {
+		DEBUGCONDUIT << fname
+			<< ": Entry not found in calendar."
+			<< endl;
+
+
+      if ( !first ) 
+      {
 
 		// In this case we want it entered into the vcalendar
 		if (!LocalOverridesPilot) {
+			DEBUGCONDUIT << fname
+				<< ": !LocalOverridesPilot so updating object."
+				<< endl;
+				
 	   	 	updateVObject(rec);
 		}
-      } else { 
+		else
+		{
+			DEBUGCONDUIT << fname
+				<< ": Scheduling this entry for deletion."
+				<< endl;
+
+		// add event to list of pilot events to delete
+		deletedList.append(rec->getID());
+		}
+      } 
+      else 
+      { 
 	if (insertall == 0) {
-		QString text;
-		text = i18n("This is the first time that "
+		DEBUGCONDUIT << fname
+			<< ": Questioning event disposition."
+			<< endl;
+
+		QString text = i18n("This is the first time that "
 			"you have done a HotSync\n"
 			"with the vCalendar conduit. "
 			"There is an appointment\n"
 			"in the PalmPilot which is not "
 			"in the vCalendar (KOrganizer).\n\n");
-		text += i18n("Appointment: ");
-		text += dateEntry->getDescription();
-		text += i18n("\n\nWhat must be done with this appointment?");
+		text += i18n("Appointment: %1.\n\n"
+			"What must be done with this appointment?")
+			.arg(dateEntry->getDescription());
 
 		response = QMessageBox::information(0, 
 			i18n("KPilot vCalendar Conduit"), 
@@ -1099,24 +1619,26 @@ void VCalConduit::doLocalSync()
 			i18n("&Insert"),i18n("&Delete"), i18n("Insert &All")
 			,0);
 
-		if (debug_level & SYNC_MINOR)
-		{
-			cerr << fname 
-				<< ": Event disposition "
-				<< response
-				<< endl;
-		}
+		DEBUGCONDUIT << fname 
+			<< ": Event disposition "
+			<< response
+			<< endl;
 
 		switch(response) 
 		{
-		case 0:
+		case 1:
+			deletedList.append(rec->getID());
+			break;
+		case 2 :
+			insertall = 1;
 			updateVObject(rec);
 			break;
-		case 1:
-			deletedList.append(new int(rec->getID()));
-			break;
-		case 2:
-			insertall = 1;
+
+		// Default is to insert this single entry
+		// and ask again later.
+		//
+		//
+		default : 
 			updateVObject(rec);
 			break;
 		}
@@ -1132,15 +1654,18 @@ void VCalConduit::doLocalSync()
   
 	if (LocalOverridesPilot)
 	{
+#ifdef DEBUG
 		if (debug_level & SYNC_MAJOR)
 		{
-			cerr << fname << ": Deleting records from pilot."
+			kdDebug() << fname << ": Deleting records from pilot."
 				<< endl;
 		}
+#endif
 
-		for (int *j = deletedList.first(); j; j = deletedList.next()) 
+		QValueList<int>::Iterator it;
+		for (it = deletedList.begin(); it != deletedList.end(); ++it)
 		{
-			rec = readRecordById(*j);
+			rec = readRecordById(*it);
 			rec->setAttrib(~dlpRecAttrDeleted);
 			writeRecord(rec);
 			delete rec;
@@ -1148,16 +1673,20 @@ void VCalConduit::doLocalSync()
 	}
 	else
 	{
-		if (debug_level & SYNC_TEDIOUS)
+#ifdef DEBUG
+		if (debug_level & SYNC_MAJOR)
 		{
-			cerr << fname << ": Leaving records in pilot, "
+			kdDebug() << fname << ": Leaving records in pilot, "
 				"even those not found in organizer."
 				<< endl;
 		}
+#endif
 	}
 
 	deletedList.clear();
   
+	KConfig& config = KPilotLink::getConfig(VCalSetup::VCalGroup);
+	setFirstTime(config,false);
 }
 
 /*
@@ -1166,24 +1695,57 @@ void VCalConduit::doLocalSync()
  */
 VObject* VCalConduit::findEntryInCalendar(unsigned int id)
 {
-  VObjectIterator i;
-  VObject* entry = 0L;
-  VObject* objectID;
-  
-  initPropIterator(&i, fCalendar);
-  
-  // go through all the vobjects in the vcal
-  while (moreIteration(&i)) {
-     entry = nextVObject(&i);
-     objectID = isAPropertyOf(entry, KPilotIdProp);
+	FUNCTIONSETUP;
 
-     if (objectID && (strcmp(vObjectName(entry), VCEventProp) == 0)) {
-       if(strtoul(fakeCString(vObjectUStringZValue(objectID)), 0L, 0) == id) {
-  	 return entry;
-       }
-     }
-  }
-  return 0L;
+	VObjectIterator i;
+	VObject* entry = 0L;
+	VObject* objectID;
+
+	initPropIterator(&i, fCalendar);
+
+	// go through all the vobjects in the vcal
+	while (moreIteration(&i)) 
+	{
+		entry = nextVObject(&i);
+		if (!entry)
+		{
+			kdWarning() << __FUNCTION__
+				<< ": nextVObject returned NULL!"
+				<< endl;
+			break;
+		}
+
+		objectID = isAPropertyOf(entry, KPilotIdProp);
+
+		if (objectID && 
+			(strcmp(vObjectName(entry), VCEventProp) == 0)) 
+		{
+			const char *s = fakeCString(
+				vObjectUStringZValue(objectID));
+			if (!s)
+			{
+				kdWarning() << __FUNCTION__
+					<< ": fakeCString returned NULL!"
+					<< endl;
+				continue;
+			}
+#if 0
+			else
+			{
+				DEBUGCONDUIT << fname
+					<< ": Looking at object with id "
+					<< s
+					<< endl;
+			}
+#endif
+
+			if(strtoul(s, 0L, 0) == id) 
+			{
+				return entry;
+			}
+		}
+	}
+	return 0L;
 }
 
 /* put up teh about / setup dialog. */
@@ -1255,3 +1817,55 @@ int VCalConduit::numFromDay(const QString &day)
   return -1; // something bad happened. :)
 } 
 
+/* virtual */ void VCalConduit::doTest()
+{
+	FUNCTIONSETUP;
+
+	QString message("This is a test. This is only a test.\n"
+		"If this had been a real error message\n"
+		"you would also have had an 18Mb core file\n"
+		"on your hands.");
+
+	KMessageBox::error(0, message, "Testing vCalendar Conduit");
+
+	getCalendar();
+}
+
+
+// $Log: vcal-conduit.cc,v $
+// Revision 1.24.2.1  2001/03/07 17:38:37  adridg
+// Bugfix for #21816 and #20318. No messages changed.
+//
+// Revision 1.24  2001/02/05 19:16:28  adridg
+// Removing calls to exit() from internal functions
+//
+// Revision 1.23  2001/02/02 17:31:57  adridg
+// Reduced debugging message overload
+//
+// Revision 1.22  2001/01/15 14:50:50  bero
+// Fix build
+//
+// Revision 1.21  2001/01/08 22:27:12  adridg
+// Fixed QFile::encodeName stupidity
+//
+// Revision 1.20  2001/01/05 12:06:01  adridg
+// Updated version number, removed VCalConduit::version()
+//
+// Revision 1.19  2001/01/03 00:05:13  adridg
+// Administrative
+//
+// Revision 1.18  2000/12/31 16:44:00  adridg
+// Patched up the debugging stuff again
+//
+// Revision 1.17  2000/12/30 20:27:42  adridg
+// Dag's Patches for Repeating Events
+//
+// Revision 1.16  2000/12/09 12:51:07  adridg
+// New patches
+//
+// Revision 1.15  2000/12/05 07:47:27  adridg
+// New debugging stuff
+//
+// Revision 1.14  2000/11/26 01:41:48  adridg
+// Last of Heiko's patches
+//
