@@ -1,49 +1,64 @@
-// addressWidget.cc
-//
-// Copyright (C) 1998,1999 Dan Pilone
-//
-// This file is distributed under the Gnu General Public Licence (GPL).
-// The GPL should have been included with this file in a file called
-// COPYING. 
+/* addressWidget.cc			KPilot
+**
+** Copyright (C) 1998-2001 by Dan Pilone
+**
+** This file defines the addressWidget, that part of KPilot that
+** displays address records from the Pilot.
+*/
 
-// $Revision: 1.7 $
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, 
+** MA 02139, USA.
+*/
 
-static char *id="$Id: addressWidget.cc,v 1.7 2000/08/28 12:22:03 pilone Exp $";
+/*
+** Bug reports and questions can be sent to adridg@cs.kun.nl
+*/
+static const char *addresswidget_id="$Id: addressWidget.cc,v 1.26.2.1 2001/03/05 23:45:50 adridg Exp $";
 
 
-// REVISION HISTORY 
-//
-// 3.1b9	By Dan Pilone
-// 3.1b10	By Adriaan de Groot: comments added all over the place,
-//		added "all" category.  The same kind of modifications
-//		that were made to memoWidget could also be made right here.
-//
-//		Remaining questions are marked with QADE.
 
-#include <kfiledialog.h>
+#include "options.h"
+
 #include <iostream.h>
-#include <pi-macros.h>
 #include <string.h>
 #include <stdlib.h>
+#include <time.h>
+#include <pi-macros.h>
+#include <pi-dlp.h>
+#include <pi-address.h>
 
 #include <qlist.h>
 #include <qlistbox.h>
 #include <qfile.h>
 #include <qpushbt.h>
 #include <qtextstream.h>
+#include <qlayout.h>
 
 #include <kapp.h>
 #include <kmessagebox.h>
 #include <kdebug.h>
+#include <kfiledialog.h>
 
 #include "strToken.h"
-#include "addressWidget.moc"
-#include "pi-dlp.h"
-#include "pi-address.h"
 #include "kpilot.h"
 #include "addressEditor.h"
 #include "kpilotOptions.h"
-#include "options.h"
+#include "listItems.h"
+
+#include "addressWidget.moc"
 
 
 // This is the size of several (automatic) buffers,
@@ -62,6 +77,7 @@ AddressWidget::AddressWidget(KPilotInstaller* installer, QWidget* parent)
 		parent->geometry().width(), parent->geometry().height());
 	setupWidget();
 	fAddressList.setAutoDelete(true);
+	fTextWidget->setFont(installer->fixed());
 	installer->addComponentPage(this, i18n("Address Book"));
 }
 
@@ -85,6 +101,7 @@ void AddressWidget::setupCategories()
 	{
 		if(strlen(fAddressAppInfo.category.name[i]))
 		{
+#ifdef DEBUG
 			if (debug_level & UI_MINOR)
 			{
 				kdDebug() << fname << 
@@ -94,6 +111,7 @@ void AddressWidget::setupCategories()
 				(int)fAddressAppInfo.category.ID[i] << 
 				endl;
 			}
+#endif
 			fCatList->insertItem(
 				fAddressAppInfo.category.name[i]);
 		}
@@ -114,10 +132,13 @@ int AddressWidget::getAllAddresses(PilotDatabase *addressDB,KConfig *config)
 
 
 
+#ifdef DEBUG
 	if (debug_level & DB_TEDIOUS)
 	{
-		kdDebug() << fname << ": Reading AddressDB...";
+		kdDebug() << fname << ": Reading AddressDB..."
+			<< endl;
 	}
+#endif
 
 	while((pilotRec = addressDB->readRecordByIndex(currentRecord)) != 0L)
 	{
@@ -127,7 +148,7 @@ int AddressWidget::getAllAddresses(PilotDatabase *addressDB,KConfig *config)
 			address = new PilotAddress(pilotRec);
 			if (address == 0L)
 			{
-				kdDebug() << fname << ": Couldn't allocate "
+				kdWarning() << __FUNCTION__ << ": Couldn't allocate "
 					"record " << currentRecord++ <<
 					endl;
 				break;
@@ -136,22 +157,21 @@ int AddressWidget::getAllAddresses(PilotDatabase *addressDB,KConfig *config)
 		}
 		delete pilotRec;
 		currentRecord++;
-		// Print out a . after every 16 records (whenever
-		// the low four bits of the record number are 0)
-		//
-		//
-		if ((debug_level & DB_TEDIOUS) && !(currentRecord & 0xf))
-		{
-			kdDebug() << '.' ;
-		}
 	}
 
+#ifdef DEBUG
 	if (debug_level & DB_TEDIOUS)
 	{
-		kdDebug() << '(' << currentRecord << " records)" << endl;
+		kdDebug() << fname 
+			<< ": Total " << currentRecord << " records" << endl;
 	}
+#endif
 
 	return currentRecord;
+#ifdef DEBUG
+	/* NOTREACHED */
+	(void) addresswidget_id;
+#endif
 }
 
 void
@@ -166,9 +186,6 @@ AddressWidget::initialize()
 
 	KConfig* config = KGlobal::config();
 
-	fCatList->clear();
-	fCatList->insertItem(i18n("All"));
-
 	fAddressList.clear();
 
 	if(addressDB->isDBOpen())
@@ -176,14 +193,16 @@ AddressWidget::initialize()
 		appLen = addressDB->readAppBlock(buffer, BUFFERSIZE);
 		unpack_AddressAppInfo(&fAddressAppInfo, buffer, appLen);
 
-		setupCategories();
+		populateCategories(fCatList,&fAddressAppInfo.category);
 		getAllAddresses(addressDB,config);
 
 		KPilotLink::getPilotLink()->closeDatabase(addressDB);
 	}
 	else
 	{
-		kdDebug() << fname << ": Could not open local AddressDB" << endl;
+		populateCategories(fCatList,0L);
+		kdWarning() << __FUNCTION__ 
+			<< ": Could not open local AddressDB" << endl;
 	}
 
 
@@ -219,38 +238,50 @@ AddressWidget::setupWidget()
 {
 	FUNCTIONSETUP;
 
+	QLabel *label;
+	QGridLayout *grid=new QGridLayout(this,6,4,SPACING);
+
 	fCatList = new QComboBox(this);
-	fCatList->move(110, 25);
+	grid->addWidget(fCatList,0,1);
 	connect(fCatList, SIGNAL(activated(int)), 
 		this, SLOT(slotSetCategory(int)));
-	QLabel* label = new QLabel(i18n("Addresses:"), this);
-	label->move(10, 30);
+
+	label = new QLabel(i18n("Category:"), this);
+	label->setBuddy(fCatList);
+	grid->addWidget(label,0,0);
+
 	fListBox = new QListBox(this);
-	fListBox->setGeometry(10, 60, 200, 150);
+	grid->addMultiCellWidget(fListBox,1,1,0,1);
 	connect(fListBox, SIGNAL(highlighted(int)), 
 		this, SLOT(slotShowAddress(int)));
 	connect(fListBox, SIGNAL(selected(int)), 
 		this, SLOT(slotEditRecord()));
+
 	label = new QLabel(i18n("Address Info:"), this);
-	label->move(290, 0);
+	grid->addWidget(label,0,2);
+
 	fTextWidget = new QMultiLineEdit(this, "textArea");
-	fTextWidget->setGeometry(230, 30, 260, 290);
-	fTextWidget->setFont(QFont("fixed", 10));
 	fTextWidget->setReadOnly(TRUE);
-	QPushButton* button = new QPushButton(i18n("Edit Record"), this);
-	button->move(10, 220);
-	connect(button, SIGNAL(clicked()), this, SLOT(slotEditRecord()));
+	grid->addMultiCellWidget(fTextWidget,1,4,2,2);
+
+	QPushButton* button ;
+	
+	fEditButton = new QPushButton(i18n("Edit Record"), this);
+	grid->addWidget(fEditButton,2,0);
+	connect(fEditButton, SIGNAL(clicked()), 
+		this, SLOT(slotEditRecord()));
 	button = new QPushButton(i18n("New Record"), this);
-	button->move(110, 220);
+	grid->addWidget(button,2,1);
 	connect(button, SIGNAL(clicked()), this, SLOT(slotCreateNewRecord()));
-	button = new QPushButton(i18n("Delete Record"), this);
-	button->move(60, 250);
-	connect(button, SIGNAL(clicked()), this, SLOT(slotDeleteRecord()));
+	fDeleteButton = new QPushButton(i18n("Delete Record"), this);
+	grid->addWidget(fDeleteButton,3,0);
+	connect(fDeleteButton, SIGNAL(clicked()), 
+		this, SLOT(slotDeleteRecord()));
 	button = new QPushButton(i18n("Import List"), this);
-	button->move(10, 290);
+	grid->addWidget(button,4,0);
 	connect(button, SIGNAL(clicked()), this, SLOT(slotImportAddressList()));
 	button = new QPushButton(i18n("Export List"), this);
-	button->move(110, 290);
+	grid->addWidget(button,4,1);
 	connect(button, SIGNAL(clicked()), this, SLOT(slotExportAddressList()));
 }
 
@@ -259,68 +290,31 @@ AddressWidget::updateWidget()
 {
 	FUNCTIONSETUP;
 
-	int addressDisplayMode = KPilotOptionsAddress::getDisplayMode();
+	int addressDisplayMode = KPilotOptionsAddress::getDisplayMode(
+		KPilotLink::getConfig());
 	int listIndex = 0;
 	int currentEntry = 0;
 
+#ifdef DEBUG
 	if (debug_level & UI_MINOR)
 	{
 		kdDebug() << fname << ": Display Mode=" << 
-			addressDisplayMode << '\n' ;
+			addressDisplayMode << endl ;
 	}
+#endif
 
-	if (fCatList->currentItem()==-1)
-	{
-		kdDebug() << fname <<
-			": No category selected in address book.\n";
-		return;
-	}
-	// Semantics of currentCatID are:
-	//
-	// >=0 is a specific category based on the text -> category number
-	//      mapping defined by the Pilot,
-	// ==-1 means "All" category selected.
-	//
-	//
-	int currentCatID = 0;
-
-	if (fCatList->currentItem()==0)
-	{
-		currentCatID=-1;
-		if (debug_level & UI_MINOR)
-		{
-			kdDebug() << fname << 
-				": Category all selected.\n";
-		}
-	}
-	else
-	{
-		// If a category is deleted after others 
-		// have been added, none of the
-		// category numbers are changed.  
-		// So we need to find the category number
-		// for this category.
-		while(strcmp(fAddressAppInfo.category.name[currentCatID], 
-			fCatList->text(fCatList->currentItem()).latin1()) &&
-			(currentCatID < fCatList->count()))
-		{
-			currentCatID++;
-		}
-
-		if (currentCatID >= fCatList->count())
-		{
-			kdDebug() << fname << 
-				": Can't find selected category!\n";
-			currentCatID=-1; // All category
-		}
-	}
+	int currentCatID = findSelectedCategory(fCatList,
+		&(fAddressAppInfo.category));
 
 	fListBox->clear();
 	fAddressList.first();
+#ifdef DEBUG
 	if (debug_level & UI_TEDIOUS)
 	{
-		kdDebug() << fname << ": Adding records...";
+		kdDebug() << fname << ": Adding records..."
+			<< endl;
 	}
+#endif
 
 	while(fAddressList.current())
 	{
@@ -338,28 +332,29 @@ AddressWidget::updateWidget()
 				addressDisplayMode);
 			if (title)
 			{
-				fListBox->insertItem(title, -1);
-				fLookupTable[currentEntry++] = listIndex;
+				PilotListItem *p = new PilotListItem(title,
+					listIndex,
+					fAddressList.current());
+				fListBox->insertItem(p);
 			}
 		}
 		listIndex++;
 		fAddressList.next();
-		// Print a . every 16 records (when the low 4
-		// bits of the index are 0)
-		//
-		//
-		if ((debug_level & UI_TEDIOUS) && !(listIndex & 0xf))
-		{
-			kdDebug() << '.' ;
-		}
 	}
 	fTextWidget->clear();
+#ifdef DEBUG
 	if (debug_level & UI_TEDIOUS)
 	{
-		kdDebug() << '(' << listIndex << " records)" << endl;
+		kdDebug() << fname
+			<< ": " << listIndex << " records" << endl;
 	}
+#endif
+
+	slotUpdateButtons();
 }
 
+
+
 char *AddressWidget::createTitle(PilotAddress *address,int displayMode)
 {
 	FUNCTIONSETUP;
@@ -368,7 +363,8 @@ char *AddressWidget::createTitle(PilotAddress *address,int displayMode)
 	char *title = new char[255];
 	if (title == 0L)
 	{
-		kdDebug() << fname << ": Cannot allocate title string." << endl;
+		kdWarning() << __FUNCTION__ 
+			<< ": Cannot allocate title string." << endl;
 		return 0L;
 	}
 
@@ -417,12 +413,32 @@ char *AddressWidget::createTitle(PilotAddress *address,int displayMode)
 
 	if(title[0] == 0L) // One last try
 	{
-		strcpy(title, fAddressList.current()->getField(entryCompany));
+		if (fAddressList.current()->getField(entryCompany))
+		{
+			strcpy(title, fAddressList.current()->
+				getField(entryCompany));
+		}
+		if (title[0] == 0)
+		{
+			QString t = i18n("[unknown]");
+			strcpy(title,t.local8Bit());
+		}
 	}
 
 	return title;
 }
 
+
+/* slot */ void AddressWidget::slotUpdateButtons()
+{
+	FUNCTIONSETUP;
+
+	bool enabled = (fListBox->currentItem() != -1);
+
+	fEditButton->setEnabled(enabled);
+	fDeleteButton->setEnabled(enabled);
+}
+
 void
 AddressWidget::slotSetCategory(int)
 {
@@ -439,17 +455,20 @@ AddressWidget::slotEditRecord()
     int item = fListBox->currentItem();
     if(item == -1)
       return;
-    item = fLookupTable[item];
-    if(fAddressList.at(item)->id() == 0x0)
+
+	PilotListItem *p = (PilotListItem *)fListBox->item(item);
+	PilotAddress *selectedRecord = (PilotAddress *)p->rec();
+
+    if(selectedRecord->id() == 0x0)
       {
 	KMessageBox::error(0L, 
-		       i18n("Cannot edit new records until \r\n"
-			    "Hot-Synced with pilot."),
+		       i18n("Cannot edit new records until\n"
+			    "Hot-Synced with Pilot."),
 		       i18n("Hot-Sync Required"));
 			 
 	return;
       }
-    AddressEditor* editor = new AddressEditor(fAddressList.at(item));
+    AddressEditor* editor = new AddressEditor(selectedRecord,this);
     connect(editor, SIGNAL(recordChangeComplete(PilotAddress*)),
 	    this, SLOT(slotUpdateRecord(PilotAddress*)));
     editor->show();
@@ -460,6 +479,22 @@ AddressWidget::slotCreateNewRecord()
 {
 	FUNCTIONSETUP;
 
+	// Response to bug 18072: Don't even try to
+	// add records to an empty or unopened database,
+	// since we don't have the DBInfo stuff to deal with it.
+	//
+	//
+	PilotDatabase *myDB= KPilotLink::getPilotLink()->
+		openLocalDatabase("AddressDB");
+	if (!myDB || !myDB->isDBOpen())
+	{
+		KMessageBox::sorry(this,
+			i18n("You can't add addresses to the address book\n"
+			     "until you have done a HotSync at least once\n"
+			     "to retrieve the database layout from your Palm."),
+			i18n("Can't add new address"));
+	}
+
   AddressEditor* editor = new AddressEditor(0L);
   connect(editor, SIGNAL(recordChangeComplete(PilotAddress*)),
 	  this, SLOT(slotAddRecord(PilotAddress*)));
@@ -471,19 +506,20 @@ AddressWidget::slotAddRecord(PilotAddress* address)
 {
 	FUNCTIONSETUP;
 
-  int currentCatID = 0;
+	int currentCatID = findSelectedCategory(fCatList,
+		&(fAddressAppInfo.category),true);
+
 
-  // If a category is deleted after others have been added, none of the
-  // category numbers are changed.  So we need to find the category number
-  // for this category.
-  while(strcmp(fAddressAppInfo.category.name[currentCatID], 
-	       fCatList->text(fCatList->currentItem()).latin1()))
-    currentCatID++;
   address->setCat(currentCatID);
   fAddressList.append(address);
   writeAddress(address);
   updateWidget();
-  fListBox->setCurrentItem(fAddressList.count() - 1); // Show the newest one
+	// k holds the item number of the address just added.
+	//
+	//
+	int k = fListBox->count() - 1 ;
+	fListBox->setCurrentItem(k); // Show the newest one
+	fListBox->setBottomItem(k);
 }
 
 void
@@ -495,6 +531,8 @@ AddressWidget::slotUpdateRecord(PilotAddress* address)
   int currentRecord = fListBox->currentItem();
   updateWidget();
   fListBox->setCurrentItem(currentRecord);
+
+	emit(recordChanged(address));
 }
 
 void
@@ -505,20 +543,23 @@ AddressWidget::slotDeleteRecord()
   int item = fListBox->currentItem();
   if(item == -1)
     return;
-  item = (int)fLookupTable[item];
-  if(fAddressList.at(item)->id() == 0x0)
+	PilotListItem * p = (PilotListItem *)fListBox->item(item);
+	PilotAddress * address = (PilotAddress *)p->rec();
+
+  if(address->id() == 0x0)
     {
-      KMessageBox::error(0L, 
-			 i18n("Cannot delete new records until \r\n Hot-Synced with pilot."), 
+      KMessageBox::error(this, 
+			 i18n("Cannot delete new records until\n"
+			      "Hot-Synced with pilot."), 
 			 i18n("Hot-Sync Required"));
       return;
     }
-  if(KMessageBox::questionYesNo(0L, i18n("Delete currently selected record?"),
+  if(KMessageBox::questionYesNo(this, i18n("Delete currently selected record?"),
 				i18n("Delete Record?")) == KMessageBox::No)
     return;
-  PilotAddress* address = fAddressList.at(item);
   address->setAttrib(address->getAttrib() | dlpRecAttrDeleted);
   writeAddress(address);
+	emit(recordChanged(address));
   initialize();
 }
 
@@ -528,25 +569,38 @@ AddressWidget::slotShowAddress(int which)
     	FUNCTIONSETUP;
 
     char text[BUFFERSIZE];
-    PilotAddress* theAdd = fAddressList.at(fLookupTable[which]);
+	PilotListItem *p = (PilotListItem *)fListBox->item(which);
+	PilotAddress* theAdd = (PilotAddress *)p->rec();
     int i;
     int pad;
     text[0] = 0L;
 
+	int showWhichPhone = theAdd->getShownPhone();
+
     for(i = 0; i < 19; i++)
 	{
 	  if ((i > 2) && (i < 8))
 	    {
 	      strcat(text, fAddressAppInfo.phoneLabels[theAdd->getPhoneLabelIndex(i-3)]);
-	      pad = 10 -
+	      pad = PhoneNumberLength -
 	      strlen(fAddressAppInfo.phoneLabels[theAdd->getPhoneLabelIndex(i-3)]);
+		if (showWhichPhone == i-3)
+		{
+			strcat(text," []");
+			pad -= 3;
+		}
 	    }
 	  else
 	    {
 	      strcat(text, fAddressAppInfo.labels[i]);
-	      pad = 10 - strlen(fAddressAppInfo.labels[i]);
+	      pad = PhoneNumberLength - strlen(fAddressAppInfo.labels[i]);
 	    }
  	strcat(text, ": ");
+	if (i == 18)
+	{
+		strcat(text,"\n");
+		pad=0;
+	}
 	while(pad > 0)
 	    {
 	    strcat(text, " ");
@@ -558,6 +612,9 @@ AddressWidget::slotShowAddress(int which)
 	    strcat(text, "\n"); // So there's no return after note, it fits nicer.
 	}
     fTextWidget->setText(text);
+
+
+	slotUpdateButtons();
     }
 
 void
@@ -579,12 +636,9 @@ AddressWidget::slotImportAddressList()
     QFile inFile(fileName);
     if(inFile.open(IO_ReadOnly) == FALSE)
  	{
-	if (debug_level)
-	{
-		kdDebug() << fname << ": Can't open file "
+		kdWarning() << __FUNCTION__ << ": Can't open file "
 			<< fileName
 			<< " read-only.\n";
-	}
  	// show error!
 	KMessageBox::error(0L,
 			   i18n("Can't open the address file for import:")+fileName,
@@ -603,12 +657,14 @@ AddressWidget::slotImportAddressList()
 	delim[0] = importFormat[3];
 	delim[1] = 0L;
 
+#ifdef DEBUG
 	if (debug_level & SYNC_MINOR)
 	{
 		kdDebug() << fname << ": Input format is " << importFormat <<
 			endl;
 		kdDebug() << fname << ": Delimiter is " << delim << endl;
 	}
+#endif
 
     while(inputStream.eof() == false)
 	{
@@ -619,15 +675,17 @@ AddressWidget::slotImportAddressList()
 	const char* nextToken = formatTokenizer->getNextField();
 
  	nextRecord = inputStream.readLine();
+	nextRecord = nextRecord.stripWhiteSpace();
+ 	if(inputStream.eof() || nextRecord.isNull())
+	{
+ 	    break;
+	}
+#ifdef DEBUG
 	if (debug_level & SYNC_TEDIOUS)
 	{
 		kdDebug() << fname << ": Read line " << nextRecord;
 	}
-
- 	if(inputStream.eof() || (nextRecord == ""))
-	{
- 	    break;
-	}
+#endif
 
 	dataTokenizer = new StrTokenizer(nextRecord.latin1(), delim);
 	strcpy(nextField, dataTokenizer->getNextField());
@@ -714,6 +772,7 @@ AddressWidget::setFieldBySymbol(PilotAddress* rec, const char* symbol, const cha
 	//     else if(strcasecmp(symbol, "%NO") == 0)
 	// 	rec->setField(entryNote, text);
 
+#ifdef DEBUG
 	if ((debug_level & SYNC_MINOR) && rc)
 	{
 		kdDebug() << fname << ": Unknown field "
@@ -727,6 +786,7 @@ AddressWidget::setFieldBySymbol(PilotAddress* rec, const char* symbol, const cha
 			<< text
 			<< endl;
 	}
+#endif
 }
 
 char*
@@ -800,7 +860,7 @@ AddressWidget::writeAddress(PilotAddress* which,PilotDatabase *addressDB)
 	//
 	if (!myDB->isDBOpen())
 	{
-		kdDebug() << fname << ": Address database is not open.\n";
+		DEBUGKPILOT << fname << ": Address database is not open.\n";
 		return;
 	}
 
@@ -836,7 +896,12 @@ AddressWidget::slotExportAddressList()
     QFile outFile(fileName);
     if(outFile.open(IO_WriteOnly | IO_Truncate) == FALSE)
  	{
- 	// show error!
+		QString message = i18n("Can't open the "
+			"address file %1 for export").arg(fileName);
+		kdWarning() << __FUNCTION__ << ": " << message << endl;
+		KMessageBox::error(0L,
+			i18n("Export Address Error"),
+			message);
  	return;
  	}
     QTextStream outStream(&outFile);
@@ -860,3 +925,63 @@ AddressWidget::slotExportAddressList()
 	}
     outFile.close();
     }
+
+// $Log: addressWidget.cc,v $
+// Revision 1.26.2.1  2001/03/05 23:45:50  adridg
+// Backport of bugfix for #21392
+//
+// Revision 1.26  2001/02/08 08:13:44  habenich
+// exchanged the common identifier "id" with source unique <sourcename>_id for --enable-final build
+//
+// Revision 1.25  2001/02/07 14:21:37  brianj
+// Changed all include definitions for libpisock headers
+// to use include path, which is defined in Makefile.
+//
+// Revision 1.24  2001/02/05 20:55:07  adridg
+// Fixed copyright headers for source releases. No code changed
+//
+// Revision 1.23  2001/01/04 22:19:37  adridg
+// Stuff for Chris and Bug 18072
+//
+// Revision 1.22  2000/12/31 16:44:00  adridg
+// Patched up the debugging stuff again
+//
+// Revision 1.21  2000/12/21 00:42:50  adridg
+// Mostly debugging changes -- added FUNCTIONSETUP and more #ifdefs. KPilot should now compile -DNDEBUG or with DEBUG undefined
+//
+// Revision 1.20  2000/12/13 16:59:27  adridg
+// Removed dead code, i18n stupidities
+//
+// Revision 1.19  2000/12/05 07:43:28  adridg
+// Fixed UI weirdness?
+//
+// Revision 1.18  2000/11/26 01:44:54  adridg
+// Last of Heiko's patches
+//
+// Revision 1.17  2000/11/17 08:37:58  adridg
+// Minor
+//
+// Revision 1.16  2000/11/14 23:02:28  adridg
+// Layout and i18n issues
+//
+// Revision 1.15  2000/11/14 06:33:22  adridg
+// Using Qt Layout code now
+//
+// Revision 1.14  2000/11/10 16:11:21  adridg
+// Re-patched array overflows in category boxes
+//
+// Revision 1.13  2000/11/10 08:33:24  adridg
+// General administrative
+//
+// Revision 1.12  2000/10/29 22:16:39  adridg
+// Misc fixes
+//
+// Revision 1.11  2000/10/29 14:12:37  habenich
+// removed compiler warnings
+//
+// Revision 1.10  2000/10/26 10:10:09  adridg
+// Many fixes
+//
+// Revision 1.9  2000/10/25 12:19:44  adridg
+// Conflicts resolved, pilot-link-0.0.0 bug workaround
+//
