@@ -1,19 +1,38 @@
-/* *******************************************************
-   KPilot - Hot-Sync Software for Unix.
-   Copyright 1998 by Dan Pilone
-   This code is released under the GNU PUBLIC LICENSE.
-   Please see the file 'COPYING' included in the KPilot
-   distribution.
-   *******************************************************
- */
+/* addressWidget.h			KPilot
+**
+** Copyright (C) 1998-2001 by Dan Pilone
+**
+** This file defines the address-viewing widget used in KPilot
+** to display the Pilot's address records.
+*/
 
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, 
+** MA 02139, USA.
+*/
+
+/*
+** Bug reports and questions can be sent to adridg@cs.kun.nl
+*/
 #ifndef __ADDRESS_WIDGET_H
 #define __ADDRESS_WIDGET_H
 
+class QMultiLineEdit;
+class QListBox;
+class QComboBox;
 #include "pilotComponent.h"
-#include <qmlined.h>
-#include <qlistbox.h>
-#include <qcombo.h>
 #include "pilotAddress.h"
 #include "kpilotlink.h"
 
@@ -42,6 +61,11 @@ class AddressWidget : public PilotComponent
       void slotCreateNewRecord();
       void slotDeleteRecord(); // Deletes the currently selected record
 
+	void slotUpdateButtons();	// Enable/disable buttons
+
+signals:
+	void recordChanged(PilotAddress *);
+
     protected:
       char* getFieldBySymbol(PilotAddress* rec, const char* symbol);
       void setFieldBySymbol(PilotAddress* rec, const char* symbol, const char* text);
@@ -74,8 +98,20 @@ private:
       QMultiLineEdit*       fTextWidget;
       struct AddressAppInfo fAddressAppInfo;
       QList<PilotAddress>   fAddressList;
-      unsigned int          fLookupTable[1000];
       QListBox*             fListBox;
+	QPushButton	*fEditButton,*fDeleteButton;
+
+public:
+	typedef enum { PhoneNumberLength=16 } Constants ;
     };
 
 #endif
+
+
+// $Log: addressWidget.h,v $
+// Revision 1.9.2.1  2001/03/05 23:45:50  adridg
+// Backport of bugfix for #21392
+//
+// Revision 1.9  2001/02/06 08:05:19  adridg
+// Fixed copyright notices, added CVS log, added surrounding #ifdefs. No code changes.
+//
