@@ -1,50 +1,50 @@
-// baseConduit.cc
-//
-// Copyright (C) 1998,1999 Dan Pilone
-//
-// This file is distributed under the Gnu General Public Licence (GPL).
-// The GPL should have been included with this file in a file called
-// COPYING.
-//
-//
-// This is baseConduit.cc for KDE 2 / KPilot 4
- 
- 
- 
-// REVISION HISTORY
-//
-// 3.1b9        By Dan Pilone
-// 3.1.14	By Adriaan de Groot. Added addSyncLogMessage(). Some
-//		code cleanup.
-// 4.0.0	By Adriaan de Groot. Stripped out includes. Moved
-//		everything to QString. Ported to KDE2.
+/* baseConduit.cc			KPilot
+**
+** Copyright (C) 1998-2001 by Dan Pilone
+**
+** This file defines the base class for all conduits, including
+** various utility functions they all need.
+*/
 
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, 
+** MA 02139, USA.
+*/
+
+/*
+** Bug reports and questions can be sent to adridg@cs.kun.nl
+*/
 #include "options.h"
 
-#ifdef KDE2
 #include <stream.h>
 #include <fcntl.h>
 #include <ctype.h>
 #include <unistd.h>
 #include <qpixmap.h>
+#include <kglobal.h>
+#include <kiconloader.h>
 #include <ksock.h>
+#include <kconfig.h>
+#include <kdebug.h>
+
+#include "kpilotlink.h"
 
 #include "baseConduit.moc"
 #include "statusMessages.h"
-#else
-#include <iostream.h>
-#include <qdir.h> // Just to avoid namespace problems in old Qt versions
-#include <ksock.h>
-#include <unistd.h>
-#include <fcntl.h>
 
-#include "baseConduit.moc"
-#include "statusMessages.h"
-#include "pilotRecord.h"
-#include "kpilot.h"
-#endif
-
-static const char *id="$Id: baseConduit.cc,v 1.4 2000/07/24 04:10:00 pilone Exp $";
+static const char *baseconduit_id="$Id: baseConduit.cc,v 1.15 2001/02/08 08:13:44 habenich Exp $";
 
 BaseConduit::BaseConduit(eConduitMode mode)
   : QObject(), fMode(mode), fDaemonSocket(0L)//, fReportData(false)
@@ -54,18 +54,20 @@ BaseConduit::BaseConduit(eConduitMode mode)
 	if((mode == BaseConduit::HotSync) || 
 		(mode == BaseConduit::Backup))
 	{
+#ifdef DEBUG
 		if (debug_level & SYNC_MINOR)
 		{
-			cerr << fname
+			kdDebug() << fname
 				<< ": Creating kpilotlink connection"
 				<< endl;
 		}
+#endif
 
 		// KPilotDaemon Status Socket
 		fDaemonSocket = new KSocket("localhost", KPILOTLINK_PORT); 
 		if (fDaemonSocket == 0L)
 		{
-			cerr << fname
+			kdError() << __FUNCTION__
 				<< ": Can't create socket"
 				<< endl ;
 			fMode=BaseConduit::Error;
@@ -73,7 +75,7 @@ BaseConduit::BaseConduit(eConduitMode mode)
 		}
 		if (fDaemonSocket->socket()<0)
 		{
-			cerr << fname
+			kdError() << __FUNCTION__
 				<< ": Socket is not connected"
 				<< endl ;
 			fMode=BaseConduit::Error;
@@ -92,16 +94,25 @@ BaseConduit::~BaseConduit()
 	}
 }
 
+int BaseConduit::getDebugLevel(KConfig& c)
+{
+	return KPilotLink::getDebugLevel(c);
+	/* NOTREACHED */
+	(void) baseconduit_id;
+}
+
 // For a description of the protocol used to
 // send log messages, see the other end of the
 // link in kpilotlink.cc.
 //
 //
+#define SYNC_MSG_SIZE	(64)
+
 int BaseConduit::addSyncLogMessage(const char *s)
 {
 	FUNCTIONSETUP;
 
-	char buffer[64];
+	char buffer[SYNC_MSG_SIZE];
 	const char *check_s;
 	char *bufp;
 	int l,r;
@@ -111,7 +122,7 @@ int BaseConduit::addSyncLogMessage(const char *s)
 	//
 	if (s == 0L) return 0;
 	l=strlen(s);
-	if (l>30) return 0;
+	if (l>(SYNC_MSG_SIZE / 2)) return 0;
 	check_s=s;
 	while (*check_s)
 	{
@@ -122,7 +133,7 @@ int BaseConduit::addSyncLogMessage(const char *s)
 		check_s++;
 	}
 
-	memset(buffer,0,64);
+	memset(buffer,0,SYNC_MSG_SIZE);
 	// Make l a multiple of sizeof(int)
 	//
 	//
@@ -145,29 +156,41 @@ int BaseConduit::addSyncLogMessage(const char *s)
 
 	return 1; // (r == (2*sizeof(int)+l));
 }
-	
+
 
 // Returns 0L if no more modified records.  User must delete
 // the returned record when finished with it.
 PilotRecord* 
 BaseConduit::readNextModifiedRecord()
 {
+	FUNCTIONSETUP;
+
   int result = 0;
 
-  write(fDaemonSocket->socket(), &CStatusMessages::NEXT_MODIFIED_REC, sizeof(int));
+  CStatusMessages::write(fDaemonSocket->socket(), 
+  	CStatusMessages::NEXT_MODIFIED_REC);
   if(read(fDaemonSocket->socket(), &result, sizeof(int)))
     {
       if(result == CStatusMessages::NO_SUCH_RECORD)
 	{
-	  cout << "BaseConduit::nextModifiedRecord() - Got NO_SUCH_RECORD" << endl;
+#ifdef DEBUG
+		if (debug_level & SYNC_TEDIOUS)
+		{
+			kdDebug() << fname
+				<< ": Got NO_SUCH_RECORD" 
+				<< endl;
+		}
+#endif
 	  return 0L;
 	}
       else
-	return getRecord(fDaemonSocket);
+	{
+		return getRecord(fDaemonSocket);
+	}
     }
   else
     {
-      cout << "CBaseConduit::nextModifiedRecord() - Failure on read??" << endl;
+      kdWarning() << __FUNCTION__ << ": Failure on read" << endl;
       return 0L;
     }
 }
@@ -178,7 +201,8 @@ PilotRecord*
 BaseConduit::readNextRecordInCategory(int category)
 {
   int result = 0;
-  write(fDaemonSocket->socket(), &CStatusMessages::NEXT_REC_IN_CAT, sizeof(int));
+	CStatusMessages::write(fDaemonSocket->socket(), 
+		CStatusMessages::NEXT_REC_IN_CAT);
   write(fDaemonSocket->socket(), &category, sizeof(int));
   read(fDaemonSocket->socket(), &result, sizeof(int));
   if(result == CStatusMessages::NO_SUCH_RECORD)
@@ -193,7 +217,8 @@ BaseConduit::readRecordById(recordid_t id)
 {
   int result = 0;
 
-  write(fDaemonSocket->socket(), &CStatusMessages::READ_REC_BY_ID, sizeof(int));
+  CStatusMessages::write(fDaemonSocket->socket(), 
+  	CStatusMessages::READ_REC_BY_ID);
   write(fDaemonSocket->socket(), &id, sizeof(recordid_t));
   read(fDaemonSocket->socket(), &result, sizeof(int));
   if(result == CStatusMessages::NO_SUCH_RECORD)
@@ -208,7 +233,8 @@ BaseConduit::readRecordByIndex(int index)
 {
   int result = 0;
 
-  write(fDaemonSocket->socket(), &CStatusMessages::READ_REC_BY_INDEX, sizeof(int));
+  CStatusMessages::write(fDaemonSocket->socket(), 
+  	CStatusMessages::READ_REC_BY_INDEX);
   write(fDaemonSocket->socket(), &index, sizeof(int));
   read(fDaemonSocket->socket(), &result, sizeof(int));
   if(result == CStatusMessages::NO_SUCH_RECORD)
@@ -225,7 +251,8 @@ BaseConduit::writeRecord(PilotRecord* rec)
   int result = 0;
   recordid_t id = 0;
 
-  write(fDaemonSocket->socket(), &CStatusMessages::WRITE_RECORD, sizeof(int));
+  CStatusMessages::write(fDaemonSocket->socket(), 
+  	CStatusMessages::WRITE_RECORD);
   writeRecord(fDaemonSocket, rec);
   read(fDaemonSocket->socket(), &result, sizeof(int));
   read(fDaemonSocket->socket(), &id, sizeof(recordid_t));
@@ -242,7 +269,8 @@ BaseConduit::writeRecord(KSocket* theSocket, PilotRecord* rec)
   recordid_t uid = rec->getID();
   char* data = rec->getData();
   
-  write(theSocket->socket(), &CStatusMessages::REC_DATA, sizeof(int));
+  CStatusMessages::write(theSocket->socket(), 
+  	CStatusMessages::REC_DATA);
   write(theSocket->socket(), &len, sizeof(int));
   write(theSocket->socket(), &attrib, sizeof(int));
   write(theSocket->socket(), &cat, sizeof(int));
@@ -255,6 +283,8 @@ BaseConduit::writeRecord(KSocket* theSocket, PilotRecord* rec)
 PilotRecord*
 BaseConduit::getRecord(KSocket* in)
 {
+	FUNCTIONSETUP;
+
   int len, attrib, cat;
   recordid_t uid;
   char* data;
@@ -268,19 +298,84 @@ BaseConduit::getRecord(KSocket* in)
   read(in->socket(), data, len);
   newRecord = new PilotRecord((void*)data, len, attrib, cat, uid);
   delete [] data;
-  cout << "Read:" << endl;
-  cout << "\tlen: " << len << endl;
-  cout << "\tattrib: " << hex<< attrib << endl;
-  cout << "\tcat: " << cat << endl;
-  cout << "\tuid: " << hex << uid << endl;
+#ifdef DEBUG
+	if (debug_level & SYNC_TEDIOUS)
+	{
+  		kdDebug() << fname
+			<< ": Read"
+			<< " len=" << len
+			<< " att=" << attrib
+			<< " cat=" << cat 
+			<< " UID=" << uid
+			<< endl;
+	}
+#endif
   return newRecord;
 }
 
 
 #include "kpilot_conduit.xpm"
 
-/* virtual */ QPixmap *BaseConduit::icon() const
+/* virtual */ QPixmap BaseConduit::icon() const
 {
-	return new QPixmap((const char **)kpilot_conduit);
+	FUNCTIONSETUP;
+
+	KGlobal::iconLoader()->addAppDir("kpilot");
+	QPixmap p = KGlobal::iconLoader()->loadIcon("conduit",
+		KIcon::Toolbar,0,KIcon::DefaultState,0,true);
+	if (p.isNull())
+	{
+		kdWarning() << __FUNCTION__ 
+			<< ": Conduit icon not found."
+			<< endl;
+		p = QPixmap((const char **)kpilot_conduit);
+	}
+	return p;
 }
 
+
+bool BaseConduit::getFirstTime(KConfig& c)
+{
+	bool b = c.readBoolEntry("FirstTime",true);
+	if (b) return b;
+
+	KConfigGroupSaver g(&c,QString::null);
+	b = c.readBoolEntry("ForceFirst",false);
+
+	return b;
+}
+
+void BaseConduit::setFirstTime(KConfig& c,bool b)
+{
+	c.writeEntry("FirstTime",b);
+}
+
+
+// $Log: baseConduit.cc,v $
+// Revision 1.15  2001/02/08 08:13:44  habenich
+// exchanged the common identifier "id" with source unique <sourcename>_id for --enable-final build
+//
+// Revision 1.14  2001/02/05 20:55:07  adridg
+// Fixed copyright headers for source releases. No code changed
+//
+// Revision 1.13  2000/12/31 16:44:00  adridg
+// Patched up the debugging stuff again
+//
+// Revision 1.12  2000/12/21 00:42:50  adridg
+// Mostly debugging changes -- added EFUNCTIONSETUP and more #ifdefs. KPilot should now compile -DNDEBUG or with DEBUG undefined
+//
+// Revision 1.11  2000/12/06 22:22:51  adridg
+// Debug updates
+//
+// Revision 1.10  2000/11/27 02:20:20  adridg
+// Internal cleanup
+//
+// Revision 1.9  2000/11/17 08:31:59  adridg
+// Minor changes
+//
+// Revision 1.8  2000/11/14 23:01:51  adridg
+// Proper first-time handling
+//
+// Revision 1.7  2000/11/14 06:32:26  adridg
+// Ditched KDE1 stuff
+//
