@@ -1,22 +1,30 @@
-// baseConduit.h
-//
-// Copyright (C) 1998,1999 Dan Pilone
-// Copyright (C) 2000 Adriaan de Groot
-//
-// This file is distributed under the Gnu General Public Licence (GPL).
-// The GPL should have been included with this file in a file called
-// COPYING.
-//
-// This is baseConduit.h for KDE 2 / KPilot 4.
- 
- 
- 
-// REVISION HISTORY
-//
-// 3.1b9        By Dan Pilone
-// 3.1.14	By Adriaan de Groot. Added addSyncLogMessage.
-//		Some code cleanup.
+/* baseConduit.h			KPilot
+**
+** Copyright (C) 1998-2001 by Dan Pilone
+**
+** This is the base class for all external conduits.
+*/
 
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, 
+** MA 02139, USA.
+*/
+
+/*
+** Bug reports and questions can be sent to adridg@cs.kun.nl
+*/
 #ifndef __BASE_CONDUIT_H
 #define __BASE_CONDUIT_H
 
@@ -31,14 +39,28 @@ class BaseConduit : public QObject
   Q_OBJECT
 
 public:
-  enum eConduitMode { None, Error, HotSync, Setup, Backup, DBInfo };
+  enum eConduitMode { 
+		Error=-1, 
+		None=0, 
+		HotSync, 
+		Setup,
+		Backup, 
+		Test,
+		DBInfo
+	};
 
+	enum ConduitExitCode {
+		Normal=0,
+		ConduitMisconfigured=1,		// f.ex missing file
+		DCOPError=2,			// generic DCOP error
+		PeerApplicationMissing=3
+		} ;
   /**
    * The mode that this conduit should be running in will be passed to the
    * constructor.   After the constructor returns the appropriate 
-   * virtual method will be called (ie: setup, hotsync, backup, etc).
+   * virtual method should be called (ie: setup, hotsync, backup, etc).
    */
-  BaseConduit(eConduitMode mode);
+  BaseConduit(eConduitMode);
   virtual ~BaseConduit();
 
   /**
@@ -74,12 +96,20 @@ public:
    */
   virtual const char* dbInfo() { return "<none>"; }
 
+	/**
+	* Run a test on this conduit, with full debugging turned on.
+	* This may be reimplemented in some conduits to do actual
+	* tests.
+	*/
+	virtual void doTest() { } ;
 
 	/**
 	 * Returns an icon for the window manager
 	 * when the conduit is in "setup" mode.
 	 */
-	 virtual QPixmap *icon() const;
+	 virtual QPixmap icon() const;
+
+	const eConduitMode getMode() const { return fMode; } ;
 
 protected:
 
@@ -114,11 +144,6 @@ protected:
    */
   recordid_t writeRecord(PilotRecord* rec); 
   
-  /**
-   * Mode for this instance of the conduit
-   */
-  eConduitMode fMode;
-
 	/**
 	* Adds a message to the sync log by talking to
 	* the daemon; the message s should not contain
@@ -129,7 +154,41 @@ protected:
 	*/
 	int addSyncLogMessage(const char *s);
 
+	/**
+	* Conduits can have an additional Debug= line in their
+	* config which may be read and ORed with the user-specified
+	* debug level. This function does that. It's not automatic
+	* because then BaseConduit would have to know the group
+	* the conduit wants to read.
+	*
+	* @ret resulting debug level
+	*/
+	int getDebugLevel(KConfig&) ;
+
+	/**
+	* Conduits can have a "first time" setting that causes
+	* additional actions to be taken. There is also a global
+	* KPilot setting "force first time" that interferes here.
+	*
+	* Remember that conduits should set first time to false
+	* in their code.
+	*
+	* @ret true for first time, false otherwise
+	*/
+	bool getFirstTime(KConfig&);
+
+	/**
+	* For consistent setting of "first time" we introduce this
+	* convenience function.
+	*/
+	void setFirstTime(KConfig&,bool=false);
+
 private:
+  /**
+   * Mode for this instance of the conduit
+   */
+  eConduitMode fMode;
+
   KSocket* fDaemonSocket;
   PilotRecord* getRecord(KSocket*);
   void writeRecord(KSocket* theSocket, PilotRecord* rec);
@@ -137,3 +196,9 @@ private:
 
 
 #endif
+
+
+// $Log: baseConduit.h,v $
+// Revision 1.15  2001/02/06 08:05:19  adridg
+// Fixed copyright notices, added CVS log, added surrounding #ifdefs. No code changes.
+//
