@@ -1,22 +1,36 @@
-// conduitApp.cc
-//
-// Copyright (C) 1998-2000 Dan Pilone
-//
-// This file is distributed under the Gnu General Public Licence (GPL).
-// The GPL should have been included with this file in a file called
-// COPYING. 
-//
-// This is conduitApp.cc for KDE 2 / KPilot 4.
-//
-//
-//
+/* conduitApp.cc			KPilot
+**
+** Copyright (C) 1998-2001 by Dan Pilone
+**
+** This provides a base class for KApplications that also
+** happen to be conduits.
+*/
 
-static const char *id=
-	"$Id: conduitApp.cc,v 1.8 2000/09/05 07:13:57 adridg Exp $";
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, 
+** MA 02139, USA.
+*/
+
+/*
+** Bug reports and questions can be sent to adridg@cs.kun.nl
+*/
+static const char *conduitapp_id=
+	"$Id: conduitApp.cc,v 1.18 2001/02/08 08:13:44 habenich Exp $";
 
 #include "options.h"
 
-#ifdef KDE2
 #include <unistd.h>
 #include <getopt.h>
 #include <stdlib.h>
@@ -27,17 +41,10 @@ static const char *id=
 #include <kaboutdata.h>
 #include <kcmdlineargs.h>
 #include <kapp.h>
+#include <kdebug.h>
+#include <dcopclient.h>
 
 #include "conduitApp.h"
-#else
-#include <iostream.h>
-#include <string.h>
-#include <unistd.h>
-#include <getopt.h>
-#include <kwm.h>
-#include "conduitApp.moc"
-#include "kpilot.h"
-#endif
 
 
 // In KDE2 we use command line options in KDE2 style (!)
@@ -46,7 +53,6 @@ static const char *id=
 //
 // Help and debug options are standard in KDE2.
 //
-#ifdef KDE2
 static KCmdLineOptions conduitoptions[] =
 {
 	{ "setup", I18N_NOOP("Start up configuration dialog " 
@@ -57,27 +63,18 @@ static KCmdLineOptions conduitoptions[] =
 		"with this conduit"), 0L },
 	{ "hotsync", I18N_NOOP("HotSync the databases associated "
 		"with this conduit"), 0L },
+	{ "test",I18N_NOOP("Test this conduit (possibly unimplemented)")
+		,0L },
+#ifdef DEBUG
 	{ "debug <level>", I18N_NOOP("Set debugging level"), "0" },
+#endif
 	{ 0,0,0 }
 } ;
-#else
-static struct option longOptions[]=
-{
-	{ "setup",0,0L,'s' },
-	{ "info",0,0L,'i' },
-	{ "backup",0,0L,'b' },
-	{ "debug",1,0L,'d' },
-	{ "hotsync",0,0L,'h' },	// Included for orthogonality
-	{ "help",0,0L,1 },
-	{ 0L,0,0L,0 }
-} ;
-#endif
 
 
 // Constructors
 //
 //
-#ifdef KDE2
 // The constructor for KDE2. In KDE2 a ConduitApp
 // HAS a KApplication, it's not a KIND OF KApplication.
 //
@@ -108,42 +105,19 @@ ConduitApp::ConduitApp(
 		I18N_NOOP("Project Leader"),
 		"pilone@slac.com",
 		"http://www.slac.com/pilone/kpilot_home/");
-#if 0
-	fAbout->addAuthor("Adriaan de Groot",
-		I18N_NOOP("Maintainer"),
-		"adridg@cs.kun.nl",
-		"http://www.cs.kun.nl/~adridg/kpilot/");                        
-#endif
+
+	/* NOTREACHED */
+	(void) conduitapp_id;
 }
-#else
-// The constructor for KDE1 places more burden on the
-// caller, who must compose a decent banner for the
-// application.
-//
-//
-ConduitApp::ConduitApp(
-	int& argc, 
-	char** argv, 
-	const QCString& rAppName,
-	const char *banner)
-  : KApplication(argc, argv, rAppName), fConduit(0L)
-{
-	fMode=handleOptions(banner,argc,argv);
-	if (fMode==BaseConduit::Error) usage(banner,longOptions);
-}
-#endif
 
 
 
-
-#ifdef KDE2
 void ConduitApp::addAuthor(const char *name,
 	const char *task,
 	const char *email)
 {
 	fAbout->addAuthor(name,task,email);
 }
-#endif
 
 
 
@@ -156,7 +130,6 @@ void ConduitApp::addAuthor(const char *name,
 // from KDE1 to KDE2 but have the same purpose: deal
 // with the options that can be passed to the conduit.
 //
-#ifdef KDE2
 // Options are added by addOptions(); the actual handling
 // of options is done much later by exec()
 //
@@ -187,45 +160,16 @@ KCmdLineArgs *ConduitApp::getOptions()
 
 	p=KCmdLineArgs::parsedArgs();
 
+#ifdef DEBUG
 	debug_level = atoi(p->getOption("debug"));
+#endif
 
 	return p;
-}
-#else
-
-BaseConduit::eConduitMode ConduitApp::handleOptions(const char *banner,
-	int& argc,char **argv)
-{
-	FUNCTIONSETUP;
-
-	int c,li;
-	BaseConduit::eConduitMode rc=BaseConduit::HotSync;
-
-	while ((c=getopt_long(argc,argv,"sibd:vh?",longOptions,&li))>0)
-	{
-		switch(c)
-		{
-		case 's' : rc=BaseConduit::Setup; break;
-		case 'i' : rc=BaseConduit::DBInfo; break;
-		case 'b' : rc=BaseConduit::Backup; break;
-		case 'h' : rc=BaseConduit::HotSync; break;
-		case 'd' : debug_level=atoi(optarg); 
-			if (debug_level)
-			{
-				cerr << fname << ": Debug level set to "
-					<< debug_level << endl;
-			}
-			break;
-		case 1 : usage(banner,longOptions); exit(0);
-		default : usage(banner,longOptions); exit(1);
-		}
-	}
-
-	return rc;
-}
-
-
+#ifdef DEBUG
+	/* NOTREACHED */
+	(void) conduitapp_id;
 #endif
+}
 
 
 // In KDE1, setConduit() performs some actions based
@@ -238,29 +182,50 @@ ConduitApp::setConduit(BaseConduit* conduit)
 {
 	FUNCTIONSETUP;
 
-#ifndef KDE2
-	if (fMode==BaseConduit::Error)
-	{
-		cerr << fname << ": ConduitApp has state \"Error\".\n";
-		return;
-	}
-#endif
 	fConduit = conduit;
+}
 
-#ifndef KDE2
-	switch(fMode)
+// setup a conduit's DCOP stuff.
+//
+//
+bool
+ConduitApp::setupDCOP()
+{
+	FUNCTIONSETUP;
+
+	// Can only happen if we call setupDCOP from somewhere
+	// before exec(). That would be very strange ....
+	//
+	if (!fApp)
 	{
-	case BaseConduit::DBInfo : cout << conduit->dbInfo(); break;
-	case BaseConduit::HotSync : conduit->doSync(); break;
-	case BaseConduit::Backup : conduit->doBackup(); break;
-	case BaseConduit::Setup : break;
-	default :
-		cerr << fname << ": ConduitApp has state " 
-			<< (int) fMode  << endl 
-			<< fname << ": where it is strange to call me."
+		kdError() << __FUNCTION__
+			<< "No KApplication object!"
 			<< endl;
+		return false;
 	}
-#endif
+
+	DCOPClient *p = fApp->dcopClient();
+	if (!p)
+	{
+		kdError() << __FUNCTION__
+			<< "Couldn't get DCOP connection."
+			<< endl;
+		return false;
+	}
+
+	if (!p->attach())
+	{
+		// The DCOP docs say that KApplication
+		// has already displayed a warning message.
+		// So don't print one here.
+		
+		return false;
+	}
+
+	// Conduit's never serve requests so there's
+	// no need to register a name.
+
+	return true;
 }
 
 // exec() actually runs the conduit. This isn't strictly
@@ -268,64 +233,107 @@ ConduitApp::setConduit(BaseConduit* conduit)
 // which in KDE2 is transferred here.
 //
 //
-#ifdef KDE2
 #define CheckArg(s,m)	if (args->isSet(s)) \
 		{ if (fMode==BaseConduit::None) \
 		{ fMode=BaseConduit::m; } else \
-		{ cerr << fname << ": More than one mode given (mode now " \
+		{ kdError() << __FUNCTION__ \
+			<< ": More than one mode given (mode now " \
 			<< (int)fMode << ')' << endl; \
 			fMode=BaseConduit::Error; } }
 
-int ConduitApp::exec()
+BaseConduit::eConduitMode ConduitApp::getMode()
 {
 	FUNCTIONSETUP;
 
-	QWidget *widget = 0L;
-	QPixmap *icon= 0L;
+	if (fMode!=BaseConduit::None) return fMode;
 
 	KCmdLineArgs *args=getOptions();
 	CheckArg("info",DBInfo);
 	CheckArg("setup",Setup);
 	CheckArg("hotsync",HotSync);
 	CheckArg("backup",Backup);
+	CheckArg("test",Test);
 
 	if (fMode==BaseConduit::None)
 	{
-		cerr << fname 
+		kdError() << __FUNCTION__ 
 			<< ": You must specify a mode for the conduit."
 			<< endl;
 		fMode=BaseConduit::Error;
 	}
+	else
+	{
+#ifdef DEBUG
+		if (debug_level & SYNC_TEDIOUS)
+		{
+			kdDebug() << fname 
+				<< ": Set mode to "
+				<< (int) fMode
+				<< endl;
+		}
+#endif
+	}
+
+	return fMode;
+}
+
+int ConduitApp::exec(bool withDCOP,bool withGUI)
+{
+	FUNCTIONSETUP;
+
+	QWidget *widget = 0L;
+
+	(void) getMode();
+
+	if (fMode == BaseConduit::Setup)
+	{
+		withGUI=true;
+	}
 
 	// Note that both styles and GUI are only in effect
 	// if we are going to do the setup dialog.
 	//
-	fApp=new KApplication(fMode==BaseConduit::Setup,
-		fMode==BaseConduit::Setup);
+	fApp=new KApplication(withGUI,withGUI);
+
+	if (withDCOP) 
+	{
+		if (!setupDCOP())
+		{
+			return 1;
+		}
+	}
 
 	switch(fMode)
 	{
 	case BaseConduit::DBInfo : cout << fConduit->dbInfo(); break;
 	case BaseConduit::HotSync : fConduit->doSync(); break;
 	case BaseConduit::Backup : fConduit->doBackup(); break;
+	case BaseConduit::Test : 
+#ifdef DEBUG
+		debug_level=-1; 
+#endif
+		fConduit->doTest(); 
+		break;
 	case BaseConduit::Setup :
+		{
+		QPixmap icon = fConduit->icon();
 		widget = fConduit->aboutAndSetup();
-		icon= fConduit->icon();
 
 		fApp->setMainWidget(widget);
-		KWin::setIcons(widget->winId(),*icon,*icon);
+		KWin::setIcons(widget->winId(),icon,icon);
 
 		widget->show();
 
 		return fApp->exec();
+		}
 	case BaseConduit::Error :
-		cerr << fname << ": ConduitApp is in Error state."
+		kdError() << __FUNCTION__ << ": ConduitApp is in Error state."
 			<< endl;
 		break;
 	default :
-		cerr << fname << ": ConduitApp has state " 
-			<< (int) fMode  << endl 
-			<< fname << ": where it is strange to call me."
+		kdWarning() << __FUNCTION__ << ": ConduitApp has state " 
+			<< (int) fMode 
+			<< ": where it is strange to call me."
 			<< endl;
 	}
 
@@ -334,28 +342,36 @@ int ConduitApp::exec()
 	//
 	return 0;
 }
-#else
-int
-ConduitApp::exec()
-{
-	FUNCTIONSETUP;
 
-	if(fMode == BaseConduit::Setup)
-	{
-		if (debug_level & UI_MAJOR)
-		{
-				cerr << fname 
-					<< ": Running setup widget"
-					<< endl ;
-		}
-		QWidget* widget = fConduit->aboutAndSetup();
-		QPixmap *icon= fConduit->icon();
 
-		KApplication::setMainWidget(widget);
-		KWin::setIcons(widget->winId(),*icon,*icon);
-		widget->show();
-		return KApplication::exec();
-	}
-	return 0;
-}
-#endif
+// $Log: conduitApp.cc,v $
+// Revision 1.18  2001/02/08 08:13:44  habenich
+// exchanged the common identifier "id" with source unique <sourcename>_id for --enable-final build
+//
+// Revision 1.17  2001/02/05 20:55:07  adridg
+// Fixed copyright headers for source releases. No code changed
+//
+// Revision 1.16  2000/12/31 16:44:00  adridg
+// Patched up the debugging stuff again
+//
+// Revision 1.15  2000/12/22 07:47:04  adridg
+// Added DCOP support to conduitApp. Breaks binary compatibility.
+//
+// Revision 1.14  2000/12/21 00:42:50  adridg
+// Mostly debugging changes -- added EFUNCTIONSETUP and more #ifdefs. KPilot should now compile -DNDEBUG or with DEBUG undefined
+//
+// Revision 1.13  2000/12/06 22:22:51  adridg
+// Debug updates
+//
+// Revision 1.12  2000/11/20 00:24:27  adridg
+// Added --test
+//
+// Revision 1.11  2000/11/17 08:31:59  adridg
+// Minor changes
+//
+// Revision 1.10  2000/11/14 06:32:26  adridg
+// Ditched KDE1 stuff
+//
+// Revision 1.9  2000/10/29 22:11:06  adridg
+// Added debug-merge feature to conduits
+//
