@@ -1,15 +1,34 @@
-// fileInstallWidget.cc
-//
-// Copyright (C) 1998,1999 Dan Pilone
-//
-// This file is distributed under the Gnu General Public Licence (GPL).
-// The GPL should have been included with this file in a file called
-// COPYING. 
-//
-// $Revision: 1.7 $
+/* fileInstallWidget.cc			KPilot
+**
+** Copyright (C) 1998-2001 by Dan Pilone
+**
+** This file defines the internal conduit "File Installer"
+** that accepts drags of URLs containing Palm DBs, prcs, and
+** such. It also does the HotSync part of installing files
+** on the Pilot.
+*/
 
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, 
+** MA 02139, USA.
+*/
 
-static const char *id="$Id: fileInstallWidget.cc,v 1.7 2000/08/30 22:16:32 pilone Exp $";
+/*
+** Bug reports and questions can be sent to adridg@cs.kun.nl
+*/
+static const char *fileinstallwidget_id="$Id: fileInstallWidget.cc,v 1.11 2001/02/08 08:13:44 habenich Exp $";
 
 
 #include <sys/types.h>
@@ -159,6 +178,8 @@ bool
 FileInstallWidget::saveData()
     {
     return true;
+	/* NOTREACHED */
+	(void) fileinstallwidget_id;
     }
 
 void 
@@ -190,3 +211,12 @@ FileInstallWidget::refreshFileInstallList()
       for(i = 2; i < installDir.count(); i++)
  	addFileToLists(installDir[i].latin1());
     }
+
+
+// $Log: fileInstallWidget.cc,v $
+// Revision 1.11  2001/02/08 08:13:44  habenich
+// exchanged the common identifier "id" with source unique <sourcename>_id for --enable-final build
+//
+// Revision 1.10  2001/02/05 20:55:07  adridg
+// Fixed copyright headers for source releases. No code changed
+//
