@@ -1,29 +1,50 @@
-// gsetupDialog.cc
-//
-// Copyright (C) 2000 Dan Pilone
-//
-// This file is distributed under the Gnu General Public Licence (GPL).
-// The GPL should have been included with this file in a file called
-// COPYING.
-//
-// This is the version of gsetupDialog.cc for KDE 2 / KPilot 4.
-//
-// You can compile this file with -DUSE_STANDALONE to produce
-// applications that do not depend on KPilotLink. The application
-// will then use the standard configuration file (i.e. appnamerc).
-//
-//
+/* gsetupDialog.cc			KPilot
+**
+** Copyright (C) 2000-2001 by Dan Pilone
+** 
+** This defines a base class for all setup dialogs in KPilot and
+** KPilot's conduits.
+** 
+** You can compile this file with -DUSE_STANDALONE to produce
+** applications that do not depend on KPilotLink. The application
+** will then use the standard configuration file (i.e. appnamerc).
+*/
 
-static const char *id="$Id: gsetupDialog.cc,v 1.7 2000/09/05 07:13:57 adridg Exp $";
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, 
+** MA 02139, USA.
+*/
+
+/*
+** Bug reports and questions can be sent to adridg@cs.kun.nl
+*/
+
+
+
+static const char *gsetupdialog_id="$Id: gsetupDialog.cc,v 1.15 2001/02/08 08:13:44 habenich Exp $";
 
 #include "options.h"
 
 #include <stream.h>
+
 #include <qfileinf.h>
 #include <qlabel.h>
 #include <qpushbutton.h>
-#include <qvbox.h>
+#include <qlayout.h>
 #include <qmultilineedit.h>
+
 #include <kmessagebox.h>
 #include <kconfig.h>
 #include <kapp.h>
@@ -31,19 +52,12 @@ static const char *id="$Id: gsetupDialog.cc,v 1.7 2000/09/05 07:13:57 adridg Exp
 #include <kfiledialog.h>
 #include <kaboutdata.h>
 #include <kaboutapplication.h>
+#include <kdebug.h>
 
 #include "gsetupDialog.moc"
 #include "kpilotlink.h"
  
-// Handle code differences between the standalone and
-// the kpilot version of this file.
-//
-//
-#ifdef USE_STANDALONE
-#define CONFIG	KGlobal::config()
-#else
 #define CONFIG	KPilotLink::getConfig()
-#endif
 
 
 //---------------------------------------------------
@@ -55,8 +69,7 @@ static const char *id="$Id: gsetupDialog.cc,v 1.7 2000/09/05 07:13:57 adridg Exp
 //
 setupDialogPage::setupDialogPage(
 	const QString &s,
-	setupDialog *parent,
-	KConfig *c) :
+	setupDialog *parent) :
 	QWidget(parent),
 	fTabName(s)
 {
@@ -65,21 +78,32 @@ setupDialogPage::setupDialogPage(
 	parentSetup=parent;
 }
 
-/* virtual */ int setupDialogPage::commitChanges(KConfig *c)
+/* virtual */ int setupDialogPage::commitChanges(KConfig& c)
 {
 	FUNCTIONSETUP;
+	// Avoid unused-parameter warning
+	(void) c;
 
 	return 0;
+	/* NOTREACHED */
+	(void) gsetupdialog_id;
 }
 
-/* virtual */ int setupDialogPage::cancelChanges(KConfig *c)
+/* virtual */ int setupDialogPage::cancelChanges(KConfig& c)
 {
 	FUNCTIONSETUP;
+	// Avoid unused-parameter warning
+	(void) c;
 
 	return 0;
 }
 
 
+/* virtual */ int setupDialogPage::validateChanges(KConfig &)
+{
+	// (void) c;
+	return 0;
+}
 
 //---------------------------------------------------
 //
@@ -99,23 +123,21 @@ setupDialog::setupDialog(QWidget *parent,
 	FUNCTIONSETUP;
 
 	const KAboutData *p=KGlobal::instance()->aboutData();
+#ifdef DEBUG
 	if (modal && debug_level & UI_TEDIOUS)
 	{
-		cerr << fname << ": This is a modal dialog." << endl;
+		kdDebug() << fname << ": This is a modal dialog." << endl;
 	}
+#endif
 
 	setCancelButton();
-#ifdef KDE2
 	setCaption(p->programName() + QString(" ") +
 		p->version());
 	// Avoid some unused parameter warnings.
 	//
 	//
-	name.length();
-	caption.length();
-#else
-	setCaption(caption.isNull() ? name : caption);
-#endif
+	(void) name.length();
+	(void) caption.length();
 
 	connect(this,SIGNAL(applyButtonPressed()),
                 this, SLOT(commitChanges()));
@@ -128,13 +150,37 @@ void setupDialog::commitChanges()
 {
 	FUNCTIONSETUP;
 	QListIterator<setupDialogPage> i(pages);
+	int r;
 
-	KConfig *config=CONFIG;
-	config->setGroup(groupName());
+	KConfig& config=CONFIG;
+	config.setGroup(groupName());
 
+	r=0;
+	for (i.toFirst(); i.current(); ++i)
+	{
+		// in case pages change it (which they shouldn't)
+		// set the group back to the dialog's group.
+		//
+		//
+		config.setGroup(groupName()); 
+		r |= i.current()->validateChanges(config);
+		if (r)
+		{
+			kdDebug() << ": Tab page "
+				<< i.current()->tabName()
+				<< " failed validation."
+				<< endl;
+		}
+	}
+	if (r)
+	{
+		kdDebug() << ": Validation failed." << endl;
+	}
+
+	config.setGroup(groupName()); 
 	if (fConfigVersion)
 	{
-		config->writeEntry("Configured",fConfigVersion);
+		config.writeEntry("Configured",fConfigVersion);
 	}
 
 	for (i.toFirst(); i.current(); ++i)
@@ -143,14 +189,13 @@ void setupDialog::commitChanges()
 		// set the group back to the dialog's group.
 		//
 		//
-		config->setGroup(groupName()); 
+		config.setGroup(groupName()); 
 		i.current()->commitChanges(config);
 	}
 
-	config->sync();
+	config.sync();
 	setResult(1);
 
-	delete config;
 
 	if (quitOnClose)
 	{
@@ -164,8 +209,8 @@ void setupDialog::cancelChanges()
 	FUNCTIONSETUP;
 	QListIterator<setupDialogPage> i(pages);
 
-	KConfig *config=CONFIG;
-	config->setGroup(groupName());
+	KConfig& config=CONFIG;
+	config.setGroup(groupName());
 
 	for (i.toFirst(); i.current(); ++i)
 	{
@@ -173,13 +218,12 @@ void setupDialog::cancelChanges()
 		// set the group back to the dialog's group.
 		//
 		//
-		config->setGroup(groupName()); 
+		config.setGroup(groupName()); 
 		i.current()->cancelChanges(config);
 	}
 
 	setResult(0);
 
-	delete config;
 
 	if (quitOnClose)
 	{
@@ -199,16 +243,18 @@ void setupDialog::setupWidget()
 
 	if (pages.count()==0)
 	{
-		cerr << fname << ": setupDialog doesn't "
+		kdWarning() << __FUNCTION__ << ": setupDialog doesn't "
 			"have any pages." << endl;
 		return;
 	}
 
+#ifdef DEBUG
 	if (debug_level & UI_MINOR)
 	{
-		cerr << fname << ": setupDialog has " << pages.count()
+		kdDebug() << fname << ": setupDialog has " << pages.count()
 			<< " pages." << endl;
 	}
+#endif
 
 	for (i.toFirst(); i.current(); ++i)
 	{
@@ -219,11 +265,13 @@ void setupDialog::setupWidget()
 		if (p->height() > y) y=p->height();
 	}
 
+#ifdef DEBUG
 	if (debug_level & UI_TEDIOUS)
 	{
-		cerr << fname << ": setupDialog has size "
+		kdDebug() << fname << ": setupDialog has size "
 			<< x << 'x' << y << endl;
 	}
+#endif
 
 	resize(x+2*SPACING,y+8*SPACING);
 }
@@ -235,7 +283,7 @@ int setupDialog::addPage(setupDialogPage *p)
 
 	if (p==0L) 
 	{
-		cerr << fname << ": NULL page passed to addPage"
+		kdError() << __FUNCTION__ << ": NULL page passed to addPage"
 			<< endl;
 		return -1;
 	}
@@ -258,11 +306,13 @@ int setupDialog::addPage(setupDialogPage *p)
 	if (filename.isNull()) return QueryNull;
 	if (filename.length()<1) return QueryNull;
 
+#ifdef DEBUG
 	if (debug_level & UI_TEDIOUS)
 	{
-		cerr << fname << ": Checking for existence of "
+		kdDebug() << fname << ": Checking for existence of "
 			<< filelabel.latin1() << ' ' << filename.latin1() << endl;
 	}
+#endif
 
 	QFileInfo info(filename);
 	if (!info.exists())
@@ -271,22 +321,26 @@ int setupDialog::addPage(setupDialogPage *p)
 		msg+='\n';
 		msg+=i18n("Really use this file?");
 
-		if (debug_level)
+#ifdef DEBUG
+		if (debug_level & UI_MAJOR)
 		{
-			cerr << fname << ": " << msg.latin1() << endl;
+			kdDebug() << fname << ": " << msg.latin1() << endl;
 		}
+#endif
 
 
 		int rc=KMessageBox::questionYesNo(parent,
 			msg,
 			i18n("Missing file?"));
 		
+#ifdef DEBUG
 		if (debug_level)
 		{
-			cerr << fname << ": User said "
+			kdDebug() << fname << ": User said "
 				<< rc << " about using "
 				"nonexistent file." << endl;
 		}
+#endif
 
 		return rc;
 	}
@@ -294,15 +348,12 @@ int setupDialog::addPage(setupDialogPage *p)
 	return QueryFileExists;
 }
 
-/* static */ int setupDialog::getConfigurationVersion(KConfig *c,
+/* static */ int setupDialog::getConfigurationVersion(KConfig& c,
 	const QString &g)
 {
-	int r;
+	c.setGroup(g);
 
-	if (c==0L) return 0;
-	c->setGroup(g);
-
-	return c->readNumEntry("Configured",0);
+	return c.readNumEntry("Configured",0);
 }
 
 
@@ -316,61 +367,57 @@ setupInfoPage::setupInfoPage(setupDialog *parent,bool includeabout) :
 	FUNCTIONSETUP;
 
 
+	QString s;
 	QLabel *text;
 	KIconLoader *l=KGlobal::iconLoader();
-	QString s;
+	const KAboutData *p=KGlobal::instance()->aboutData();
+
+	QGridLayout *grid = new QGridLayout(this,4,4,SPACING);
+	grid->addColSpacing(0,SPACING);
+	grid->addColSpacing(4,SPACING);
+
 
 	text=new QLabel(this);
 	text->setPixmap(l->loadIcon(KGlobal::instance()->instanceName(),
 		KIcon::Desktop));
 	text->adjustSize();
-	text->move(10,10);
+	grid->addWidget(text,0,1);
 
-	// Now we use a QVBox to arrange all the
-	// text on the page so that it doesn't interfere with the icon.
-	// We use the about data for this application to fill in
-	// the text.
-	//
-	QVBox *frame=new QVBox(this,0L,0,false);
-	frame->setSpacing(10);
-	frame->move(10+text->width()+10,10);
 
-	const KAboutData *p=KGlobal::instance()->aboutData();
-
-	text=new QLabel(frame);
+	text=new QLabel(this);
 	s=p->programName();
 	s+=' ';
 	s+=p->version();
 	s+='\n';
 	s+=p->copyrightStatement();
 	text->setText(s);
+	grid->addMultiCellWidget(text,0,0,2,3);
 
-	text=new QLabel(frame);
+	text=new QLabel(this);
 	s=p->shortDescription();
 	text->setText(s);
+	grid->addMultiCellWidget(text,1,1,2,3);
 
-	text=new QLabel(frame);
+	text=new QLabel(this);
 	s=p->homepage();
 	s+='\n';
 	s+=i18n("Send bugs reports to ");
 	s+=p->bugAddress();
 	text->setText(s);
+	grid->addMultiCellWidget(text,2,2,2,3);
 
 	if (includeabout)
 	{
-		QHBox *hb=new QHBox(frame);
 		QPushButton *but=new QPushButton(i18n("More About ..."),
-			hb);
+			this);
 		connect(but, SIGNAL(clicked()),
 			this, SLOT(showAbout()));
 		but->adjustSize();
-		text=new QLabel(hb);
-		text->setText(" ");
-		text->adjustSize();
-		hb->setStretchFactor(text,100);
+		grid->addWidget(but,3,2);
 	}
 
-	frame->adjustSize();
+	grid->setRowStretch(4,100);
+	grid->setColStretch(3,100);
 }
 
 /* slot */ void setupInfoPage::showAbout()
@@ -383,3 +430,11 @@ setupInfoPage::setupInfoPage(setupDialog *parent,bool includeabout) :
 	// delete kap;
 }
 
+
+// $Log: gsetupDialog.cc,v $
+// Revision 1.15  2001/02/08 08:13:44  habenich
+// exchanged the common identifier "id" with source unique <sourcename>_id for --enable-final build
+//
+// Revision 1.14  2001/02/05 20:55:07  adridg
+// Fixed copyright headers for source releases. No code changed
+//
