@@ -1,19 +1,35 @@
-// gsetupDialog.h
-//
-// Copyright (C) 2000 Adriaan de Groot
-//
-// This file is distributed under the Gnu General Public Licence (GPL).
-// The GPL should have been included with this file in a file called
-// COPYING.
-//
-// This is the KDE2 version of gsetupDialog.h, intended for KPilot 4.
-// It should still compile under KDE1, though. Major changes have been
-// made in the types of functions (const char * -> const QString &) as
-// well as the implementation of some functions.
-//
-// $Id: gsetupDialog.h,v 1.3 2000/07/30 10:01:55 adridg Exp $
+/* gsetupDialog.h			KPilot
+**
+** Copyright (C) 2000-2001 by Dan Pilone
+**
+** This is a base class for setup dialogs, which provides some
+** utility functions. It assumes that every setup dialog is a
+** tabbed dialog with an About page.
+*/
 
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, 
+** MA 02139, USA.
+*/
 
+/*
+** Bug reports and questions can be sent to adridg@cs.kun.nl
+*/
+
+#ifndef _GSETUPDIALOG_H
+#define _GSETUPDIALOG_H
 
 #ifndef __OPTIONS_H
 #include "options.h"
@@ -39,15 +55,18 @@ public:
 	/**
 	* Make a page for a setup dialog. Use the
 	* given tab name, which should already be
-	* translated by i18n(). The KConfig * can
+	* translated by i18n(). 
+	*
+	* Subclasses will have the KConfig& parameter
+	* which can
 	* be used so that the page can read its 
 	* configuration from the file. The group of
 	* the configuration file is set by the dialog,
 	* and pages should not change it.
 	*/
 	setupDialogPage(const QString &tabname,
-		setupDialog *parent,
-		KConfig *c=0L);
+		setupDialog *parent /* , Add for subclasses
+		KConfig& c */ );
 		
 
 	/**
@@ -60,7 +79,7 @@ public:
 	* the group is a property of the dialog,
 	* not of the page.
 	*/
-	virtual int commitChanges(KConfig *);
+	virtual int commitChanges(KConfig&);
 
 	/**
 	* If the user cancels a setup dialog, this
@@ -69,7 +88,19 @@ public:
 	* the page -- just in case you have a page that
 	* makes changes to something before the user OKs it.
 	*/
-	virtual int cancelChanges(KConfig *);
+	virtual int cancelChanges(KConfig&);
+
+	/** Before committing changes, the dialog calls
+	* validateChanges() on all the pages to see if the
+	* information is consistent (whatever the pages think
+	* that is). If there is a page with a non-valid state,
+	* the dialog complains and the dialog is *NOT* closed.
+	*
+	* Returns 0 if all is well.
+	* Returns non-0 if the data is inconsistent and the
+	*	dialog can't be sensibly closed.
+	*/
+	virtual int validateChanges(KConfig&);
 
 	/**
 	* @return The tab name given to the constructor
@@ -174,7 +205,7 @@ public:
 	* A convenience function; returns the stored configuration
 	* number from a config file.
 	*/
-	static int getConfigurationVersion(KConfig *c,
+	static int getConfigurationVersion(KConfig& c,
 		const QString &group=QString::null);
 
 public slots:
@@ -290,8 +321,18 @@ private:
 
 	int fConfigVersion;
 } ;
+#endif /* _GSETUPDIALOG_H */
 
 // $Log: gsetupDialog.h,v $
+// Revision 1.6  2001/02/06 08:05:19  adridg
+// Fixed copyright notices, added CVS log, added surrounding #ifdefs. No code changes.
+//
+// Revision 1.5  2001/01/30 14:00:34  habenich
+// added surrounding #ifndef's
+//
+// Revision 1.4  2000/11/10 08:32:33  adridg
+// Fixed spurious config new() and delete()
+//
 // Revision 1.3  2000/07/30 10:01:55  adridg
 // Completed KDE2 layout
 //
