@@ -1,26 +1,37 @@
-// kpilot.cc
-//
-// Copyright (C) 1998,1999,2000 Dan Pilone
-//
-// This file is distributed under the Gnu General Public Licence (GPL).
-// The GPL should have been included with this file in a file called
-// COPYING.
+/* kpilot.cc			KPilot
+**
+** Copyright (C) 1998-2001 by Dan Pilone
+**
+** This is the main program in KPilot.
+*/
 
-// $Revision: 1.10 $
-static const char *id="$Id: kpilot.cc,v 1.10 2000/08/28 12:22:03 pilone Exp $";
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, 
+** MA 02139, USA.
+*/
+
+/*
+** Bug reports and questions can be sent to adridg@cs.kun.nl
+*/
 
 
-// REVISION HISTORY
-//
-// 3.1b9	By Dan Pilone
-// 3.1b10	By Adriaan de Groot: comments added all over the place,
-//		added debug-level variable. The error messages sent to
-//		the user still need work. Fixed socket bugs thanks
-//		to Robert Ambrose. Added dependency on pilotDaemon.h
-//		to ensure compatibility.
-//
+static const char *kpilot_id="$Id: kpilot.cc,v 1.36 2001/02/08 17:59:34 adridg Exp $";
 
 
+#include "options.h"
+
 
 #include <sys/types.h>
 #include <dirent.h>
@@ -30,6 +41,7 @@ static const char *id="$Id: kpilot.cc,v 1.10 2000/08/28 12:22:03 pilone Exp $";
 #include <fcntl.h>
 #include <sys/stat.h>
 #include <unistd.h>
+#include <errno.h>
 
 #include <qfile.h>
 #include <qlist.h>
@@ -46,9 +58,11 @@ static const char *id="$Id: kpilot.cc,v 1.10 2000/08/28 12:22:03 pilone Exp $";
 #include <ksock.h>
 #include <kcombobox.h>
 #include <kmenubar.h>
+#include <kstddirs.h>
 #include <kaboutdata.h>
 #include <kcmdlineargs.h>
-#include <kstddirs.h>
+#include <kiconloader.h>
+#include <kdebug.h>
 
 #include "kpilotOptions.h"
 #include "kpilot.moc"
@@ -59,84 +73,52 @@ static const char *id="$Id: kpilot.cc,v 1.10 2000/08/28 12:22:03 pilone Exp $";
 #include "statusMessages.h"
 #include "conduitSetup.h"
 #include "pilotDaemon.h"
-#include "options.h"
 
 
-const int KPilotInstaller::ID_FILE_QUIT = 1;
-const int KPilotInstaller::ID_FILE_SETTINGS = 2;
-const int KPilotInstaller::ID_FILE_BACKUP = 3;
-const int KPilotInstaller::ID_FILE_RESTORE = 4;
-const int KPilotInstaller::ID_HELP_HELP = 5;
-const int KPilotInstaller::ID_HELP_ABOUT = 6;
-const int KPilotInstaller::ID_CONDUITS_ENABLE = 7;
-const int KPilotInstaller::ID_CONDUITS_SETUP = 8;
-// Components that go in the "Conduits" menu -- ie.
-// address conduit, memo conduit, and file installer --
-// get a menu id derived from ID_COMBO+n, where n is
-// the number of installed components.
-// This is why we choose ID_COMBO a long way
-// away from ther ids: so that we have lots
-// of ids free for the components.
-// Remember to catch this in the menu handler.
-const int KPilotInstaller::ID_COMBO = 1000;
-
-// This is a number indicating what configuration version
-// we're dealing with. Whenever new configuration options are
-// added that make it imperative for the user to take a
-// look at the configuration of KPilot (for example the
-// skipDB setting really needs user attention) we can change
-// (increase) this number.
-//
-//
-const int KPilotInstaller::ConfigurationVersion = 320;
-
 KPilotInstaller::KPilotInstaller()
-  : KTMainWindow(), fMenuBar(0L), fStatusBar(0L), fToolBar(0L),
+  : KMainWindow(0), fMenuBar(0L), fStatusBar(0L), fToolBar(0L),
     fQuitAfterCopyComplete(false), fManagingWidget(0L), fPilotLink(0L),
-    fPilotCommandSocket(0L), fPilotStatusSocket(0L), fKillDaemonOnExit(false)
+    fPilotCommandSocket(0L), fPilotStatusSocket(0L), fKillDaemonOnExit(false),
+    fStatus(Startup)
 {
 	FUNCTIONSETUP;
 
-	int cfg_version;
+	KConfig& config = KPilotLink::getConfig();
+	// Log a warning if the config file is too old.
+	//
+	//
+	(void) KPilotOptions::isNewer(config);
 
-	KConfig* config = KGlobal::config();
-	config->setGroup(QString());
-	cfg_version=config->readNumEntry("Configured", 0);
+	readConfig(config);
 
-	if(cfg_version < ConfigurationVersion)
-	{
-		if (debug_level & UI_MAJOR)
-		{
-			cerr << fname << ": Read config version "
-				<< cfg_version
-				<< " require "
-				<< ConfigurationVersion
-				<< endl;
-		}
-
-		// If we haven't been configured,
-		// force the user to set things up.
-		KPilotOptions* options = new KPilotOptions(this);
-		options->show();
-		delete options;
-	}
-    if(config->readNumEntry("NextUniqueID", 0) == 0)
+    if(config.readNumEntry("NextUniqueID", 0) == 0)
       {
 	// Is this an ok value to use??
-	config->writeEntry("NextUniqueID", 0xf000);
-	config->sync();
+	config.writeEntry("NextUniqueID", 0xf000);
+	config.sync();
       }
+
+	// Just a block to isolate the config file.
+	//
+	//
+	{
+	KConfig KDEGlobalConfig(QString::null);
+	KDEGlobalConfig.setGroup("General");
+	fixedFont = KDEGlobalConfig.readFontEntry("fixed");
+	}
+
     initPilotLink();
 	if (!fPilotCommandSocket)
 	{
-		cerr << fname << ": Couldn't connect to daemon -- quitting"
+		kdError() << __FUNCTION__ << ": Couldn't connect to daemon -- quitting"
 			<< endl;
-		exit(1);
+		fStatus = Error ;
+		return;
 	}
     setupWidget();
     initComponents();
     initStatusLink();  // This is separate to allow components to initialize
-    showTitlePage();
+    showTitlePage(QString::null,true);
     show();
     }
 
@@ -150,6 +132,15 @@ KPilotInstaller::~KPilotInstaller()
 	if(fKillDaemonOnExit && fPilotCommandSocket &&
 		(fPilotCommandSocket->socket()>=0))
 	{
+#ifdef DEBUG
+		if (debug_level & SYNC_TEDIOUS)
+		{
+			kdDebug() << fname
+				<< ": Killing daemon."
+				<< endl;
+		}
+#endif
+
 		ofstream out(fPilotCommandSocket->socket());
 		out << -3 << endl;
 	}
@@ -158,6 +149,13 @@ KPilotInstaller::~KPilotInstaller()
 	fPilotCommandSocket=0L;
 }
 
+void KPilotInstaller::readConfig(KConfig& config)
+{
+	config.setGroup(QString::null);
+	fKillDaemonOnExit = config.readBoolEntry("StopDaemonAtExit",false);
+}
+
+
 #include "kpilot.xpm"
 
 void
@@ -172,14 +170,15 @@ KPilotInstaller::setupWidget()
     // KWM::setIcon(winId(), kapp->getIcon());
     setCaption("KPilot");
     setMinimumSize(500,405);
-    setMaximumSize(500,405);
+    // setMaximumSize(500,405);
+    initIcons();
     initMenu();
     initStatusBar();
     initToolBar();
     fManagingWidget = new QWidget(this);
     fManagingWidget->setMinimumSize(500,330);
     fManagingWidget->show();
-    setView(fManagingWidget, FALSE);
+    setCentralWidget(fManagingWidget);
     }
 
 void
@@ -217,10 +216,9 @@ KPilotInstaller::initStatusBar()
 	welcomeMessage+=version(0);
 	welcomeMessage+=')';
 
-	fStatusBar = new KStatusBar(this, "statusbar");
+	fStatusBar = statusBar();
 	fStatusBar->insertItem(welcomeMessage,0);
 	fStatusBar->show();
-	setStatusBar(fStatusBar);
 }
 
 // These are XPM files disguised as .h files
@@ -228,30 +226,80 @@ KPilotInstaller::initStatusBar()
 //
 #include "hotsync.h"
 #include "toolbar_backup.xpm"
+#include "toolbar_restore.xpm"
+#include "fastsync.xpm"
+
+void KPilotInstaller::initIcons()
+{
+	FUNCTIONSETUP;
+
+	KIconLoader *il = KGlobal::iconLoader();
+
+	icon_quit = il->loadIcon("exit",
+		KIcon::Toolbar,0,KIcon::DefaultState,0,true);
+
+	if (icon_quit.isNull())
+	{
+		kdWarning() << __FUNCTION__ << ": Quit icon not found." << endl;
+	}
+
+	icon_fastsync = QPixmap((const char **)fastsync_xpm);
+	icon_hotsync = QPixmap((const char **)hotsync_icon);
+	icon_backup = QPixmap((const char **)toolbar_backup);
+	icon_restore = QPixmap((const char **)toolbar_restore);
+}
+
 
 void
 KPilotInstaller::initToolBar()
   {
 	FUNCTIONSETUP;
 
-  fToolBar = new KToolBar(this, "toolbar");
-  QPixmap icon(hotsync_icon);
+	fToolBar = new KToolBar(this, "toolbar");
 
-  fToolBar->insertButton(icon, 0, SIGNAL(clicked()), this, SLOT(doHotSync()),
-			 TRUE, i18n("Hot-Sync"));
+	KConfig& c = KPilotLink::getConfig();
+	QStringList s = c.readListEntry("ToolbarIcons");
 
-	// This next button exactly mirrors
-	// the functionality of the menu back
-	// "backup" choice.
+
+	// We allow some kind of toolbar customisation,
+	// and we should switch to the real KDE2 configurable
+	// toolbars soon (after KDE 2.1 / KPilot 4.0.0)
 	//
 	//
+	if (s.isEmpty() || s.contains("HotSync"))
 	{
-		QPixmap bicon((const char **)toolbar_backup);
-		fToolBar->insertButton(bicon,ID_FILE_BACKUP,
+		fToolBar->insertButton(icon_hotsync, ID_FILE_HOTSYNC,
+			SIGNAL(clicked(int)), this, SLOT(menuCallback(int)),
+			TRUE, i18n("Hot-Sync"));
+	}
+
+	if (s.contains("FastSync"))
+	{
+		fToolBar->insertButton(icon_fastsync, ID_FILE_FASTSYNC,
+			SIGNAL(clicked(int)),this,SLOT(menuCallback(int)),
+			TRUE,i18n("Fast-Sync"));
+	}
+
+	if (s.isEmpty() || s.contains("Backup"))
+	{
+		// This next button exactly mirrors
+		// the functionality of the menu back
+		// "backup" choice.
+		//
+		//
+		fToolBar->insertButton(icon_backup,ID_FILE_BACKUP,
 			SIGNAL(clicked(int)),this,SLOT(menuCallback(int)),
 			TRUE, i18n("Full Backup"));
 	}
 
+	if (s.contains("Restore"))
+	{
+		fToolBar->insertButton(icon_restore,ID_FILE_RESTORE,
+			SIGNAL(clicked(int)),this,SLOT(menuCallback(int)),
+			TRUE, i18n("Full Restore"));
+	}
+
+
 
 
 	// KDE2 style guide says "No quit toolbar button"
@@ -264,19 +312,11 @@ KPilotInstaller::initToolBar()
 	//	TRUE, i18n("Quit"));
 
 	conduitCombo=new QComboBox(fToolBar,"conduitCombo");
-	conduitCombo->insertItem(i18n("Pilot Application"));
+	conduitCombo->insertItem(version(0));
 	fToolBar->insertWidget(KPilotInstaller::ID_COMBO,140,conduitCombo,0);
 	connect(conduitCombo,SIGNAL(activated(int)),
 		this,SLOT(slotModeSelected(int)));
-	/*
-	fToolBar->insertCombo(i18n("Pilot Application"), 
-		KPilotInstaller::ID_COMBO, false,
-		SIGNAL(activated(int)), this, 
-		SLOT(slotModeSelected(int)), true,
-		i18n("KPilot Mode"), 140, 0);
-	*/
 
-  // This only works after Beta 4.. 
   fToolBar->alignItemRight(KPilotInstaller::ID_COMBO);
   addToolBar(fToolBar);
   }
@@ -286,37 +326,59 @@ void
 KPilotInstaller::slotModeSelected(int selected)
 {
 	FUNCTIONSETUP;
+	int current = 0 ;
 
+#ifdef DEBUG
 	if (debug_level& UI_TEDIOUS)
 	{
-		cerr << fname << ": Responding to callback " << selected
+		kdDebug() << fname << ": Responding to callback " << selected
 			<< endl;
 	}
+#endif
 
 	if((unsigned int)selected >= fVisibleWidgetList.count())
 	{
-		cerr << fname << ": Illegal component #" 
+		kdWarning() << __FUNCTION__ << ": Illegal component #" 
 			<< selected << " selected.\n" << endl;
 		return;
 	}
 
 
+	current=0;
 	for (fVisibleWidgetList.first();
 		fVisibleWidgetList.current();
 		fVisibleWidgetList.next())
 	{
-		fVisibleWidgetList.current()->hide();
+		if (selected != current)
+		{
+			fVisibleWidgetList.current()->hide();
+		}
+		else
+		{
+			fVisibleWidgetList.at(selected)->show();
+		}
+
+		current++;
 	}
 		
-	fVisibleWidgetList.at(selected)->show();
+
+	fStatusBar->changeItem(conduitCombo->text(selected),0);
 }
 
-void KPilotInstaller::showTitlePage()
+void KPilotInstaller::showTitlePage(const QString& msg,bool force)
 {
 	FUNCTIONSETUP;
 
-	slotModeSelected(0);
-	conduitCombo->setCurrentItem(0);
+	if ((conduitCombo->currentItem()!=0) || force)
+	{
+		slotModeSelected(0);
+		conduitCombo->setCurrentItem(0);
+	}
+
+	if (!msg.isNull())
+	{
+		fStatusBar->changeItem(msg,0);
+	}
 }
 
 	
@@ -330,14 +392,14 @@ KPilotInstaller::initPilotLink()
 
 	if(fPilotLink)
 	{
-		cerr << fname << ": Pilot Link already created?\n" ;
+		kdWarning() << __FUNCTION__ << ": Pilot Link already created?\n" ;
 		return;
 	}
 
 	fPilotLink = new KPilotLink();
 	if (fPilotLink==NULL)
 	{
-		cerr << fname << ": Can't allocate fPilotLink.\n";
+		kdError() << __FUNCTION__ << ": Can't allocate fPilotLink.\n";
 		KMessageBox::error(this,
 				   i18n("Allocating PilotLink failed."),
 				   i18n("Cannot create link to Daemon"));
@@ -354,10 +416,12 @@ KPilotInstaller::initPilotLink()
 		// We were called after a reconfigure
 		//
 		//
-		if (debug_level)
+#ifdef DEBUG
+		if (debug_level && SYNC_MAJOR)
 		{
-			cerr << fname << ": Reconfiguring daemon.\n" ;
+			kdDebug() << fname << ": Reconfiguring daemon.\n" ;
 		}
+#endif
 
 		ofstream out(fPilotCommandSocket->socket());
 		out << "-2" << endl;
@@ -372,21 +436,26 @@ void KPilotInstaller::initCommandSocket()
 
 	if (fPilotCommandSocket)
 	{
+		kdWarning() << __FUNCTION__ 
+			<< ": We already have a command socket"
+			<< endl;
 		return;
 	}
 
+#ifdef DEBUG
 	if (debug_level & SYNC_MINOR)
 	{
-		cerr << fname
+		kdDebug() << fname
 			<< ": Creating command socket"
 			<< endl ;
 	}
+#endif
 
 	fPilotCommandSocket = new KSocket("localhost", 
 		PILOTDAEMON_COMMAND_PORT);
 	if (fPilotCommandSocket==NULL)
 	{
-		cerr << fname << ": Can't allocate fPilotCommandSocket.\n";
+		kdError() << __FUNCTION__ << ": Can't allocate fPilotCommandSocket.\n";
 		KMessageBox::error(this,
 				   i18n("Allocating fPilotCommandSocket failed."),
 				   i18n("Cannot create link to Daemon"));
@@ -396,13 +465,15 @@ void KPilotInstaller::initCommandSocket()
 		return;
 	}
 
+#ifdef DEBUG
 	if (debug_level & SYNC_TEDIOUS)
 	{
-		cerr << fname
+		kdDebug() << fname
 			<< ": Got socket " 
 			<< fPilotCommandSocket->socket()
 			<< endl ;
 	}
+#endif
 
 	
 	if((fPilotCommandSocket->socket() < 0) ||
@@ -410,12 +481,14 @@ void KPilotInstaller::initCommandSocket()
 	{
 		int i;
 
+#ifdef DEBUG
 		if (debug_level & SYNC_MAJOR)
 		{
-			cerr << fname
-				<< ": Starting daemon"
+			kdDebug() << fname
+				<< ": Socket not OK, starting daemon"
 				<< endl;
 		}
+#endif
 
 		// It wasn't running...
 		messageDialog = 
@@ -438,6 +511,7 @@ void KPilotInstaller::initCommandSocket()
 
 		KProcess pilotDaemon;
 		pilotDaemon << "kpilotDaemon";
+#ifdef DEBUG
 		if (debug_level)
 		{
 			QString s;
@@ -446,6 +520,7 @@ void KPilotInstaller::initCommandSocket()
 			pilotDaemon << "--debug";
 			pilotDaemon << s;
 		}
+#endif
 			
 		kapp->processEvents();
 
@@ -462,8 +537,24 @@ void KPilotInstaller::initCommandSocket()
 			sleep(1);
 			kapp->processEvents();
 
+#ifdef DEBUG
+			if (debug_level & SYNC_TEDIOUS)
+			{
+				kdDebug() << fname
+					<< ": Trying to connect"
+					<< endl;
+			}
+#endif
 			fPilotCommandSocket = new KSocket("localhost",
 				PILOTDAEMON_COMMAND_PORT);
+			if (!fPilotCommandSocket)
+			{
+				kdError() << __FUNCTION__
+					<< ": Couldn't allocate KSocket"
+					<< endl;
+				continue;
+			}
+
 			if ((fPilotCommandSocket->socket() >= 0) &&
 				testSocket(fPilotCommandSocket))
 			{
@@ -476,14 +567,22 @@ void KPilotInstaller::initCommandSocket()
 			}
 		}
 
+#ifdef DEBUG
+		if (debug_level & UI_MINOR)
+		{
+			kdDebug() << fname
+				<< ": Halfway result "
+				<< "PilotCommandSocket="
+				<< (int)fPilotCommandSocket
+				<< endl;
+		}
+#endif
 			
 		if(!fPilotCommandSocket)
 		{
-			if (debug_level)
-			{
-				cerr << fname << ": Can't connect to daemon"
-					<< endl ;
-			}
+			kdError() << __FUNCTION__ 
+				<< ": Can't connect to daemon"
+				<< endl ;
 
 			KMessageBox::error(this, 
 					   i18n("Cannot start KPilot Daemon. "
@@ -492,27 +591,64 @@ void KPilotInstaller::initCommandSocket()
 					   i18n("Cannot connect to Daemon"));
 					   
 
-			KPilotOptions* options = new KPilotOptions(this);
-			options->show(); // It's modal..
+#ifdef DEBUG
 			if (debug_level & UI_TEDIOUS)
 			{
-				cerr << fname << ": User said "
-					<< options->result()
+				kdDebug() << fname << ": creating options "
+					<< endl;
+			}
+#endif
+			KPilotOptions* options = new KPilotOptions(this);
+			if (options)
+			{
+				options->exec();
+#ifdef DEBUG
+				if (debug_level & UI_TEDIOUS)
+				{
+					kdDebug() << fname << ": User said "
+						<< options->result()
+						<< endl;
+				}
+#endif
+				delete options;
+			}
+			else
+			{
+				kdError() << __FUNCTION__
+					<< ": Couldn't create options window."
 					<< endl;
 			}
-			delete options;
 		}
 
 		fKillDaemonOnExit = true;
 
 		if (messageDialog!=NULL)
 		{
-			messageDialog->hide();
+#ifdef DEBUG
+			if (debug_level & UI_TEDIOUS)
+			{
+				kdDebug() << fname
+					<< ": Closing and deleting msg dialog"
+					<< endl;
+			}
+#endif
+			messageDialog->close();
 			delete messageDialog;
 		}
 	}
 
 	fLinkCommand[0] = 0L;
+
+#ifdef DEBUG
+	if (debug_level & UI_MINOR)
+	{
+		kdDebug() << fname
+			<< ": End result "
+			<< "PilotCommandSocket="
+			<< (int)fPilotCommandSocket
+			<< endl;
+	}
+#endif
 }
 
 
@@ -535,7 +671,10 @@ int KPilotInstaller::testSocket(KSocket *s)
 	r=write(fd,buf,strlen(buf));
 	if (r<0)
 	{
-		perror(fname);
+		int e=errno;
+		kdError() << __FUNCTION__  
+			<< ": (" << strerror(e) << ")" 
+			<< endl;
 	}
 	signal(SIGPIPE,SIG_DFL);
 	
@@ -552,11 +691,13 @@ KPilotInstaller::initStatusLink()
 		PILOTDAEMON_STATUS_PORT);
 	if (fPilotStatusSocket->socket()!=-1)
 	{
+#ifdef DEBUG
 		if (debug_level& SYNC_TEDIOUS)
 		{
-			cerr << fname <<
+			kdDebug() << fname <<
 				": Connected socket successfully.\n";
 		}
+#endif
 
 		connect(fPilotStatusSocket, SIGNAL(readEvent(KSocket*)),
 			this, SLOT(slotDaemonStatus(KSocket*)));
@@ -564,7 +705,7 @@ KPilotInstaller::initStatusLink()
 	}
 	else
 	{
-		cerr << fname <<
+		kdError() << __FUNCTION__ <<
 			": Failed to connect socket to daemon.\n";
 	}
 }
@@ -578,38 +719,81 @@ KPilotInstaller::slotDaemonStatus(KSocket* daemon)
 {
 	FUNCTIONSETUP;
 
-  ifstream in(daemon->socket());
-  int status;
-  
-  in.read(&status, sizeof(int));
-  if(status == CStatusMessages::SYNC_STARTING)
-    {
-//       fLastWidgetSelected = fToolBar->getCombo(KPilotInstaller::ID_COMBO)->currentItem();
-//       fToolBar->getCombo(KPilotInstaller::ID_COMBO)->setCurrentItem(0);
-//       slotModeSelected(0);
-//       fToolBar->getCombo(KPilotInstaller::ID_COMBO)->setEnabled(false);
-      if(fLinkCommand[0] == 0L)
-	doHotSync();
-      fStatusBar->changeItem(i18n("Hot-Sync in progress..."), 0);
-      ofstream out(fPilotCommandSocket->socket());
-      out << fLinkCommand << flush;
-    }
-  else if(status == CStatusMessages::SYNC_COMPLETED)
-    {
-//       fToolBar->getCombo(KPilotInstaller::ID_COMBO)->setEnabled(true);
-//       fToolBar->getCombo(KPilotInstaller::ID_COMBO)->setCurrentItem(fLastWidgetSelected);
-//       slotModeSelected(fLastWidgetSelected);
-      fStatusBar->changeItem(i18n("Hot-Sync complete."), 0);
-      fLinkCommand[0] = 0L;
-      for(fPilotComponentList.first(); fPilotComponentList.current(); fPilotComponentList.next())
-	//fPilotComponentList.current()->postHotSync();
-	fPilotComponentList.current()->initialize();
-    }
-  else if(status == CStatusMessages::FILE_INSTALL_REQUEST)
-    {
-      for(fPilotComponentList.first(); fPilotComponentList.current(); fPilotComponentList.next())
-	fPilotComponentList.current()->initialize();
-    }
+	ifstream in(daemon->socket());
+	int status;
+	in.read(&status, sizeof(int));
+
+	DEBUGKPILOT << fname
+		<< ": Got command "
+		<< status
+		<< endl;
+
+	switch(status)
+	{
+	case CStatusMessages::SYNC_STARTING :
+		if(fLinkCommand[0] == 0L)
+		{
+			// This only happens when the daemon tells
+			// us to sync based on a button push.
+			//
+			//
+			KConfig& c = KPilotLink::getConfig();
+
+			// Either doFastSync() or doHotSync() sets up
+			// fLinkCommand to actually contain the bytes
+			// that we need to respond.
+			//
+			//
+			if (c.readBoolEntry("PreferFastSync",false))
+			{
+				getPilotLink()->setFastSyncRequired(true);
+				doFastSync();
+				fStatusBar->changeItem(
+					i18n("FastSync in progress..."), 0);
+			}
+			else
+			{
+				getPilotLink()->setFastSyncRequired(false);
+				doHotSync();
+				fStatusBar->changeItem(
+					i18n("HotSync in progress..."), 0);
+			}
+		}
+
+		// This block writes some stuff to the link and
+		// therefore requires its own ofstream object.
+		//
+		//
+		{
+		ofstream out(fPilotCommandSocket->socket());
+		out << fLinkCommand << flush;
+		}
+		break;
+	case CStatusMessages::SYNC_COMPLETED :
+		fStatusBar->changeItem(i18n("HotSync complete."), 0);
+		fLinkCommand[0] = 0L;
+		for(fPilotComponentList.first(); 
+			fPilotComponentList.current(); 
+			fPilotComponentList.next())
+		{
+			fPilotComponentList.current()->initialize();
+		}
+		break;
+	case CStatusMessages::FILE_INSTALL_REQUEST :
+		for(fPilotComponentList.first(); 
+			fPilotComponentList.current(); 
+			fPilotComponentList.next())
+		{
+			fPilotComponentList.current()->initialize();
+		}
+		break;
+	default :
+		kdWarning() << __FUNCTION__
+			<< ": Unknown command "
+			<< status
+			<< " received."
+			<< endl;
+	}
 }
 
 void
@@ -632,33 +816,33 @@ KPilotInstaller::doRestore()
   fStatusBar->changeItem(i18n("Restoring pilot. Please press the hot-sync button."), 0);
   sprintf(fLinkCommand, "%d\n", KPilotLink::Restore);
 }
-  
-void
-KPilotInstaller::doHotSync()
+ 
+void KPilotInstaller::setupSync(int kind,const QString& message)
 {
 	FUNCTIONSETUP;
 
-	showTitlePage();
-	fStatusBar->changeItem(i18n(
-		"Hot-Syncing.  "
-		"Please press the hot-sync button."), 0);
+	showTitlePage(message);
+
 	if (fLinkCommand[0] == 0)
 	{
-		sprintf(fLinkCommand, "%d\n", KPilotLink::HotSync);
+		sprintf(fLinkCommand, "%d\n",kind);
 		for(fPilotComponentList.first(); 
 			fPilotComponentList.current(); 
 			fPilotComponentList.next())
 		{
+#ifdef DEBUG
 			if (debug_level & SYNC_MINOR)
 			{
-				cerr << fname << ": Pre-sync for builtins."
+				kdDebug() << fname << ": Pre-sync for builtins."
 					<< endl;
 			}
+#endif
 			fPilotComponentList.current()->preHotSync(fLinkCommand);
 		}
 	}
 }
 
+
 void
 KPilotInstaller::closeEvent(QCloseEvent *e)
 {
@@ -676,10 +860,17 @@ KPilotInstaller::initMenu()
     QPopupMenu* fileMenu = new QPopupMenu;
     fileMenu->insertItem(i18n("&Settings"), KPilotInstaller::ID_FILE_SETTINGS);
     fileMenu->insertSeparator(-1);
-    fileMenu->insertItem(i18n("&Backup"), KPilotInstaller::ID_FILE_BACKUP);
-    fileMenu->insertItem(i18n("&Restore"), KPilotInstaller::ID_FILE_RESTORE);
+	fileMenu->insertItem(icon_hotsync,
+		i18n("&Hot-Sync"),KPilotInstaller::ID_FILE_HOTSYNC);
+	fileMenu->insertItem(icon_fastsync,
+		i18n("&Fast-Sync"),KPilotInstaller::ID_FILE_FASTSYNC);
+	fileMenu->insertItem(icon_backup,
+		i18n("&Backup"), KPilotInstaller::ID_FILE_BACKUP);
+	fileMenu->insertItem(icon_restore,
+		i18n("&Restore"), KPilotInstaller::ID_FILE_RESTORE);
     fileMenu->insertSeparator(-1);
-    fileMenu->insertItem(i18n("&Quit"), KPilotInstaller::ID_FILE_QUIT);
+	fileMenu->insertItem(icon_quit,
+		i18n("&Quit"), KPilotInstaller::ID_FILE_QUIT);
     connect(fileMenu, SIGNAL (activated(int)), SLOT (menuCallback(int)));
     
 	conduitMenu = new QPopupMenu;
@@ -689,18 +880,14 @@ KPilotInstaller::initMenu()
 	connect(conduitMenu, SIGNAL(activated(int)),
 		SLOT(menuCallback(int)));
 
-	QPopupMenu *theHelpMenu = KTMainWindow::helpMenu(QString(version(0)) +
-		i18n("\n\nCopyright (C) 1998-2000 Dan Pilone, Adriaan de Groot") +
-		i18n("\n\nProgramming by:\n") +
-		authors()) ;
+	KPopupMenu *theHelpMenu = helpMenu();
     
-    this->fMenuBar = new KMenuBar(this);
-    this->fMenuBar->insertItem(i18n("&File"), fileMenu);
-    this->fMenuBar->insertItem(i18n("&Conduits"), conduitMenu);
-    this->fMenuBar->insertSeparator();
-    this->fMenuBar->insertItem(i18n("&Help"), theHelpMenu);
-    this->fMenuBar->show();
-    setMenu(this->fMenuBar);
+	fMenuBar = menuBar();
+	fMenuBar->insertItem(i18n("&File"), fileMenu);
+	fMenuBar->insertItem(i18n("&Conduits"), conduitMenu);
+	fMenuBar->insertSeparator();
+	fMenuBar->insertItem(i18n("&Help"), theHelpMenu);
+	fMenuBar->show();
     }
 
 void
@@ -720,6 +907,23 @@ KPilotInstaller::quit()
 		fPilotComponentList.current()->saveData();
 	}
 
+	if(fKillDaemonOnExit && fPilotCommandSocket &&
+		(fPilotCommandSocket->socket()>=0))
+	{
+#ifdef DEBUG
+		if (debug_level & SYNC_TEDIOUS)
+		{
+			kdDebug() << fname
+				<< ": Killing daemon."
+				<< endl;
+		}
+#endif
+
+		ofstream out(fPilotCommandSocket->socket());
+		out << -3 << endl;
+	}
+
+
 	if (fPilotStatusSocket) delete fPilotStatusSocket;
 	fPilotStatusSocket=0L;
 
@@ -752,11 +956,13 @@ void KPilotInstaller::menuCallback(int item)
 	KPilotOptions* options = 0L;
 	CConduitSetup* conSetup = 0L;
 
+#ifdef DEBUG
 	if (debug_level & UI_TEDIOUS)
 	{
-		cerr << fname << ": Responding to callback " << item
+		kdDebug() << fname << ": Responding to callback " << item
 			<< endl;
 	}
+#endif
 
 	if ((item>=ID_COMBO) && 
 		(item<ID_COMBO+(int)fVisibleWidgetList.count()))
@@ -789,29 +995,38 @@ void KPilotInstaller::menuCallback(int item)
 		options = new KPilotOptions(this);
 		if (options==NULL)
 		{
-			cerr << fname << 
+			kdError() << __FUNCTION__ << 
 				": Can't allocate KPilotOptions object\n";
 			break;
 		}
 
+#ifdef DEBUG
 		if (debug_level & UI_MINOR)
 		{
-			cerr << fname << ": Running options dialog." 
+			kdDebug() << fname << ": Running options dialog." 
 				<< endl;
 		}
-		options->show();
+#endif
+		options->exec();
+#ifdef DEBUG
 		if (debug_level & UI_MINOR)
 		{
-			cerr << fname << ": dialog result "
-			<< options->result() << endl;
+			kdDebug() << fname << ": dialog result "
+				<< options->result() << endl;
 		}
+#endif
 
 		if (options->result())
 		{
+#ifdef DEBUG
 			if (debug_level & UI_TEDIOUS)
 			{
-				cerr << fname << ": Updating link." << endl;
+				kdDebug() << fname 
+					<< ": Updating link." << endl;
 			}
+#endif
+
+			readConfig(KPilotLink::getConfig());
 
 			// Update the link to reflect new settings.
 			//
@@ -826,12 +1041,14 @@ void KPilotInstaller::menuCallback(int item)
 			fPilotComponentList.current();
 			fPilotComponentList.next())
 			{
+#ifdef DEBUG
 				if (debug_level & UI_TEDIOUS)
 				{
-					cerr << fname 
+					kdDebug() << fname 
 						<< ": Updating components." 
 						<< endl;
 				}
+#endif
 
 				fPilotComponentList.current()->initialize();
 			}
@@ -839,10 +1056,12 @@ void KPilotInstaller::menuCallback(int item)
 
 		delete options;
 		options=NULL;
+#ifdef DEBUG
 		if (debug_level & UI_MINOR)
 		{
-			cerr << fname << ": Done with options." << endl;
+			kdDebug() << fname << ": Done with options." << endl;
 		}
+#endif
 		break;
 
 	case KPilotInstaller::ID_FILE_BACKUP:
@@ -853,19 +1072,29 @@ void KPilotInstaller::menuCallback(int item)
 		showTitlePage();
 		doRestore();
 		break;
+	case KPilotInstaller::ID_FILE_HOTSYNC :
+		showTitlePage();
+		doHotSync();
+		break;
+	case KPilotInstaller::ID_FILE_FASTSYNC :
+		showTitlePage();
+		doFastSync();
+		break;
 	case KPilotInstaller::ID_CONDUITS_SETUP:
 		showTitlePage();
 		conSetup = new CConduitSetup(this);
-		conSetup->show();
+		conSetup->exec();
 		delete conSetup;
 		break;
 	}
 
+#ifdef DEBUG
 	if (debug_level & UI_TEDIOUS)
 	{
-		cerr << fname << ": Done responding to item " << item
+		kdDebug() << fname << ": Done responding to item " << item
 			<< endl;
 	}
+#endif
 }
 
 void 
@@ -880,58 +1109,44 @@ KPilotInstaller::slotSyncDone(KProcess*)
   fStatusBar->changeItem(i18n("Hot-Sync complete."),0);
 }
 
-void 
-KPilotInstaller::testDir(QString name)
-    {
-	FUNCTIONSETUP;
-
-    DIR *dp = NULL;
-    dp = opendir(name.latin1());
-    if(dp == 0L)
-	{
-	::mkdir (name.latin1(), S_IRWXU);
-	}
-    else
-    	{
-	closedir( dp );
-	}
-    }
-    
+ 
 /* static */ const char *KPilotInstaller::version(int kind)
 {
   // I don't think the program title needs to be translated. (ADE)
   //
   //
   if (kind) 
-    return ::id;
+  {
+    return ::kpilot_id;
+    }
   else 
-    return "KPilot v4.0b";
+  {
+    return "KPilot v4.0.1";
+    }
 }
 
-static char authorsbuf[256]={0};
-/* static */ const char *KPilotInstaller::authors()
+// Command line options descriptions.
+//
+//
+//
+//
+static KCmdLineOptions kpilotoptions[] =
 {
-	if (!authorsbuf[0])
-	{
-		sprintf(authorsbuf,"%s%s",
-			"Dan Pilone, Adriaan de Groot\n",
-			i18n("and many others.").latin1());
-	}
-
-	return authorsbuf;
-}
-
-static struct option longOptions[]=
-{
-	{ "debug",1,0L,'d' },
-	{ "htmlhelp",0,0L, 2 },
-	{ "help",0,0L,1 },
-	{ "setup",0,0L,'s' },
-	{ 0L,0,0L,0 }
+	{ "setup", I18N_NOOP("Setup the Pilot device and other parameters"),0L },
+	{ "cs", I18N_NOOP("Run conduit setup"),0L },
+#ifdef DEBUG
+	{ "debug <level>", I18N_NOOP("Set debug level to <level> (try 1023)"),"0" },
+#endif
+	{ 0,0,0 }
 } ;
 
+
+
+
 // "Regular" mode == 0
-// setup mode == 1
+// setup mode == 's'
+// setup forced by config change == 'S'
+// conduit setup == 'c'
 //
 // This is only changed by the --setup flag --
 // kpilot still does a setup the first time it is run.
@@ -940,74 +1155,148 @@ static struct option longOptions[]=
 int run_mode=0;
 			 
 
-void handleOptions(int& argc, char **argv)
-{
-	FUNCTIONSETUP;
-	static const char *banner=
-		"KPilot v4.0b\n"
-		"Copyright (C) 1998,1999 Dan Pilone\n"
-		"Copyright (C) 2000 Dan Pilone, Adriaan de Groot\n\n";
-
-	int c,li;
-
-	while((c=getopt_long(argc,argv,"d:s",longOptions,&li))>0)
-	{
-		switch(c)
-		{
-		case 'd' : debug_level=atoi(optarg);
-			if (debug_level)
-			{
-				cerr << fname << ": Debug level set to "
-					<< debug_level << endl;
-			}
-			break;
-		case 's' : run_mode='s';
-			break;
-		case 2 : kapp->invokeHTMLHelp("kpilot/index.html", "");
-		case 1 : usage(banner,longOptions); exit(0);
-		default : usage(banner,longOptions); exit(1);
-		}
-	}
-}
-
-
 int main(int argc, char** argv)
 {
 	FUNCTIONSETUP;
 
-	// QStrList fileList;
         KAboutData about("kpilot", I18N_NOOP("KPilot"),
-                         "4.0b",
+                         "4.0b2",
                          "KPilot - Hot-sync software for unix\n\n",
                          KAboutData::License_GPL,
                          "(c) 1998-2000, Dan Pilone");
+	about.addAuthor("Dan Pilone",
+		I18N_NOOP("Project Leader"),
+		"pilone@slac.com",
+		"http://www.slac.com/pilone/kpilot_home/");
+	about.addAuthor("Adriaan de Groot",
+		I18N_NOOP("Maintainer"),
+		"adridg@cs.kun.nl",
+		"http://www.cs.kun.nl/~adridg/kpilot/");
+	about.addAuthor("Heiko Purnhagen",
+		I18N_NOOP("Bugfixer"),
+		"purnhage@tnt.uni-hannover.de");
+
 
         KCmdLineArgs::init(argc, argv, &about);
-	KApplication a;
-	handleOptions(argc,argv);
+	KCmdLineArgs::addCmdLineOptions(kpilotoptions);
+	KApplication::addCmdLineOptions();
+	KCmdLineArgs *p=KCmdLineArgs::parsedArgs();
 
-	if (run_mode=='s')
+#ifdef DEBUG
+	debug_level=atoi(p->getOption("debug"));
+#endif
+	if (p->isSet("setup")) { run_mode='s'; } 
+	if (p->isSet("cs")) { run_mode='c'; }
+
+	KApplication a(true,true);
+
+	KConfig& c=KPilotLink::getConfig();
+	(void)KPilotLink::getDebugLevel(c);
+	if (KPilotLink::getConfigVersion(c)<KPilotLink::ConfigurationVersion)
 	{
-		if (debug_level & UI_MAJOR)
-		{
-			cerr << fname << ": Running setup first."
-				<< " (mode " << run_mode << ')'
-				<< endl ;
-		}
+		run_mode='S';
+	}
 
-		KPilotOptions* options = new KPilotOptions(0L);
-		options->show();
-		if (! options->result())
+	if (run_mode=='c')
+	{
+		CConduitSetup *cs = new CConduitSetup(0L);
+		int r = cs->exec();
+		if (r)
+		{
+			return 1;	// Dialog cancelled
+		}
+		else
 		{
 			return 0;
 		}
 	}
 
+	if ((run_mode=='s') || (run_mode=='S'))
+	{
+#ifdef DEBUG
+		if (debug_level & UI_MAJOR)
+		{
+			kdDebug() << fname << ": Running setup first."
+				<< " (mode " << run_mode << ")"
+				<< endl ;
+		}
+#endif
+
+		KPilotOptions* options = new KPilotOptions(0L);
+		int r = options->exec();
+
+		if (run_mode=='s')
+		{
+			if (r)
+			{
+				return 1;
+			}
+			else
+			{
+				return 0;
+			}
+		}
+
+		if (r) return 1;
+			
+
+		// The options dialog may have changed the group
+		// while reading or writing settings (still a
+		// bad idea, actually).
+		//
+		c.setGroup(QString::null);
+	}
+
+	if (KPilotLink::getConfigVersion(c)<KPilotLink::ConfigurationVersion)
+	{
+		kdWarning() << __FUNCTION__ << ": Is still not configured for use."
+			<< endl;
+		return 1;
+	}
 
         KPilotInstaller *tp = new KPilotInstaller();
 
+	if (tp->status() == KPilotInstaller::Error)
+	{
+		delete tp;
+		tp=0;
+		return 1;
+	}
+
         KGlobal::dirs()->addResourceType("pilotdbs", "share/apps/kpilot/DBBackup");
 	a.setMainWidget(tp);
 	return a.exec();
 }
 
+
+// $Log: kpilot.cc,v $
+// Revision 1.36  2001/02/08 17:59:34  adridg
+// Removed spurious #ifdefs, and the #define that goes with it. Make KPilot exit consistently after user-requested setup actions.
+//
+// Revision 1.35  2001/02/08 13:17:19  adridg
+// Fixed crash when conduits run during a backup and exit after the
+// end of that backup (because the event loop is blocked by the backup
+// itself). Added better debugging error exit message (no i18n needed).
+//
+// Revision 1.34  2001/02/08 08:13:44  habenich
+// exchanged the common identifier "id" with source unique <sourcename>_id for --enable-final build
+//
+// Revision 1.33  2001/02/05 20:58:48  adridg
+// Fixed copyright headers for source releases. No code changed
+//
+// Revision 1.32  2001/02/05 19:16:32  adridg
+// Removing calls to exit() from internal functions
+//
+// Revision 1.31  2001/02/05 11:19:18  adridg
+// Reduced icon-loading code to hard-coded xpms
+//
+// Revision 1.30  2001/01/19 22:18:43  waba
+// KTMainWindow is obsolete. I hope it works because I can't test due to lack of
+// pilot. At least it compiles.
+//
+// Revision 1.29  2001/01/06 13:21:53  adridg
+// Updated version number
+//
+// Revision 1.28  2001/01/03 00:02:45  adridg
+// Added Heiko's FastSync
+//
