@@ -1,15 +1,30 @@
-// kpilot.h
-//
-// Copyright (C) 1998,1999 Dan Pilone
-// Copyright (C) 2000 Adriaan de Groot
-//
-// This file is distributed under the Gnu General Public Licence (GPL).
-// The GPL should have been included with this file in a file called
-// COPYING.
-//
+/* kpilot.h			KPilot
+**
+** Copyright (C) 1998-2001 by Dan Pilone
+**
+** This is the main program in KPilot.
+*/
 
-// $Revision: 1.5 $
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, 
+** MA 02139, USA.
+*/
 
+/*
+** Bug reports and questions can be sent to adridg@cs.kun.nl
+*/
 #ifndef __KPILOT_H
 #define __KPILOT_H
 
@@ -17,10 +32,11 @@
 #include <qmenubar.h>
 #include <qlist.h>
 #include <qpopmenu.h>
+#include <qpixmap.h>
 
 #include <kapp.h>
 #include <klocale.h>
-#include <ktmainwindow.h>
+#include <kmainwindow.h>
 #include <kprogress.h>
 #include <kprocess.h>
 
@@ -35,7 +51,7 @@ class QComboBox;
 
 
 
-class KPilotInstaller : public KTMainWindow
+class KPilotInstaller : public KMainWindow
     {
     Q_OBJECT
 
@@ -50,12 +66,6 @@ class KPilotInstaller : public KTMainWindow
 	* id of kpilot.o
 	*/
 	static const char *version(int kind);
-	/**
-	* Return a string with names of KPilot authors.
-	* @see version
-	*/
-	static const char *authors();
-
 
 	/**
 	* Set the main widget to showing the kpilot
@@ -63,21 +73,27 @@ class KPilotInstaller : public KTMainWindow
 	* the component list -- the logo always remains and
 	* can hide whatever is going on in the background.
 	*/
-	void showTitlePage();
+	void showTitlePage(const QString& statusMsg=QString::null,
+		bool force=false);
+
+	/**
+	* Returns the user's preference for the system-wide
+	* fixed font.
+	*/
+	const QFont& fixed() const { return fixedFont; }  ;
 
-    void testDir(QString name);
     bool getQuitAfterCopyComplete() const { return fQuitAfterCopyComplete; }
     // Adds 'name' to the pull down menu of components
     void addComponentPage(QWidget* widget, QString name);
 
 
-	/**
-	* This number can be changed every time a new
-	* KPilot version is released that absolutely requires
-	* the user to take a look at the configuration of
-	* KPilot.
-	*/
-	static const int ConfigurationVersion;
+	typedef enum { Normal,
+		Startup,
+		WaitingForDaemon,
+		UIBusy,
+		Error } Status ;
+
+	Status status() const { return fStatus; } ;
 
     protected:
       void closeEvent(QCloseEvent *e);
@@ -98,22 +114,52 @@ class KPilotInstaller : public KTMainWindow
 protected:
 	int testSocket(KSocket *);
 
+	void readConfig(KConfig&);
+
+
+	void setupSync(int kind,const QString& msg);
+	void doHotSync() 
+	{ 
+		setupSync(KPilotLink::HotSync,
+			i18n("Hot-Syncing. ")+
+			i18n("Please press the hot-sync button."));
+	}
+	void doFastSync()
+	{ 
+		setupSync(KPilotLink::FastSync,
+			i18n("Fast-Syncing. ")+
+			i18n("Please press the hot-sync button."));
+	}
+
 private:
+      void initIcons();
       void initMenu();
       void initStatusBar();
       void initToolBar();
       void setupWidget();
       void initComponents();
       
-      static const int ID_FILE_QUIT;
-      static const int ID_FILE_SETTINGS;
-      static const int ID_FILE_BACKUP;
-      static const int ID_FILE_RESTORE;
-      static const int ID_HELP_ABOUT;
-      static const int ID_HELP_HELP;
-      static const int ID_CONDUITS_ENABLE;
-      static const int ID_CONDUITS_SETUP;
-      static const int ID_COMBO;
+	/**
+	* These are constants used in the KPilotInstaller code.
+	* Most of them are IDs for UI elements. ID_FILE_QUIT is a big
+	* number (compared to ID_COMBO) because elements that are
+	* inserted into the combo box get numbers counting from
+	* ID_COMBO+1, so we need room for all those numbers. 998
+	* internal conduits seems like plenty.
+	*/
+	typedef enum { 
+		ID_COMBO=1,
+		ID_FILE_QUIT=1000,
+		ID_FILE_SETTINGS,
+		ID_FILE_BACKUP,
+		ID_FILE_RESTORE,
+		ID_FILE_HOTSYNC,
+		ID_FILE_FASTSYNC,
+		ID_HELP_ABOUT,
+		ID_HELP_HELP,
+		ID_CONDUITS_ENABLE,
+		ID_CONDUITS_SETUP 
+		} Constants ;
       
       KMenuBar*       fMenuBar;
       KStatusBar*     fStatusBar;
@@ -129,6 +175,8 @@ private:
       char            fLinkCommand[10000];
       int             fLastWidgetSelected;
 
+      Status fStatus;
+
 	/**
 	* We keep track of this one (conduitMenu)
 	* because the various builtin conduits
@@ -146,10 +194,13 @@ private:
 	*/
 	QComboBox	*conduitCombo;
 
+	QPixmap	icon_hotsync,icon_backup,icon_fastsync,icon_restore,
+		icon_quit;
+	QFont fixedFont;
+
  protected slots:
       void menuCallback(int);
       void quit();
-      void doHotSync();
       void fileInstalled(int which);
       void slotModeSelected(int selected);
       void slotSyncDone(KProcess* which);
@@ -163,3 +214,9 @@ private:
 
  
 #endif
+
+
+// $Log: kpilot.h,v $
+// Revision 1.16  2001/02/06 08:05:19  adridg
+// Fixed copyright notices, added CVS log, added surrounding #ifdefs. No code changes.
+//
