@@ -1,20 +1,36 @@
-// kpilotLink.h
-//
-// Copyright (C) 1998,1999,2000 Dan Pilone
-//
-// This file is distributed under the Gnu General Public Licence (GPL).
-// The GPL should have been included with this file in a file called
-// COPYING. 
-//
-// This is the version of kpilotLink.h for KDE2 / KPilot 4.
-//
-//
+/* kpilotlink.h			KPilot
+**
+** Copyright (C) 1998-2001 by Dan Pilone
+**
+** This is a horrible class that implements three different
+** functionalities and that should be split up as soon as 2.1 
+** is released. See the .cc file for more.
+*/
 
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, 
+** MA 02139, USA.
+*/
+
+/*
+** Bug reports and questions can be sent to adridg@cs.kun.nl
+*/
 
 #ifndef __KPILOT_LINK
 #define __KPILOT_LINK
 
-#if (QT_VERSION > 199)
 #include <qobject.h>
 
 class QWidget;
@@ -28,28 +44,13 @@ class KProcess;
 class PilotRecord;
 class MessageDialog;
 
-#include "pilotUser.h"
-// #include "pi-file.h"
-#include "pilotDatabase.h"
-#include "pilotSerialDatabase.h"
-#include "pilotLocalDatabase.h"
+class PilotSerialDatabase;
+class PilotLocalDatabase;
 
-#else
-#include <qobject.h>
-#include <qlist.h>
-#include <kurl.h>
-#include <kstatusbar.h>
-#include <kprogress.h>
-#include <kapp.h>
-#include <kprocess.h>
-#include <ksock.h>
 #include "pilotUser.h"
-#include "pi-file.h"
 #include "pilotDatabase.h"
 #include "pilotSerialDatabase.h"
 #include "pilotLocalDatabase.h"
-#include "messageDialog.h"
-#endif
 
 /**
   * This class is an attempt to provide some wrapper around the pilot-link
@@ -73,8 +74,16 @@ class KPilotLink : public QObject
   Q_OBJECT
   
   friend class PilotSerialDatabase;
-  
+
 public:
+	/**
+	* This number can be changed every time a new
+	* KPilot version is released that absolutely requires
+	* the user to take a look at the configuration of
+	* KPilot.
+	*/
+	static const int ConfigurationVersion;
+
   /**
    * Used for opening local databases only.
    */
@@ -85,18 +94,17 @@ public:
    * devicePath = path to serial port.  Defaults to /dev/pilot
    */
   KPilotLink(QWidget* owner, KStatusBar* statusBar = 0L, 
-#ifdef KDE2
 		const QString &devicePath = QString::null);
-#else
-		const QString &devicePath = QString());
-#endif
   ~KPilotLink();
   
   /**
    * Commands sent from KPilot requesting the daemon
    * to perform those actions.
    */
-  enum Commands { Backup, Restore, HotSync, InstallFile, TestConnection };
+	enum Commands { Backup, Restore, 
+		HotSync, FastSync,
+		InstallFile, TestConnection 
+		};
   
   /**
    * Static method to get the current link..
@@ -126,7 +134,8 @@ public:
   /**
    * Changes the path (port) that the link should work with.
    */
-  void changePilotPath(const char* devicePath) { initPilotSocket(devicePath); }
+  void changePilotPath(const QString& devicePath) 
+	{ initPilotSocket(devicePath); }
 
   /**
    * This is merely a flag for any widget that should run.  Will be set by KPilot when doing
@@ -138,7 +147,10 @@ public:
    * Returns the whether the widget should do a full or partial backup.  Mostly obsolete now
    * that conduits are being used.
    */
-  bool slowSyncRequired() { return fSlowSyncRequired; }
+  bool slowSyncRequired() const { return fSlowSyncRequired; }
+
+  void setFastSyncRequired(bool yesno) { fFastSyncRequired = yesno; } 
+  bool fastSyncRequired() const { return fFastSyncRequired; } 
   
   /**
    * Backups all databases to BACKUP_DIR/username
@@ -184,16 +196,40 @@ public:
 	*
 	* Callers should delete this object when no longer needed.
 	*/
-#ifdef KDE2
-	static KConfig *getConfig(const QString &group=QString::null);
-#else
-	static KConfig *getConfig(const QString &group=QString());
-#endif
+	static KConfig& getConfig(const QString &group=QString::null);
+
+	/**
+	* Reads the configuration version from a standard location.
+	*/
+	static int getConfigVersion(KConfig *);
+	static int getConfigVersion(KConfig&);
+
+	/**
+	* We might have an additional Debug= line in their
+	* config which may be read and ORed with the user-specified
+	* debug level. This function does that. 
+	*
+	* @ret resulting debug level
+	*/
+	static int getDebugLevel(KConfig&,const QString& group=QString::null);
 
 private:
+	/**
+	* For initializing the link: read the configuration
+	* file and save vital information from there.
+	*/
+	void readConfig();
+
   PilotRecord* readRecord(KSocket*);
   void writeRecord(KSocket*, PilotRecord*);
 
+	/**
+	* Write a single-word response message to the command
+	* connection. This is typically used to respond to 
+	* requests from conduits. Pass one of the CStatusMessages.
+	*/
+	int writeResponse(KSocket *, int m);
+
   /**
    * Starts syncing the next (could be first) database, either by firing up a conduit, or
    * by using syncDatabase() to back it up into the BACKUP_DIR.  Uses
@@ -202,13 +238,40 @@ private:
 	int findNextDB(struct DBInfo *);
   void syncNextDB();
   void doConduitBackup();
+	/**
+	* This function is called by slotConduitCLosed and
+	* some other places to resume processing of databases
+	* for a backup or sync.
+	*/
+	void resumeDB();
+
+	/**
+	* When the sync is done (or the backup, or whatever ...)
+	* call this function to cleanup and emit done signals.
+	*/
+	void finishDatabaseSync();
+
+
+public:
+	typedef enum { Normal, PilotLinkError } Status ;
+
+	Status status() const { return fStatus; } ;
 
 public slots:
   void slotConduitRead(KSocket*);
   void slotConduitClosed(KSocket*);
   void slotConduitConnected(KSocket*);
+	void slotConduitDone(KProcess *);
  /* END CONDUIT SYNCING SUPPORT */
 
+private:
+	/**
+	* This is en enum listing the states that a running conduit
+	* may be in. This is used to detect conduits that crash or
+	* otherwise misbehave.
+	*/
+	enum { None = 0 , Running, Connected, Done } fConduitRunStatus ;
+
 public:
   /**
    * Opens database "database" on Pilot and returns the id to reference it:
@@ -285,11 +348,12 @@ private:
 
   int compare(struct db* d1, struct db* d2); // Compares two database infos..
   void initConduitSocket();         // Sets up fConduitSocket
-  void initPilotSocket(const char* devicePath);
+  void initPilotSocket(const QString& devicePath, bool inetconnection=false);
 
   int         fPilotMasterSocket;   // This is the master one created with the class
   int         fCurrentPilotSocket;  // This changes with each connect()/disconnect()
   bool        fSlowSyncRequired;
+	bool fFastSyncRequired;
   QWidget*    fOwningWidget;
   KStatusBar* fStatusBar;           // Optional
   QDialog*    fProgressDialog;
@@ -301,6 +365,9 @@ private:
   int         fNextDBIndex;         // The next DB to sync
   KProcess*    fConduitProcess;
   MessageDialog* fMessageDialog;    // The dialog showing current status
+
+	Status fStatus;
+
 signals:
   void databaseSyncComplete();
   void syncingDatabase(char*);
@@ -309,3 +376,14 @@ signals:
 };
 
 #endif
+
+
+// $Log: kpilotlink.h,v $
+// Revision 1.18  2001/02/08 13:17:19  adridg
+// Fixed crash when conduits run during a backup and exit after the
+// end of that backup (because the event loop is blocked by the backup
+// itself). Added better debugging error exit message (no i18n needed).
+//
+// Revision 1.17  2001/02/06 08:05:19  adridg
+// Fixed copyright notices, added CVS log, added surrounding #ifdefs. No code changes.
+//
