@@ -1,26 +1,33 @@
-// memoWidget.cc
-//
-// Copyright (C) 1998,1999 Dan Pilone
-//
-// This file is distributed under the Gnu General Public Licence (GPL).
-// The GPL should have been included with this file in a file called
-// COPYING. 
+/* memoWidget.cc			KPilot
+**
+** Copyright (C) 1998-2001 by Dan Pilone
+**
+** This is the memo-viewing widget (internal conduit) used by KPilot.
+*/
 
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, 
+** MA 02139, USA.
+*/
 
+/*
+** Bug reports and questions can be sent to adridg@cs.kun.nl
+*/
+static const char *memowidget_id="$Id: memoWidget.cc,v 1.23.2.1 2001/03/05 23:45:50 adridg Exp $";
 
-// REVISION HISTORY 
-//
-// 3.1b9	By Dan Pilone
-// 3.1b10	By Adriaan de Groot: comments added all over the place,
-//		added "all" category. Started code-layout war by imposing
-//		my own layout style. Added many robustness checks and
-//		errors (to stderr).
-//
-//		Remaining questions are marked with QADE.
-
-static const char *id="$Id: memoWidget.cc,v 1.7 2000/08/28 12:22:03 pilone Exp $";
-
-
+#include "options.h"
 
 #include <time.h>
 #include <iostream.h>
@@ -31,15 +38,15 @@ static const char *id="$Id: memoWidget.cc,v 1.7 2000/08/28 12:22:03 pilone Exp $
 #include <qlistbox.h>
 #include <qfile.h>
 #include <qpushbt.h>
+#include <qlayout.h>
 #include <kapp.h>
 #include <kmessagebox.h>
 #include <kfiledialog.h>
-#include <kdebug.h>
 
 #include "kpilot.h"
-#include "options.h"
+#include "listItems.h"
 #include "memoWidget.moc"
-#include "pi-dlp.h"
+#include <pi-dlp.h>
 
 // QADE: Is this a Pilot limitation, or is it a KPilot limitation?
 int MemoWidget::MAX_MEMO_LEN = 8192;
@@ -65,7 +72,9 @@ MemoWidget::MemoWidget(KPilotInstaller* installer, QWidget* parent)
 	setupWidget();
 	initialize();
 	fMemoList.setAutoDelete(true);
+	fTextWidget->setFont(installer->fixed());
 	installer->addComponentPage(this, "Memos");
+	slotUpdateButtons();
 }
 
 MemoWidget::~MemoWidget()
@@ -74,45 +83,6 @@ MemoWidget::~MemoWidget()
 
 }
 
-// void MemoWidget::initializeCategories(PilotDatabase *memoDB)
-//
-// Fill up the categories combobox with a list of all the
-// categories available on the Pilot.
-//
-void MemoWidget::initializeCategories(PilotDatabase *memoDB)
-{
-	FUNCTIONSETUP;
-
-	int i;
-	fCatList->clear();
-	// Get all the category names. The "All" category isn't
-	// in the list of category names, so add it here by
-	// hand.
-	//
-	//
-	fCatList->insertItem(i18n("All"));
-
-	unsigned char buffer[PILOT_BUFFER_SIZE];
-
-	int appLen = memoDB->readAppBlock(buffer, sizeof(buffer));
-	unpack_MemoAppInfo(&fMemoAppInfo, buffer, appLen);
-
-	for(i = 0; i < 15; i++)
-	{
-		if(strlen(fMemoAppInfo.category.name[i]))
-		{
-			fCatList->insertItem(fMemoAppInfo.category.name[i]);
-			if (debug_level & UI_MINOR)
-			{
-				kdDebug() << fname << 
-					": Added category " <<
-					i << '=' <<
-					fMemoAppInfo.category.name[i] <<
-					'\n' ;
-			}
-		}
-	}
-}
 
 // void MemoWidget::initializeMemos(PilotDatabase *memoDB)
 //
@@ -151,6 +121,7 @@ MemoWidget::initializeMemos(PilotDatabase *memoDB)
 			{
 				memo = new PilotMemo(pilotRec);
 				fMemoList.append(memo);
+#ifdef DEBUG
 				if (debug_level & UI_TEDIOUS)
 				{
 					kdDebug() << fname <<
@@ -158,25 +129,30 @@ MemoWidget::initializeMemos(PilotDatabase *memoDB)
 						<< currentRecord
 						<< endl ;
 				}
+#endif
 			}
 			else
 			{
+#ifdef DEBUG
 				if (debug_level&UI_TEDIOUS)
 				{
 					kdDebug() << fname <<
 						": Skipped secret record " <<
 						currentRecord << endl ;
 				}
+#endif
 			}
 		}
 		else
 		{
+#ifdef DEBUG
 			if (debug_level&UI_TEDIOUS)
 			{
 				kdDebug() << fname << 
 					": Skipped deleted record " <<
 					currentRecord << endl ;
 			}
+#endif
 		}
 
 		delete pilotRec;
@@ -199,14 +175,22 @@ MemoWidget::initialize()
 		KPilotLink::getPilotLink()->openLocalDatabase("MemoDB");
 	if (memoDB==NULL || !memoDB->isDBOpen())
 	{
-		kdDebug() << fname << 
+		kdWarning() << __FUNCTION__ << 
 			": Can't open local database MemoDB\n" ;
 
+		populateCategories(fCatList,0L);
 		updateWidget();
 		return;
 	}
 
-	initializeCategories(memoDB);
+	// Normal case: there is a database so we can read it
+	// and determine all the categories.
+	//
+	unsigned char buffer[PILOT_BUFFER_SIZE];
+	int appLen = memoDB->readAppBlock(buffer, sizeof(buffer));
+	unpack_MemoAppInfo(&fMemoAppInfo, buffer, appLen);
+
+	populateCategories(fCatList,&fMemoAppInfo.category);
 	initializeMemos(memoDB);
 
 	KPilotLink::getPilotLink()->closeDatabase(memoDB);
@@ -232,6 +216,10 @@ MemoWidget::saveData()
 {
 	FUNCTIONSETUP;
 	return true;
+#ifdef DEBUG
+	/* NOTREACHED */
+	(void) memowidget_id;
+#endif
 }
 
 
@@ -239,9 +227,6 @@ MemoWidget::saveData()
 //
 // Setup all the GUI components by allocating them. 
 //
-// QADE: I don't like all these new() calls without checks -- unless
-// Qt provides a new() that throws exceptions when new() fails to allocate
-// enough memory.
 //
 void
 MemoWidget::setupWidget()
@@ -250,39 +235,60 @@ MemoWidget::setupWidget()
 
 	QLabel *label=NULL;
 	QPushButton *button=NULL;
+	QGridLayout *grid = new QGridLayout(this,5,4,SPACING);
 
 	fCatList = new QComboBox(this);
-	fCatList->move(110, 25);
+	grid->addWidget(fCatList,0,1);
 	connect(fCatList, SIGNAL(activated(int)), 
 		this, SLOT(slotSetCategory(int)));
 
 	label = new QLabel(i18n("Memos:"), this);
-	label->move(10, 30);
+	label->setBuddy(fCatList);
+	grid->addWidget(label,0,0);
 
 	fListBox = new QListBox(this);
-	fListBox->setGeometry(10, 60, 200, 150);
+	grid->addMultiCellWidget(fListBox,1,1,0,1);
 	connect(fListBox, SIGNAL(highlighted(int)), 
 		this, SLOT(slotShowMemo(int)));
+	connect(fListBox, SIGNAL(selectionChanged()),
+		this, SLOT(slotUpdateButtons()));
 
 	label = new QLabel(i18n("Memo Text:"), this);
-	label->move(290, 0);
+	grid->addWidget(label,0,2);
 
 	fTextWidget = new QMultiLineEdit(this, "textArea");
-	fTextWidget->setGeometry(230, 30, 260, 290);
+	grid->addMultiCellWidget(fTextWidget,1,4,2,2);
 	connect(fTextWidget, SIGNAL(textChanged()), 
 		this, SLOT(slotTextChanged()));
 
 	button = new QPushButton(i18n("Import Memo"), this);
-	button->move(10, 220);
+	grid->addWidget(button,2,0);
 	connect(button, SIGNAL(clicked()), this, SLOT(slotImportMemo()));
 
-	button = new QPushButton(i18n("Export Memo"), this);
-	button->move(110, 220);
-	connect(button, SIGNAL(clicked()), this, SLOT(slotExportMemo()));
+	fExportButton = new QPushButton(i18n("Export Memo"), this);
+	grid->addWidget(fExportButton,2,1);
+	connect(fExportButton, SIGNAL(clicked()), this, SLOT(slotExportMemo()));
 
-	button = new QPushButton(i18n("Delete Memo"), this);
-	button->move(60, 250);
-	connect(button, SIGNAL(clicked()), this, SLOT(slotDeleteMemo()));
+	fDeleteButton = new QPushButton(i18n("Delete Memo"), this);
+	grid->addWidget(fDeleteButton,3,0);
+	connect(fDeleteButton, SIGNAL(clicked()), this, SLOT(slotDeleteMemo()));
+}
+
+void
+MemoWidget::slotUpdateButtons()
+{
+	FUNCTIONSETUP;
+
+	int item = fListBox->currentItem();
+
+	if (fExportButton)
+	{
+		fExportButton -> setEnabled(item != -1);
+	}
+	if (fDeleteButton)
+	{
+		fDeleteButton -> setEnabled(item != -1);
+	}
 }
 
 void 
@@ -301,27 +307,28 @@ MemoWidget::slotDeleteMemo()
 
 	if(item == -1)
 	{
+#ifdef DEBUG
 		kdDebug() << fname <<
 			": No current item selected\n" ;
+#endif
 		return;
 	}
 
-	item = fLookupTable[item];
-	if(fMemoList.at(item)->id() == 0x0)
+	PilotListItem *p = (PilotListItem *)fListBox->item(item);
+	PilotMemo *memo = (PilotMemo *)p->rec();
+
+	if(memo->id() == 0x0)
 	{
 		// QADE: Why is this? What prevents us from deleting
 		// a "new" memo, ie. one we've imported, before *ever*
 		// sending it to the Pilot?
 		//
 		//
-		if (debug_level)
-		{
-			kdDebug() << fname <<
-				": Refusing to delete new memo.\n";
-		}
+		kdWarning() << __FUNCTION__ <<
+			": Refusing to delete new memo.\n";
 
 		KMessageBox::error(this, i18n("Hot-Sync Required"), 
-			i18n("Cannot delete new memo until \r\n" 
+			i18n("Cannot delete new memo until \n" 
 				"Hot-Synced with pilot."));
 		return;
 	}
@@ -331,15 +338,16 @@ MemoWidget::slotDeleteMemo()
 				      i18n("Delete currently selected memo?"),
 				      i18n("Delete Memo?")) == KMessageBox::No)
 	{
+#ifdef DEBUG
 		if (debug_level)
 		{
 			kdDebug() << fname <<
 				": Used decided not to delete memo.\n" ;
 		}
+#endif
 		return;
 	}
 
-	PilotMemo* memo = fMemoList.at(item);
 	// QADE: Apparently a PilotMemo is not some kind of PilotRecord,
 	// so the PilotRecord methods don't work on it.
 	//
@@ -350,6 +358,7 @@ MemoWidget::slotDeleteMemo()
 	initialize();
 }
 
+
 void
 MemoWidget::updateWidget()
 {
@@ -357,88 +366,16 @@ MemoWidget::updateWidget()
 
 	if (fCatList->currentItem()==-1)
 	{
-		kdDebug() << fname <<
+		DEBUGKPILOT << fname <<
 			": No category selected.\n";
 		return ;
 	}
 
 	int listIndex = 0;
 	int currentEntry = 0;
+	int currentCatID = findSelectedCategory(fCatList,
+		&(fMemoAppInfo.category),false);
 
-	// Semantics of currentCatID are: 
-	//
-	// >=0 is a specific category based on the text -> category number 
-	// 	mapping defined by the Pilot, 
-	// ==-1 means "All" category selected.
-	//
-	//
-	int currentCatID = 0;
-
-	// If a category is deleted after others have been added, none of the
-	// category numbers are changed.  So we need to find the category number
-	// for this category (this category is represented by the selected
-	// *text*).
-	//
-	//
-	// The top entry in the list is "All", so if the top item is
-	// selected we can indicate that we are using the "All" category.
-	//
-	//
-	if (fCatList->currentItem()==0)
-	{
-		currentCatID=-1;
-		if (debug_level&UI_MINOR)
-		{
-			kdDebug() << fname <<
-				": Category 'All' selected.\n" ;
-		}
-	}
-	else
-	{
-		QString selectedCategory=fCatList->text(fCatList->currentItem());
-		if (debug_level&UI_MINOR)
-		{
-			kdDebug() << fname << 
-				": List item " << fCatList->currentItem() <<
-				" selected, text=" <<
-				selectedCategory << '\n' ;
-		}
-
-		currentCatID=0;
-		while(strcmp(fMemoAppInfo.category.name[currentCatID], 
-		       selectedCategory.latin1()) && 
-			(currentCatID < fCatList->count()))
-		{
-			if (debug_level&UI_TEDIOUS)
-			{
-				kdDebug() << fname <<
-					": Didn't match category " <<
-					currentCatID << '=' <<
-					fMemoAppInfo.category.name[currentCatID]
-					<< '\n' ;
-			}
-
-			currentCatID++;
-		}
-
-		if (currentCatID < fCatList->count())
-		{
-			if (debug_level&UI_MINOR)
-			{
-				kdDebug() << fname << 
-					": Matched category " <<
-					currentCatID << '=' <<
-					fMemoAppInfo.category.name[currentCatID]
-					<< '\n' ;
-			}
-		}
-		else
-		{
-			kdDebug() << fname << ": Selected category didn't match "
-				"any name!\n" ;
-			currentCatID=-1;
-		}
-	}
 
 	fListBox->clear();
 	fMemoList.first();
@@ -454,24 +391,35 @@ MemoWidget::updateWidget()
 		if((fMemoList.current()->getCat() == currentCatID) ||
 			(currentCatID==-1))
 		{
-			// List will delete it.
-			fListBox->insertItem(fMemoList.current()->getTitle());
-			fLookupTable[currentEntry++] = listIndex;
+			// List will delete the title of the memo,
+			// so there's no memory leak here.
+			//
+			//
+			PilotListItem *p = new PilotListItem(
+				fMemoList.current()->shortTitle(),
+				listIndex,
+				fMemoList.current());
+
+			fListBox->insertItem(p);
+#ifdef DEBUG
 			if (debug_level & UI_TEDIOUS)
 			{
 				kdDebug() << fname << ": Added memo "
 					<< fMemoList.current()->getTitle()
 					<< endl;
 			}
+#endif
 		}
 		else
 		{
+#ifdef DEBUG
 			if (debug_level & UI_TEDIOUS)
 			{
 				kdDebug() << fname << ": Skipped memo "
 					<< fMemoList.current()->getTitle()
 					<< endl;
 			}
+#endif
 		}
 
 		listIndex++;
@@ -479,6 +427,8 @@ MemoWidget::updateWidget()
 	}
 
 	fTextWidget->clear();
+
+	slotUpdateButtons();
 }
 
 void
@@ -486,8 +436,11 @@ MemoWidget::slotShowMemo(int which)
 {      
   disconnect(fTextWidget, SIGNAL(textChanged()), this, SLOT(slotTextChanged()));
   fTextWidget->deselect();
-  fTextWidget->setText(fMemoList.at(fLookupTable[which])->text());
+	PilotListItem *p = (PilotListItem *)fListBox->item(which);
+	PilotMemo * theMemo = (PilotMemo *)p->rec();
+	fTextWidget->setText(theMemo->text());
   connect(fTextWidget, SIGNAL(textChanged()), this, SLOT(slotTextChanged()));
+	
 }
 
 void
@@ -506,15 +459,16 @@ void
 MemoWidget::slotTextChanged()
 {
   FUNCTIONSETUP;
-  PilotMemo* currentMemo;
 
   if(fListBox->currentItem() >= 0)
     {
-      currentMemo = fMemoList.at(fLookupTable[fListBox->currentItem()]);
+	PilotListItem *p = (PilotListItem *)fListBox->item(
+		fListBox->currentItem());
+	PilotMemo* currentMemo = (PilotMemo *)p->rec();
       if(currentMemo->id() == 0x0)
 	{
 	  KMessageBox::error(0L,
-			     i18n("Cannot edit new memo until \r\n Hot-Synced with pilot."), 
+			     i18n("Cannot edit new memo until \n Hot-Synced with pilot."), 
 			     i18n("Hot-Sync Required"));
 	  slotShowMemo(fListBox->currentItem());
 	  return;
@@ -530,20 +484,9 @@ MemoWidget::slotImportMemo()
     FUNCTIONSETUP;
     int i = 0;
     int nextChar;
-    int currentCatID = -1;
+	int currentCatID = findSelectedCategory(fCatList,
+		&(fMemoAppInfo.category),true);
   
-    // If a category is deleted after others have been added, none of the
-    // category numbers are changed.  So we need to find the category number
-    // for this category.
-    char notFound = 1;
-    while (notFound)
-      {
-	currentCatID++;
-	if (fMemoAppInfo.category.name[currentCatID])
-	  notFound = strcmp(fMemoAppInfo.category.name[currentCatID],
-			    fCatList->text(fCatList->currentItem()).latin1());
-      }
-
     QString fileName = KFileDialog::getOpenFileName();
     if(fileName != NULL)
 	{
@@ -553,7 +496,7 @@ MemoWidget::slotImportMemo()
 	    // show error!
 	    return;
 	    }
-	char text[MemoWidget::MAX_MEMO_LEN];
+	char *text = new char[MemoWidget::MAX_MEMO_LEN];
 	for(i = 0; (i < (MemoWidget::MAX_MEMO_LEN - 1)) && ((nextChar = importFile.getch()) != -1); i++)
 	    text[i] = nextChar;
 	text[i] = 0;
@@ -561,6 +504,7 @@ MemoWidget::slotImportMemo()
 	fMemoList.append(aMemo);
 	writeMemo(aMemo);
 	updateWidget();
+	delete[] text;
 	}
     }
 
@@ -573,12 +517,15 @@ MemoWidget::slotExportMemo()
 
     if(item == -1)
 	return;
-    item = fLookupTable[item];
+
+	PilotListItem *p = (PilotListItem *)fListBox->item(item);
+	PilotMemo* theMemo = (PilotMemo *)p->rec();
+
     QString fileName = KFileDialog::getSaveFileName();
     if(fileName == 0L)
 	return;
 
-    data = fMemoList.at(item)->text();
+    data = theMemo->text();
 
     QFile outFile(fileName);
     if(outFile.open(IO_WriteOnly | IO_Truncate) == FALSE)
@@ -590,3 +537,18 @@ MemoWidget::slotExportMemo()
     outStream.writeRawBytes(data, strlen(data) + 1);
     outFile.close();
     }
+
+// $Log: memoWidget.cc,v $
+// Revision 1.23.2.1  2001/03/05 23:45:50  adridg
+// Backport of bugfix for #21392
+//
+// Revision 1.23  2001/02/08 08:13:44  habenich
+// exchanged the common identifier "id" with source unique <sourcename>_id for --enable-final build
+//
+// Revision 1.22  2001/02/07 14:21:43  brianj
+// Changed all include definitions for libpisock headers
+// to use include path, which is defined in Makefile.
+//
+// Revision 1.21  2001/02/05 20:58:48  adridg
+// Fixed copyright headers for source releases. No code changed
+//
