@@ -1,22 +1,34 @@
-// pilotDaemon.cc
-//
-// Copyright (C) 1998,1999 Dan Pilone
-//
-// This file is distributed under the Gnu General Public Licence (GPL).
-// The GPL should have been included with this file in a file called
-// COPYING. 
+/* pilotDaemon.cc			KPilot
+**
+** Copyright (C) 1998-2001 by Dan Pilone
+**
+** This is the KPilot Daemon, which does the actual communication with
+** the Pilot and with the conduits.
+*/
 
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, 
+** MA 02139, USA.
+*/
 
+/*
+** Bug reports and questions can be sent to adridg@cs.kun.nl
+*/
+static const char *id="$Id: pilotDaemon.cc,v 1.29.2.1 2001/03/05 21:30:34 adridg Exp $";
 
-// REVISION HISTORY 
-//
-// 3.1b10	By Adriaan de Groot: comments added all over the place,
-//		moved the definition of the port numbers to the .h file
-//		so others can read them without linking to pilotDaemon.o.
-//
-//		Remaining questions are marked with QADE.
-
-static char *id="$Id: pilotDaemon.cc,v 1.8 2000/08/30 22:16:32 pilone Exp $";
+#include "options.h"
 
 #include <sys/time.h>
 #include <sys/types.h>
@@ -30,14 +42,18 @@ static char *id="$Id: pilotDaemon.cc,v 1.8 2000/08/30 22:16:32 pilone Exp $";
 #include <stdlib.h>
 #include <getopt.h>
 #include <signal.h>
+#include <errno.h>
 
 #include <qdir.h>
 #include <qlist.h>
-#include <qpopmenu.h>
 #include <qcursor.h>
 #include <qdragobject.h>
+#include <errno.h>
 
-#include <kapp.h>
+#include <kuniqueapp.h>
+#include <kaboutdata.h>
+#include <kaboutapplication.h>
+#include <kcmdlineargs.h>
 #include <kwin.h>
 #include <ksimpleconfig.h>
 #include <kurl.h>
@@ -45,6 +61,7 @@ static char *id="$Id: pilotDaemon.cc,v 1.8 2000/08/30 22:16:32 pilone Exp $";
 #include <kmessagebox.h>
 #include <kstddirs.h>
 #include <kpopupmenu.h>
+#include <kiconloader.h>
 #include <kio/netaccess.h>
 #include <kdebug.h>
 
@@ -52,60 +69,26 @@ static char *id="$Id: pilotDaemon.cc,v 1.8 2000/08/30 22:16:32 pilone Exp $";
 #include "hotsync.h"
 #include "busysync.h"
 #include "statusMessages.h"
-#include "options.h"
 #include "kpilot.h"
 
-static struct option longOptions[]=
-{
-	{ "debug",1,0L,'d' },
-	{ "help",0,0L,1 },
-	{ 0L,0,0L,0 }
-} ;
 
-void handleOptions(int& argc, char **argv)
+
+// Define OWN_CRASHHANDLER if you want the daemon to handle crashes
+// by itself, like KPilot 3.x did.
+//
+//
+#undef OWN_CRASHHANDLER
+
+
+PilotDaemonTray::PilotDaemonTray(PilotDaemon *p) :
+	KSystemTray(0,"pilotDaemon"), 
+	daemon(p)
 {
 	FUNCTIONSETUP;
-
-	static const char *banner=
-		"\t\tKPilotDaemon v4.0b\n"
-		"Copyright (C) 1998,1999 Dan Pilone\n"
-		"Copyright (C) 2000 Adriaan de Groot\n\n";
-
-	int c,li;
-
-	while((c=getopt_long(argc,argv,"d:",longOptions,&li))>0)
-	{
-		switch(c)
-		{
-		case 'd' : debug_level=atoi(optarg);
-			if (debug_level)
-			{
-				cerr << fname << ": Debug level set to "
-					<< debug_level << endl;
-			}
-			break;
-		case 1 : usage(banner,longOptions); exit(0);
-		default : usage(banner,longOptions); exit(1);
-		}
-	}
+	setupWidget();
 }
 
-
-DockingLabel::DockingLabel (PilotDaemon* daemon, QWidget* w) : KDockWindow(), fDaemon(daemon)
-{
-  FUNCTIONSETUP;
-  QPixmap icon(hotsync_icon);
-  setPixmap(icon);
-  QPopupMenu* menu = contextMenu();
-  menu->insertItem(i18n("&About"), daemon, SLOT(slotShowAbout()));
-  menu->insertSeparator();
-  menu->insertItem(i18n("&Exit"), daemon, SLOT(quitImmediately()));
-  setAcceptDrops(true);
-}
-
-
-void 
-DockingLabel::mousePressEvent(QMouseEvent *e)
+/* virtual */ void PilotDaemonTray::mousePressEvent(QMouseEvent *e)
 {
   FUNCTIONSETUP;
   if( e->button() == RightButton)
@@ -114,48 +97,137 @@ DockingLabel::mousePressEvent(QMouseEvent *e)
       contextMenuAboutToShow( menu );
       menu->popup( e->globalPos() );
     }
+    else
+	{
+		KSystemTray::mousePressEvent(e);
+	}
 }
 
-void DockingLabel::dragEnterEvent(QDragEnterEvent* event)
+/* virtual */ void PilotDaemonTray::closeEvent(QCloseEvent *e)
 {
-  event->accept(QUriDrag::canDecode(event));
+	FUNCTIONSETUP;
+	(void) e;
+	daemon->quitImmediately();
 }
 
-
 void
-DockingLabel::dropEvent(QDropEvent* drop)
-{
-  QStrList list;
-  QUriDrag::decode(drop, list);
-  
-  kdDebug() << "DockingLabel::dropEvent() - Got " << list.first() << endl;
-  
-  if(list.first() != 0L)
-    {
-      unsigned int i = 0;
-      QString dirname = KGlobal::dirs()->saveLocation("data", QString("kpilot/pending_install/"));
-      while (i < list.count())
-	{
-	  KURL srcName = list.at(i);
-	  KURL destDir(dirname + "/" + srcName.filename());
-	  KIO::NetAccess::copy(srcName, destDir);
-	  i++;
-	}
-    }
-}
-
-int PilotDaemon::getPilotSpeed(KConfig *config)
+PilotDaemonTray::setupWidget()
 {
 	FUNCTIONSETUP;
 
-	int speed = config->readNumEntry("PilotSpeed", 0);
+	KGlobal::iconLoader()->addAppDir("kpilot");
+	icon = KGlobal::iconLoader()->loadIcon("hotsync",KIcon::Toolbar,
+		0,KIcon::DefaultState,0,
+		true);
+	busyicon = KGlobal::iconLoader()->loadIcon("busysync",KIcon::Toolbar,
+		0,KIcon::DefaultState,0,true);
+	if (icon.isNull())
+	{
+		kdDebug() << fname << ": HotSync icon not found."
+			<< endl;
+		icon=QPixmap(hotsync_icon);
+	}
+	if (busyicon.isNull())
+	{
+		kdDebug() << fname << ": HotSync-Busy icon not found."
+			<< endl;
+		busyicon=QPixmap(busysync_icon);
+	}
+
+	changeIcon(Normal);
+
+	KPopupMenu* menu = contextMenu();
+	menu->insertItem(i18n("&About"), this, SLOT(slotShowAbout()));
+	menuKPilotItem=menu->insertItem(i18n("Start &KPilot"),daemon,
+		SLOT(slotRunKPilot()));
+
+#ifdef DEBUG
+	if (debug_level & UI_TEDIOUS)
+	{
+		kdDebug() << fname
+			<< ": Finished getting icons"
+			<< endl;
+	}
+#endif
+}
+
+void PilotDaemonTray::slotShowAbout()
+{
+	FUNCTIONSETUP;
+  
+	if (!kap)
+	{
+		kap=new KAboutApplication(0,"kpdab",false);
+	}
+
+	kap->show();
+}
+
+
+void PilotDaemonTray::enableRunKPilot(bool b)
+{
+	contextMenu()->setItemEnabled(menuKPilotItem,b);
+}
+
+
+void PilotDaemonTray::changeIcon(IconShape i)
+{
+	FUNCTIONSETUP;
+
+	switch(i)
+	{
+	case Normal:
+		if (icon.isNull())
+		{
+			kdWarning() << __FUNCTION__
+				<< ": Regular icon is NULL!"
+				<< endl;
+		}
+		setPixmap(icon);
+		break;
+	case Busy:
+		if (busyicon.isNull())
+		{
+			kdWarning() << __FUNCTION__
+				<< ": Busy icon is NULL!"
+				<< endl;
+		}
+		setPixmap(busyicon);
+		break;
+	default :
+		kdDebug() << fname 
+			<< ": Bad icon number "
+			<< (int)i
+			<< endl;
+	}
+}
+
+
+
+
+
+
+
+static KCmdLineOptions kpilotoptions[] =
+{
+	{ "debug <level>", I18N_NOOP(""),"0" },
+	{ 0,0,0 }
+} ;
+
+
+
+int PilotDaemon::getPilotSpeed(KConfig& config)
+{
+	FUNCTIONSETUP;
+
+	int speed = config.readNumEntry("PilotSpeed", 0);
 
 	// Translate the speed entry in the
 	// config file to something we can
 	// put in the environment (for who?)
 	//
 	//
-	char *speedname=0L;
+	const char *speedname=0L;
 
 	switch(speed)
 	{
@@ -178,59 +250,99 @@ int PilotDaemon::getPilotSpeed(KConfig *config)
 		speedname="PILOTRATE=9600";
 	}
 
+#ifdef DEBUG
 	if (debug_level & SYNC_MINOR)
 	{
-		cerr << fname
+		kdDebug() << fname
 			<< ": Speed set to "
 			<< speedname << " ("
 			<< speed << ')'
 			<< endl;
 	}
+#endif
 
-	putenv(speedname);
+	putenv((char *)speedname);
 
 	return speed;
+#ifdef DEBUG
+	/* NOTREACHED */
+	(void) id;
+#endif
 }
 
+
 PilotDaemon::PilotDaemon() : 
-	KTMainWindow(), 
+	DCOPObject("KPilotDaemonIface"),
 	fStatus(INIT),
   	fMonitorProcess(0L), fCurrentSocket(0L),
     fCommandSocket(0L), fStatusSocket(0L), fQuit(false), fPilotLink(0L),
-    fDockingLabel(0L), fStartKPilot(false), fWaitingForKPilot(false)
+	fStartKPilot(false), fWaitingForKPilot(false),
+	tray(0L)
 {
 	FUNCTIONSETUP;
 
-	KConfig* config = KPilotLink::getConfig();
-	config->setGroup(QString());
+	KConfig& config = KPilotLink::getConfig();
   
-  fPilotDevice = config->readEntry("PilotDevice");
+	fPilotDevice = config.readEntry("PilotDevice");
 
 
 	getPilotSpeed(config);
 
-  fStartKPilot = (bool) config->readNumEntry("StartKPilotAtHotSync", 0);
-  delete config;
-  fStatusConnections.setAutoDelete(true);
+	fStartKPilot = (bool) config.readNumEntry("StartKPilotAtHotSync", 0);
+	fStatusConnections.setAutoDelete(true);
 
-  setupWidget();
-  setupConnections();
-	if (fStatus == ERROR) return;
-  setupSubProcesses();
+	setupConnections();
+	if (fStatus == ERROR) 
+	{
+#ifdef DEBUG
+		if (debug_level & SYNC_MAJOR)
+		{
+			kdDebug() << fname
+				<< ": Setting up connections failed."
+				<< endl;
+		}
+#endif
+		return;
+	}
+	setupSubProcesses();
+
+	if (config.readBoolEntry("DockDaemon",false))
+	{
+		tray = new PilotDaemonTray(this);
+	}
+
+#ifdef DEBUG
+	if (debug_level & UI_TEDIOUS)
+	{
+		kdDebug() << fname
+			<< ": The daemon is ready with status "
+			<< (int)fStatus
+			<< endl;
+	}
+#endif
 }
 
-
-void
-PilotDaemon::testDir(QString name)
+void PilotDaemon::showTray()
 {
 	FUNCTIONSETUP;
 
-    DIR *dp = NULL;
-    dp = opendir(name.latin1());
-    if(dp == 0L)
-        ::mkdir (name.latin1(), S_IRWXU);
-    else
-        closedir( dp );
+	if (!tray) 
+	{
+		DEBUGDAEMON << fname
+			<< ": No tray icon to display!"
+			<< endl;
+
+		return;
+	}
+
+	// Copied from Klipper
+	KWin::setSystemTrayWindowFor( tray->winId(), 0 );
+	tray->setGeometry(-100, -100, 42, 42 );
+	tray->show();
+
+	DEBUGDAEMON << fname
+		<< ": Tray icon displayed."
+		<< endl;
 }
 
 void
@@ -238,29 +350,25 @@ PilotDaemon::reloadSettings()
 {
 	FUNCTIONSETUP;
 
-  KConfig* config = KPilotLink::getConfig();
-  config->setGroup(QString());
+	KConfig& config = KPilotLink::getConfig();
   
-  fPilotDevice = config->readEntry("PilotDevice");
+	fPilotDevice = config.readEntry("PilotDevice");
 	getPilotSpeed(config);
-  fStartKPilot = (bool) config->readNumEntry("StartKPilotAtHotSync", 0);
-  delete config;
+  fStartKPilot = (bool) config.readNumEntry("StartKPilotAtHotSync", 0);
 
 	if (fMonitorProcess)
 	{
-		disconnect(fMonitorProcess, SIGNAL(processExited(KProcess*)),
-			this, SLOT(slotProcFinished(KProcess*)));
-		fMonitorProcess->kill();
-		delete fMonitorProcess;
-		fMonitorProcess=0L;
+		killMonitor();
 	}
 	else
 	{
-		cerr << fname << ": No listener to kill (which is OK)."
+#ifdef DEBUG
+		kdDebug() << fname << ": No listener to kill (which is OK)."
 			<< endl;
+#endif
 	}
 
-	fPilotLink->changePilotPath(fPilotDevice.latin1());
+	fPilotLink->changePilotPath(QFile::encodeName(fPilotDevice));
 	setupSubProcesses();
 }
 
@@ -268,34 +376,63 @@ void
 PilotDaemon::setupConnections()
 {
 	FUNCTIONSETUP;
+	int e=0;
 
-	fCommandSocket = new KServerSocket(PilotDaemon::COMMAND_PORT);
-	connect(fCommandSocket, SIGNAL(accepted(KSocket*)), 
-		this, SLOT(slotAccepted(KSocket*)));
-	fStatusSocket = new KServerSocket(PilotDaemon::STATUS_PORT);
-	connect(fStatusSocket, SIGNAL(accepted(KSocket*)),
-		this, SLOT(slotAddStatusConnection(KSocket*)));
+	fPilotLink = 0L;
+	fCommandSocket = 0L;
+	fStatusSocket = 0L;
 
-	if ((fCommandSocket == 0L) || (fStatusSocket == 0L) ||
-		(fCommandSocket->socket() < 0 ) ||
-		(fStatusSocket->socket() < 0))
+	fPilotLink = new KPilotLink(0L, 0L, QFile::encodeName(fPilotDevice));
+	if (!fPilotLink)
 	{
-		cerr << fname
-			<< ": Couldn't create sockets for daemon"
-			<< endl;
-		if (fCommandSocket) delete fCommandSocket;
-		if (fStatusSocket) delete fStatusSocket;
-		fCommandSocket=0L;
-		fStatusSocket=0L;
-
-		fStatus=ERROR;
-		return;
+		e = EACCES;
+		goto ErrConn;
+	}
+	if (fPilotLink->status() != KPilotLink::Normal)
+	{
+		e = EACCES;
+		goto ErrConn;
 	}
 
-	fPilotLink = new KPilotLink(0L, 0L, fPilotDevice.latin1());
+	fCommandSocket = new KServerSocket(PilotDaemon::COMMAND_PORT);
+	if (fCommandSocket && (fCommandSocket->socket() < 0 )) 
+	{
+		e = errno ; 
+		goto ErrConn;
+	}
+	fStatusSocket = new KServerSocket(PilotDaemon::STATUS_PORT);
+	if (fStatusSocket && (fStatusSocket->socket() < 0 )) 
+	{
+		e = errno ;
+		goto ErrConn;
+	}
+
+	if (!(fPilotLink && fCommandSocket && fStatusSocket)) goto ErrConn;
+
 	connect(fPilotLink, SIGNAL(databaseSyncComplete()),
 		this, SLOT(slotDBBackupFinished()));
 	connect(this, SIGNAL(endHotSync()), this, SLOT(slotEndHotSync()));
+	connect(fCommandSocket, SIGNAL(accepted(KSocket*)), 
+		this, SLOT(slotAccepted(KSocket*)));
+	connect(fStatusSocket, SIGNAL(accepted(KSocket*)),
+		this, SLOT(slotAddStatusConnection(KSocket*)));
+
+	return;
+
+ErrConn:
+	kdError() << __FUNCTION__
+		<< ": While creating socket for daemon: "
+		<< strerror(e)
+		<< endl;
+
+	if (fPilotLink) delete fPilotLink;
+	if (fCommandSocket) delete fCommandSocket;
+	if (fStatusSocket) delete fStatusSocket;
+	fPilotLink=0L;
+	fCommandSocket=0L;
+	fStatusSocket=0L;
+
+	fStatus=ERROR;
 }
 
 void
@@ -303,6 +440,13 @@ PilotDaemon::setupSubProcesses()
 {
 	FUNCTIONSETUP;
 
+	if (fMonitorProcess)
+	{
+		kdWarning() << __FUNCTION__
+			<< ": There is already a monitor process!"
+			<< endl;
+	}
+
 	fMonitorProcess = new KProcess();
 	if (fMonitorProcess)
 	{
@@ -313,99 +457,168 @@ PilotDaemon::setupSubProcesses()
 	}
 	else
 	{
-		cerr << fname << ": Can't start new listener process."
+		kdWarning() << __FUNCTION__ << ": Can't start new listener process."
 			<< endl;
 	}
 }
 
-void
-PilotDaemon::setupWidget()
+#ifdef DEBUG
+KPilotLink *PilotDaemon::getPilotLink()
 {
 	FUNCTIONSETUP;
 
-  KConfig* config = KPilotLink::getConfig();
-  config->setGroup(QString());
-  if(config->readNumEntry("DockDaemon", 0))
-    {
-      fDockingLabel = new DockingLabel(this, (QWidget*)0L);
-      fDockingLabel->show();
-    }
-  delete config;
-}
+	if (fPilotLink)
+	{
+		DEBUGKPILOT << fname
+			<< ": Returning Pilot Link @"
+			<< (int) fPilotLink
+			<< endl;
 
-void 
-PilotDaemon::slotShowAbout()
-{
-  FUNCTIONSETUP;
-  
-  KMessageBox::error(0L, i18n("KPilot Hot-Sync Daemon v4.0 \n"
-				 "By: Dan Pilone.\n"
-				"Email: pilone@slac.com"),
-		       i18n("KPilot Daemon v4.0"));
+		return fPilotLink;
+	}
+	else
+	{
+		kdWarning() << __FUNCTION__
+			<< ": No Pilot Link!"
+			<< endl;
+		return 0;
+	}
 }
+#endif
 
-void
-PilotDaemon::quitImmediately()
+void PilotDaemon::killMonitor(bool finishsync)
 {
 	FUNCTIONSETUP;
 
-	getPilotLink()->endHotSync();
+	if (finishsync)
+	{
+		getPilotLink()->endHotSync();
+	}
+
+	KProcess *m=getMonitorProcess();
+	if (m)
+	{
+		kdDebug() << fname << ": Killing monitor" << endl;
+		m->kill();
+	}
+
+	if (fMonitorProcess)
+	{
+		disconnect(fMonitorProcess, SIGNAL(processExited(KProcess*)),
+			this, SLOT(slotProcFinished(KProcess*)));
+		delete fMonitorProcess;
+		fMonitorProcess=0L;
+	}
+}
+
+
+void PilotDaemon::quitImmediately()
+{
+	FUNCTIONSETUP;
+	killMonitor();
 	quit(true);
 	kapp->quit();
 } 
  
+void
+PilotDaemon::startHotSync(int mode)
+{
+	FUNCTIONSETUP;
+
+	switch(mode)
+	{
+	case 1:
+		DEBUGDAEMON << fname
+			<< ": Starting a normal HotSync"
+			<< endl;
+		break;
+	case 2: 
+		DEBUGDAEMON << fname
+			<< ": Starting a FastSync"
+			<< endl;
+		break;
+	case 3:
+		DEBUGDAEMON << fname
+			<< ": Starting a full Backup"
+			<< endl;
+		break;
+	default :
+		kdWarning() << __FUNCTION__
+			<< ": Unknown mode "
+			<< mode
+			<< " passed to startHotSync()"
+			<< endl;
+		return;
+	}
+
+	kdWarning() << __FUNCTION__
+		<< ": Unimplemented right now."
+		<< endl;
+}
+
 void
 PilotDaemon::startHotSync()
 {
 	FUNCTIONSETUP;
 
 
-	if(fDockingLabel)
+	if (tray) 
 	{
-		QPixmap icon(busysync_icon);
-		fDockingLabel->setPixmap(icon);
+		DEBUGKPILOT << fname
+			<< ": Changing tray icon."
+			<< endl;
+
+		tray->changeIcon(PilotDaemonTray::Busy);
 	}
 
   // We need to send the SYNC_STARTING message after the sync
   // has already begun so that if KPilot is running it doesn't start
   // issuing commands before KPilotLink is ready.
-  getPilotLink()->startHotSync();
-  sendStatus(CStatusMessages::SYNC_STARTING);
+#ifdef DEBUG
 	if (debug_level &  SYNC_MAJOR)
 	{
-		cerr << fname 
+		kdDebug() << fname 
 			<< ": Requesting KPilotLink::startHotSync()" << endl;
 	}
+#endif
+  getPilotLink()->startHotSync();
+  sendStatus(CStatusMessages::SYNC_STARTING);
 
   if(fCurrentSocket == 0L)
     {
+#ifdef DEBUG
 	if (debug_level & SYNC_MINOR)
 	{
-		cerr << fname  <<
+		kdDebug() << fname  <<
 			": No KPilot running." << endl;
 	}
+#endif
 		
       if(fStartKPilot) // We are supposed to start up kpilot..
 	{
+#ifdef DEBUG
 		if (debug_level & SYNC_MAJOR)
 		{
-			cerr << fname << ": Starting KPilot GUI." << endl;
+			kdDebug() << fname << ": Starting KPilot GUI." << endl;
 		}
+#endif
 
 	  fWaitingForKPilot = true;
 	  if (fork()==0)
 	    {
 	      execlp("kpilot", "kpilot", 0);
-		cerr << fname << ": Failed to start KPilot." << endl;
-	      exit(1);
+		kdError() << __FUNCTION__ << ": Failed to start KPilot." << endl;
+	      exit(1);	// This is a legitimate exit(), since we should never get here.
 	    }
 	}
       else
 	{
+#ifdef DEBUG
 		if (debug_level & SYNC_MAJOR)
 		{
-			cerr  << fname << ": Starting quick sync." << endl;
+			kdDebug()  << fname << ": Starting quick sync." << endl;
 		}
+#endif
 	  getPilotLink()->quickHotSync();
 	}
     }
@@ -417,18 +630,19 @@ PilotDaemon::slotDBBackupFinished()
 {
 	FUNCTIONSETUP;
 
+#ifdef DEBUG
 	if (debug_level & SYNC_MAJOR)
 	{
-		cerr << fname << ": DB Syncing finished." << endl;
+		kdDebug() << fname << ": DB Syncing finished." << endl;
 	}
+#endif
 
-	KConfig* config = KPilotLink::getConfig();
-	config->setGroup(QString());
-	if(config->readNumEntry("SyncFiles"))
+	KConfig& config = KPilotLink::getConfig();
+	if(config.readNumEntry("SyncFiles"))
 	{
-	  getPilotLink()->installFiles(KGlobal::dirs()->saveLocation("data", QString("kpilot/pending_install/")));
+	  getPilotLink()->installFiles(KGlobal::dirs()->saveLocation("data", 
+		QString("kpilot/pending_install/")));
 	}
-	delete config;
 	emit(endHotSync());
 }
 
@@ -437,6 +651,7 @@ PilotDaemon::slotProcFinished(KProcess*)
 {
 	FUNCTIONSETUP;
 
+	killMonitor(false);
 	startHotSync();
 }
 
@@ -445,28 +660,26 @@ PilotDaemon::slotEndHotSync()
 {
 	FUNCTIONSETUP;
 
-	if(fDockingLabel)
-	{
-		QPixmap icon(hotsync_icon);
-		fDockingLabel->setPixmap(icon);
-	}
+	if (tray) { tray -> changeIcon(PilotDaemonTray::Normal); } 
 
 	KPilotLink *p=getPilotLink();
 
 	if (p)
 	{
+#ifdef DEBUG
 		if (debug_level & SYNC_MAJOR)
 		{
-			cerr << fname
+			kdDebug() << fname
 				<< ": Ending hot-sync now"
 				<< endl;
 		}
+#endif
 
 		p->endHotSync();
 	}
 	else
 	{
-		cerr << fname
+		kdError() << __FUNCTION__
 			<< ": No link to pilot!"
 			<< endl;
 	}
@@ -475,7 +688,8 @@ PilotDaemon::slotEndHotSync()
 
 	if(!quit())
 	{
-		fMonitorProcess->start(KProcess::NotifyOnExit);
+		killMonitor(false);
+		setupSubProcesses();
 	}
 	else
 	{
@@ -496,13 +710,15 @@ PilotDaemon::slotAccepted(KSocket* connection)
 		return;
 	}
 
+#ifdef DEBUG
 	if (debug_level & SYNC_MAJOR)
 	{
-		cerr << fname 
+		kdDebug() << fname 
 			<< ": Accepted command connection "
 			<< (int) connection
 			<< endl;
 	}
+#endif
 
   fCurrentSocket = connection;
   connect(fCurrentSocket, SIGNAL(closeEvent(KSocket*)),
@@ -510,6 +726,8 @@ PilotDaemon::slotAccepted(KSocket* connection)
   connect(fCurrentSocket, SIGNAL(readEvent(KSocket*)),
 	  this, SLOT(slotCommandReceived(KSocket*)));
   fCurrentSocket->enableRead(true);
+
+	if (tray) { tray->enableRunKPilot(false); } 
 }
 
 void
@@ -521,6 +739,17 @@ PilotDaemon::slotCommandReceived(KSocket*)
   int command;
 
   in >> command;
+
+#ifdef DEBUG
+	if (debug_level & SYNC_TEDIOUS)
+	{
+		kdDebug() << fname
+			<< ": Received command "
+			<< command
+			<< endl;
+	}
+#endif
+
   switch(command)
     {
       // < 0 means commands to us.
@@ -540,32 +769,42 @@ PilotDaemon::slotCommandReceived(KSocket*)
       getPilotLink()->doFullRestore();
       break;
     case KPilotLink::HotSync:
+	getPilotLink()->setFastSyncRequired(false);
+    case KPilotLink::FastSync:
       if(getPilotLink()->slowSyncRequired())
+      {
 	getPilotLink()->doFullBackup();
+	}
       else
+      {
 	getPilotLink()->quickHotSync();
+	}
       break;
     case KPilotLink::InstallFile:
       getPilotLink()->installFiles(KGlobal::dirs()->saveLocation("data", QString("kpilot/pending_install/")));
       break;
 	case KPilotLink::TestConnection :
+#ifdef DEBUG
 		if (debug_level & SYNC_MAJOR)
 		{
-			cerr  << fname
+			kdDebug()  << fname
 				<< ": Connection tests OK"
 				<< endl ;
 		}
+#endif
 		break;
     default:
-      cerr << fname << ": Unknown command!" << command << endl;
+      kdWarning() << __FUNCTION__ << ": Unknown command!" << command << endl;
       break;
     }
 
+#ifdef DEBUG
 	if (debug_level & SYNC_TEDIOUS)
 	{
-		cerr << fname
+		kdDebug() << fname
 			<< ": Done reading." << endl;
 	}
+#endif
 }
 
 void
@@ -576,22 +815,25 @@ PilotDaemon::slotConnectionClosed(KSocket* connection)
 	delete connection;
 	if (fCurrentSocket != connection)
 	{
-		cerr << fname 
+		kdWarning() << __FUNCTION__
 			<< ": Connection other than current was closed?"
 			<< endl;
 	}
 	else
 	{
+#ifdef DEBUG
 		if (debug_level & SYNC_TEDIOUS)
 		{
-			cerr << fname 
+			kdDebug() << fname 
 				<< ": Connection "
 				<< (int) connection
 				<< " closed"
 				<< endl;
 		}
+#endif
 
 		fCurrentSocket = 0L;
+		if (tray) { tray->enableRunKPilot(true); } 
 	}
 	emit(endHotSync());
 }
@@ -601,13 +843,15 @@ PilotDaemon::slotAddStatusConnection(KSocket* connection)
 {
 	FUNCTIONSETUP;
 
+#ifdef DEBUG
 	if (debug_level & SYNC_MAJOR)
 	{
-		cerr << fname 
+		kdDebug() << fname 
 			<< ": Accepted status connection "
 			<< (int) connection
 			<< endl;
 	}
+#endif
   fStatusConnections.append(connection);
   connect(connection, SIGNAL(closeEvent(KSocket*)),
 	  this, SLOT(slotRemoveStatusConnection(KSocket*)));
@@ -624,14 +868,16 @@ PilotDaemon::slotRemoveStatusConnection(KSocket* connection)
 {
 	FUNCTIONSETUP;
 
+#ifdef DEBUG
 	if (debug_level & SYNC_TEDIOUS)
 	{
-		cerr << fname 
+		kdDebug() << fname 
 			<< ": Connection "
 			<< (int) connection
 			<< " closed"
 			<< endl;
 	}
+#endif
 
 	fStatusConnections.remove(connection); // will be deleted by list.
 }
@@ -681,9 +927,13 @@ PilotDaemon::sendStatus(const int status)
 	KSocket *c;
 	int updateCount=0;
 
+#ifdef DEBUG
+	// Large debugging block
+	//
+	//
 	if (debug_level & SYNC_MINOR)
 	{
-		cerr << fname 
+		kdDebug() << fname 
 			<< ": Sending status " << status
 			<< endl;
 	}
@@ -694,27 +944,30 @@ PilotDaemon::sendStatus(const int status)
 			(c=fStatusConnections.current()) ; 
 			fStatusConnections.next())
 		{
-			cerr << fname << ": Will send to connection "
+			kdDebug() << fname << ": Will send to connection "
 				<< (int) c
 				<< endl;
 		}
 	}
+#endif
 
 	for(fStatusConnections.first() ; 
 		(c=fStatusConnections.current()) ; 
 		fStatusConnections.next())
 	{
+#ifdef DEBUG
 		if (debug_level & SYNC_TEDIOUS)
 		{
-			cerr << fname
+			kdDebug() << fname
 				<< ": Sending to connection "
 				<< (int) c
 				<< endl;
 		}
+#endif
 
 		if (c->socket()<0)
 		{
-			cerr << fname
+			kdWarning() << __FUNCTION__
 				<< ": Connection "
 				<< (int) c 
 				<< " has no valid socket"
@@ -728,43 +981,68 @@ PilotDaemon::sendStatus(const int status)
 		}
 	}
 
+#ifdef DEBUG
 	if (debug_level & SYNC_MINOR)
 	{
-		cerr << fname
+		kdDebug() << fname
 			<< ": Completed status update for "
 			<< updateCount
 			<< " connections"
 			<< endl;
 	}
+#endif
 }
 
 void
-PilotDaemon::saveProperties(KConfig*)
+PilotDaemon::saveProperties(KConfig&)
 {
 	FUNCTIONSETUP;
 
-  disconnect(fMonitorProcess, SIGNAL(processExited(KProcess*)),
-	  this, SLOT(slotProcFinished(KProcess*)));
-  fMonitorProcess->kill();
+	killMonitor();
 }
 
 PilotDaemon::~PilotDaemon()
 {
 	FUNCTIONSETUP;
 
-  //  Should delete this but something goes apeshit
-  disconnect(fMonitorProcess, SIGNAL(processExited(KProcess*)),
-	     this, SLOT(slotProcFinished(KProcess*)));
-  fMonitorProcess->kill();
-//   delete fMonitorProcess;
-  //   delete fSyncProcess;
+	killMonitor();
+
   delete fPilotLink;
   delete fCommandSocket;
   delete fStatusSocket;
   
 }
 
+void PilotDaemon::slotRunKPilot()
+{
+	FUNCTIONSETUP;
+
+	if (fCurrentSocket)
+	{
+		kdDebug() << fname 
+			<< ": Only one KPilot at a time."
+			<< endl;
+		return;
+	}
+
+	KProcess *k=new KProcess();
+
+	*k << "kpilot";
+#ifdef DEBUG
+	if (debug_level)
+	{
+		*k << "--debug" ;
+		*k << QString::number(debug_level);
+	}
+#endif
+
+	k->start(KProcess::DontCare);
+}
+
 PilotDaemon* gPilotDaemon=0L;
+
+
+#ifdef OWN_CRASHHANDLER
 int crashFlag=0;
 
 void signalHandler(int s)
@@ -774,10 +1052,12 @@ void signalHandler(int s)
 
 	crashFlag++;
 
-	if (debug_level)
-	{
-		cerr << fname << ": Caught signal " << s << endl;
-	}
+	// In (crashed) cases like this I think we
+	// can't use kdError() safely, so this is
+	// the one instance of cerr left ...
+	//	
+	//
+	cerr << fname << ": Caught signal " << s << endl;
 
 	// Suppose the daemon crashes. We get here
 	// with crashFlag=1. We set the alarm and it goes
@@ -822,17 +1102,13 @@ void signalHandler(int s)
 
 	if (gPilotDaemon)
 	{
-		KProcess *m=gPilotDaemon->getMonitorProcess();
-		if (m)
-		{
-			cerr << fname << ": Killing monitor" << endl;
-			m->kill();
-		}
+		gPilotDaemon->killMonitor();
 	}
 
 
 	exit(-1);
 }
+#endif
 
 
 
@@ -840,29 +1116,129 @@ int main(int argc, char* argv[])
 {
 	FUNCTIONSETUP;
 
+        KAboutData about("kpilotDaemon", I18N_NOOP("KPilot"),
+                         "4.0b2",
+                         "KPilot - Hot-sync software for unix\n\n",
+                         KAboutData::License_GPL,
+                         "(c) 1998-2000, Dan Pilone");
+	about.addAuthor("Dan Pilone",
+		I18N_NOOP("Project Leader"),
+		"pilone@slac.com",
+		"http://www.slac.com/pilone/kpilot_home/");
+	about.addAuthor("Adriaan de Groot",
+		I18N_NOOP("Maintainer"),
+		"adridg@cs.kun.nl",
+		"http://www.cs.kun.nl/~adridg/kpilot/");
 
-	KApplication a(argc, argv, "pilotDaemon");
-	handleOptions(argc,argv);
+        KCmdLineArgs::init(argc, argv, &about);
+	KCmdLineArgs::addCmdLineOptions(kpilotoptions);
+	KUniqueApplication::addCmdLineOptions();
+	KCmdLineArgs *p=KCmdLineArgs::parsedArgs();
 
+#ifdef DEBUG
+	debug_level=atoi(p->getOption("debug"));
+	if (debug_level)
+	{
+		DEBUGDAEMON << fname
+			<< ": Debug level set to "
+			<< debug_level
+			<< endl;
+	}
+#endif
+
+	if (!KUniqueApplication::start())
+	{
+		return 0;
+	}
+	KUniqueApplication a(true,true);
+
+	// A block just to keep variables local.
+	//
+	//
+	{
+	KConfig& c=KPilotLink::getConfig();
+	c.setReadOnly(true);
+	int v = c.readNumEntry("Configured",0);
+
+	if (v < KPilotLink::ConfigurationVersion)
+	{
+		kdError() << __FUNCTION__ 
+			<< ": Is still not configured for use."
+			<< endl;
+		return 1;
+	}
+
+	DEBUGDAEMON << fname
+		<< ": Configuration version "
+		<< v
+		<< endl;
+	}
 
 
 	gPilotDaemon = new PilotDaemon();
 
 	if (gPilotDaemon->status()==PilotDaemon::ERROR)
 	{
-		cerr << fname 
-			<< ": Failed to start up daemon"
+		delete gPilotDaemon;
+		gPilotDaemon = 0;
+		kdError() << __FUNCTION__ 
+			<< ": **\n"
+			   ": Failed to start up daemon\n"
+			   ": due to errors constructing it.\n"
+			   ": **"
 			<< endl;
-		exit(2);
+		return 2;
 	}
 	
+#ifdef OWN_CRASHHANDLER
 	signal(SIGHUP, signalHandler);
 	signal(SIGINT, signalHandler);
 	signal(SIGPIPE, signalHandler);
 	signal(SIGSEGV, signalHandler);
 	signal(SIGQUIT, signalHandler);
 	signal(SIGTERM, signalHandler);
+#endif
+
+	gPilotDaemon->showTray();
 
-	a.setMainWidget(gPilotDaemon);
 	return a.exec();
+
+	/* NOTREACHED */
+	(void) id;
 }
+
+
+
+// $Log: pilotDaemon.cc,v $
+// Revision 1.29.2.1  2001/03/05 21:30:34  adridg
+// Fixed double-sync, backport. Bug #19538. No strings changed.
+//
+// Revision 1.29  2001/02/08 13:17:19  adridg
+// Fixed crash when conduits run during a backup and exit after the
+// end of that backup (because the event loop is blocked by the backup
+// itself). Added better debugging error exit message (no i18n needed).
+//
+// Revision 1.28  2001/02/05 21:01:07  adridg
+// Fixed copyright headers for source releases. No code changed
+//
+// Revision 1.27  2001/02/05 19:16:32  adridg
+// Removing calls to exit() from internal functions
+//
+// Revision 1.26  2001/01/06 13:20:23  adridg
+// Cleaned up DCOP; changed version number
+//
+// Revision 1.25  2001/01/04 22:19:37  adridg
+// Stuff for Chris and Bug 18072
+//
+// Revision 1.24  2001/01/04 11:33:20  bero
+// Fix build
+//
+// Revision 1.23  2001/01/03 00:02:45  adridg
+// Added Heiko's FastSync
+//
+// Revision 1.22  2001/01/02 15:02:59  bero
+// Fix build
+//
+// Revision 1.21  2000/12/31 16:44:00  adridg
+// Patched up the debugging stuff again
+//
