@@ -1,19 +1,42 @@
-// pilotLocalDatabase.cc
-//
-// Copyright (C) 1998,1999 Dan Pilone
-//
-// This file is distributed under the Gnu General Public Licence (GPL).
-// The GPL should have been included with this file in a file called
-// COPYING.
-//
-//
-static const char *id="$Id: pilotLocalDatabase.cc,v 1.4 2000/07/24 04:10:00 pilone Exp $";
+/* pilotLocalDatabase.cc			KPilot
+**
+** Copyright (C) 1998-2001 by Dan Pilone
+**
+** This defines an interface to Pilot databases on the local disk.
+*/
+
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, 
+** MA 02139, USA.
+*/
+
+/*
+** Bug reports and questions can be sent to adridg@cs.kun.nl
+*/
+
+
+static const char *pilotlocaldatabase_id="$Id: pilotLocalDatabase.cc,v 1.9 2001/02/08 08:13:44 habenich Exp $";
+
+#include "options.h"
 
 #include <stdio.h>
 #include <unistd.h>
 #include <iostream.h>
 #include <string.h>
 #include "pilotLocalDatabase.h"
+#include <kdebug.h>
 
 PilotLocalDatabase::PilotLocalDatabase(const char* path, const char* dbName)
   : PilotDatabase(), fPathName(0L), fDBName(0L), fAppInfo(0L), fAppLen(0), 
@@ -51,21 +74,30 @@ void PilotLocalDatabase::checkDBName()
 // Reads the application block info
 int PilotLocalDatabase::readAppBlock(unsigned char* buffer, int )
     {
+	FUNCTIONSETUP;
     if(isDBOpen() == false)
 	{
-	cerr << "PilotLocalDatabase::readAppBlock() - Error: DB not open!" << endl;
+	kdError() << __FUNCTION__ << ": DB not open!" << endl;
 	return -1;
+	/* NOTREACHED */
+	(void) pilotlocaldatabase_id;
 	}
     memcpy((void*)buffer, fAppInfo, fAppLen);
     return fAppLen;
+#ifdef DEBUG
+	/* NOTREACHED */
+	(void) pilotlocaldatabase_id;
+#endif
     }
 
 // Writes the application block info.
 int PilotLocalDatabase::writeAppBlock(unsigned char* buffer, int len)
 {
+	FUNCTIONSETUP;
+
   if(isDBOpen() == false)
     {
-      cerr << "PilotLocalDatabase::writeAppBlock() - Error: DB not open!" << endl;
+      kdError() << __FUNCTION__ << ": DB not open!" << endl;
       return -1;
     }
   delete [] fAppInfo;
@@ -78,12 +110,14 @@ int PilotLocalDatabase::writeAppBlock(unsigned char* buffer, int len)
 // Reads a record from database by id, returns record length
 PilotRecord* PilotLocalDatabase::readRecordById(recordid_t id)
     {
+	FUNCTIONSETUP;
+
     int i;
 
     fPendingRec = -1;
     if(isDBOpen() == false)
 	{
-	cerr << "PilotLocalDatabase::readRecordById() - Error: DB not open!" << endl;
+	kdDebug() << fname << ": DB not open!" << endl;
 	return 0L;
 	}
     for(i = 0; i < fNumRecords; i++)
@@ -98,10 +132,11 @@ PilotRecord* PilotLocalDatabase::readRecordById(recordid_t id)
 // Reads a record from database, returns the record length
 PilotRecord* PilotLocalDatabase::readRecordByIndex(int index)
     {
+	FUNCTIONSETUP;
     fPendingRec = -1;
     if(isDBOpen() == false)
 	{
-	cerr << "PilotLocalDatabase::readRecordByIndex() - Error: DB not open!" << endl;
+	kdError() << __FUNCTION__ << ": DB not open!" << endl;
 	return 0L;
 	}
     if(index >= fNumRecords)
@@ -113,10 +148,11 @@ PilotRecord* PilotLocalDatabase::readRecordByIndex(int index)
 // Reads the next record from database in category 'category'
 PilotRecord* PilotLocalDatabase::readNextRecInCategory(int category)
     {
+	FUNCTIONSETUP;
     fPendingRec = -1;
     if(isDBOpen() == false)
 	{
-	cerr << "PilotLocalDatabase::readNextRecInCategory() - Error: DB not open!" << endl;
+	kdError() << __FUNCTION__ << ": DB not open!" << endl;
 	return 0L;
 	}
     while((fCurrentRecord < fNumRecords) && (fRecords[fCurrentRecord]->getCat() != category))
@@ -131,9 +167,11 @@ PilotRecord* PilotLocalDatabase::readNextRecInCategory(int category)
 // Reads the next record from database that has the dirty flag set.
 PilotRecord* PilotLocalDatabase::readNextModifiedRec()
     {
+	FUNCTIONSETUP;
+
     if(isDBOpen() == false)
 	{
-	cerr << "PilotLocalDatabase::readNextModifiedRec() - Error: DB not open!" << endl;
+	kdError() << __FUNCTION__ << ": DB not open!" << endl;
 	return 0L;
 	}
     // Should this also check for deleted?
@@ -150,14 +188,16 @@ PilotRecord* PilotLocalDatabase::readNextModifiedRec()
 // Writes a new ID to the record specified the index.  Not supported on Serial connections
 int PilotLocalDatabase::writeID(PilotRecord* rec)
 {
+	FUNCTIONSETUP;
+
   if(isDBOpen() == false)
     {
-      cerr << "PilotLocalDatabase::writeID() - Error: DB not open!" << endl;
+      kdError() << __FUNCTION__ << ": DB not open!" << endl;
       return -1;
     }
   if(fPendingRec == -1)
     {
-      cerr << "PilotLocalDatabase::writeID() - Error: Last call was _NOT_ readNextModifiedRec()" << endl;
+      kdError() << __FUNCTION__ << ": Last call was _NOT_ readNextModifiedRec()" << endl;
       return -1;
     }
   fRecords[fPendingRec]->setID(rec->getID());
@@ -168,12 +208,13 @@ int PilotLocalDatabase::writeID(PilotRecord* rec)
 // Writes a new record to database (if 'id' == 0, it is assumed that this is a new record to be installed on pilot)
 int PilotLocalDatabase::writeRecord(PilotRecord* newRecord)
     {
+	FUNCTIONSETUP;
     int i;
 
     fPendingRec = -1;
     if(isDBOpen() == false)
 	{
-	cerr << "PilotLocalDatabase::writeRecord() - Error: DB not open!" << endl;
+	kdError() << __FUNCTION__ << ": DB not open!" << endl;
 	return -1;
 	}
     // We can't do this since it's possible the local apps need to rewrite a record
@@ -212,12 +253,14 @@ int PilotLocalDatabase::writeRecord(PilotRecord* newRecord)
 // Resets all records in the database to not dirty.
 int PilotLocalDatabase::resetSyncFlags()
     {
+	FUNCTIONSETUP;
+
     int i;
 
     fPendingRec = -1;
     if(isDBOpen() == false)
 	{
-	cerr << "PilotLocalDatabase::readRecordByIndex() - Error.DB not open!" << endl;
+	kdError() << __FUNCTION__ << ": DB not open!" << endl;
 	return -1;
 	}
     for(i = 0; i < fNumRecords; i++)
@@ -228,10 +271,11 @@ int PilotLocalDatabase::resetSyncFlags()
 // Resets next record index to beginning
 int PilotLocalDatabase::resetDBIndex()
     {
+	FUNCTIONSETUP;
     fPendingRec = -1;
     if(isDBOpen() == false)
 	{
-	cerr << "PilotLocalDatabase::resetDBIndex() - Error: DB not open!" << endl;
+	kdError() << __FUNCTION__ << ": DB not open!" << endl;
 	return -1;
 	}
     fCurrentRecord = 0;
@@ -241,10 +285,11 @@ int PilotLocalDatabase::resetDBIndex()
 // Purges all Archived/Deleted records from Palm Pilot database
 int PilotLocalDatabase::cleanUpDatabase()
     {
+	FUNCTIONSETUP;
     fPendingRec = -1;
     if(isDBOpen() == false)
 	{
-	cerr << "PilotLocalDatabase::cleanUpDatabase() - Error: DB not open!" << endl;
+	kdError() << __FUNCTION__ << ": DB not open!" << endl;
 	return -1;
 	}
     int i,j;
@@ -268,6 +313,7 @@ int PilotLocalDatabase::cleanUpDatabase()
 
 void PilotLocalDatabase::openDatabase()
     {
+	FUNCTIONSETUP;
     void* tmpBuffer;
     pi_file* dbFile;
     char tempName[256];
@@ -281,7 +327,7 @@ void PilotLocalDatabase::openDatabase()
     dbFile = pi_file_open(tempName);
     if(dbFile == 0L)
 	{
-	cerr << "Failed to open " << tempName << endl;
+	kdError() << __FUNCTION__ << ": Failed to open " << tempName << endl;
 	return;
 	}
     pi_file_get_info(dbFile, &fDBInfo);
@@ -328,3 +374,12 @@ void PilotLocalDatabase::closeDatabase()
     unlink(tempName);
     rename(newName, tempName);
     }
+
+
+// $Log: pilotLocalDatabase.cc,v $
+// Revision 1.9  2001/02/08 08:13:44  habenich
+// exchanged the common identifier "id" with source unique <sourcename>_id for --enable-final build
+//
+// Revision 1.8  2001/02/05 20:58:48  adridg
+// Fixed copyright headers for source releases. No code changed
+//
