@@ -1,36 +1,42 @@
-// pilotSerialDatabase.cc
-//
-// Copyright (C) 1998,1999 Dan Pilone
-//
-// This file is distributed under the Gnu General Public Licence (GPL).
-// The GPL should have been included with this file in a file called
-// COPYING. 
-//
-// This is pilotSerialDatabase.cc for KDE 2 / KPilot 4.
-//
-// TODO:
-//
-//
+/* pilotSerialDatabase.cc			KPilot
+**
+** Copyright (C) 1998-2001 by Dan Pilone
+**
+** Databases approached through DLP / Pilot-link look different,
+** so this file defines an API for them.
+*/
 
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, 
+** MA 02139, USA.
+*/
+
+/*
+** Bug reports and questions can be sent to adridg@cs.kun.nl
+*/
 #include "options.h"
 
-#ifdef KDE2
 #include <time.h>
 #include <stream.h>
 #include <pi-dlp.h>
 #include <kmessagebox.h>
 #include <klocale.h>
+#include <kdebug.h>
 
 #include "pilotSerialDatabase.h"
 #include "kpilotlink.h"
-#else
-#include <iostream.h>
-#include <string.h>
-#include <kmsgbox.h>
-#include "kpilotlink.h"
-#include "pilotSerialDatabase.h"
-#include "pi-dlp.h"
-#endif
 
 PilotSerialDatabase::PilotSerialDatabase(KPilotLink* pilotLink, const char* dbName)
   : PilotDatabase(), fDBName(0L), fDBHandle(-1), fPilotLink(pilotLink)
@@ -49,9 +55,10 @@ PilotSerialDatabase::~PilotSerialDatabase()
 // Reads the application block info
 int PilotSerialDatabase::readAppBlock(unsigned char* buffer, int maxLen)
     {
+	FUNCTIONSETUP;
     if(isDBOpen() == false)
 	{
-	cerr << "PilotSerialDatabase::readAppBlock() - Error.DB not open!" << endl;
+	kdError() << __FUNCTION__ << ": DB not open" << endl;
 	return -1;
 	}
     return dlp_ReadAppBlock(getPilotLink()->getCurrentPilotSocket(), getDBHandle(), 0, (void *)buffer, maxLen);
@@ -60,9 +67,10 @@ int PilotSerialDatabase::readAppBlock(unsigned char* buffer, int maxLen)
 // Writes the application block info.
 int PilotSerialDatabase::writeAppBlock(unsigned char* buffer, int len)
 {
+	FUNCTIONSETUP;
   if(isDBOpen() == false)
     {
-      cerr << "PilotSerialDatabase: writeAppBlock() - Error DB not open!" << endl;
+      kdError() << __FUNCTION__ << ": DB not open" << endl;
       return -1;
     }
   return dlp_WriteAppBlock(getPilotLink()->getCurrentPilotSocket(), getDBHandle(), buffer, len);
@@ -72,12 +80,13 @@ int PilotSerialDatabase::writeAppBlock(unsigned char* buffer, int len)
 // Reads a record from database by id, returns record length
 PilotRecord* PilotSerialDatabase::readRecordById(recordid_t id)
     {
+	FUNCTIONSETUP;
     char* buffer[0xffff];
     int index, size, attr, category;
 
     if(isDBOpen() == false)
 	{
-	cerr << "PilotSerialDatabase::readRecordByIndex() - Error.DB not open!" << endl;
+	kdError() << __FUNCTION__ << ": DB not open" << endl;
 	return 0L;
 	}
     if(dlp_ReadRecordById(getPilotLink()->getCurrentPilotSocket(), getDBHandle(), id, buffer, &index,
@@ -89,13 +98,14 @@ PilotRecord* PilotSerialDatabase::readRecordById(recordid_t id)
 // Reads a record from database, returns the record length
 PilotRecord* PilotSerialDatabase::readRecordByIndex(int index)
     {
+	FUNCTIONSETUP;
     char* buffer[0xffff];
     int size, attr, category;
     recordid_t id;
 
     if(isDBOpen() == false)
 	{
-	cerr << "PilotSerialDatabase::readRecordByIndex() - Error.DB not open!" << endl;
+	kdError() << __FUNCTION__ << ": DB not open" << endl;
 	return 0L;
 	}
     if(dlp_ReadRecordByIndex(getPilotLink()->getCurrentPilotSocket(), getDBHandle(), index, 
@@ -107,13 +117,14 @@ PilotRecord* PilotSerialDatabase::readRecordByIndex(int index)
 // Reads the next record from database in category 'category'
 PilotRecord* PilotSerialDatabase::readNextRecInCategory(int category)
     {
+	FUNCTIONSETUP;
     char* buffer[0xffff];
     int index, size, attr;
     recordid_t id;
 
     if(isDBOpen() == false)
 	{
-	cerr << "PilotSerialDatabase::readRecordByIndex() - Error.DB not open!" << endl;
+	kdError() << __FUNCTION__ << ": DB not open" << endl;
 	return 0L;
 	}
     if(dlp_ReadNextRecInCategory (getPilotLink()->getCurrentPilotSocket(), getDBHandle(), 
@@ -125,13 +136,14 @@ PilotRecord* PilotSerialDatabase::readNextRecInCategory(int category)
 // Reads the next record from database that has the dirty flag set.
 PilotRecord* PilotSerialDatabase::readNextModifiedRec()
     {
+	FUNCTIONSETUP;
     char* buffer[0xffff];
     int index, size, attr, category;
     recordid_t id;
 
     if(isDBOpen() == false)
 	{
-	cerr << "PilotSerialDatabase::readRecordByIndex() - Error.DB not open!" << endl;
+	kdError() << __FUNCTION__ << ": DB not open" << endl;
 	return 0L;
 	}
     if(dlp_ReadNextModifiedRec(getPilotLink()->getCurrentPilotSocket(), getDBHandle(), (void*)buffer, 
@@ -143,12 +155,13 @@ PilotRecord* PilotSerialDatabase::readNextModifiedRec()
 // Writes a new record to database (if 'id' == 0, one will be assigned and returned in 'newid')
 int PilotSerialDatabase::writeRecord(PilotRecord* newRecord)
     {
+	FUNCTIONSETUP;
     recordid_t newid;
     int success;
 
     if(isDBOpen() == false)
 	{
-	cerr << "PilotSerialDatabase::readRecordByIndex() - Error.DB not open!" << endl;
+	kdError() << __FUNCTION__ << ": DB not open" << endl;
 	return -1;
 	}
     success = dlp_WriteRecord(getPilotLink()->getCurrentPilotSocket(), getDBHandle(), newRecord->getAttrib(), 
@@ -162,9 +175,10 @@ int PilotSerialDatabase::writeRecord(PilotRecord* newRecord)
 // Resets all records in the database to not dirty.
 int PilotSerialDatabase::resetSyncFlags()
     {
+	FUNCTIONSETUP;
     if(isDBOpen() == false)
 	{
-	cerr << "PilotSerialDatabase::readRecordByIndex() - Error.DB not open!" << endl;
+	kdError() << __FUNCTION__ << ": DB not open" << endl;
 	return -1;
 	}
     return dlp_ResetSyncFlags(getPilotLink()->getCurrentPilotSocket(), getDBHandle()); 
@@ -173,9 +187,10 @@ int PilotSerialDatabase::resetSyncFlags()
 // Resets next record index to beginning
 int PilotSerialDatabase::resetDBIndex()
     {
+	FUNCTIONSETUP;
     if(isDBOpen() == false)
 	{
-	cerr << "PilotSerialDatabase::readRecordByIndex() - Error.DB not open!" << endl;
+	kdError() << __FUNCTION__ << ": DB not open" << endl;
 	return -1;
 	}
     return dlp_ResetDBIndex(getPilotLink()->getCurrentPilotSocket(), getDBHandle()); 
@@ -184,9 +199,10 @@ int PilotSerialDatabase::resetDBIndex()
 // Purges all Archived/Deleted records from Palm Pilot database
 int PilotSerialDatabase::cleanUpDatabase()
     {
+	FUNCTIONSETUP;
     if(isDBOpen() == false)
 	{
-	cerr << "PilotSerialDatabase::readRecordByIndex() - Error.DB not open!" << endl;
+	kdError() << __FUNCTION__ << ": DB not open" << endl;
 	return -1;
 	}
     return dlp_CleanUpDatabase(getPilotLink()->getCurrentPilotSocket(), getDBHandle()); 
@@ -198,13 +214,9 @@ void PilotSerialDatabase::openDatabase()
 
     if(dlp_OpenDB(getPilotLink()->getCurrentPilotSocket(), 0, dlpOpenReadWrite, getDBName(), &db) < 0)
 	{
-#ifdef KDE2
 	KMessageBox::error(getPilotLink()->getOwningWidget(),
 		i18n("Cannot open database"),
 		i18n("Pilot database error"));
-#else
-	KMsgBox::message(getPilotLink()->getOwningWidget(), "Cannot open database!", "ERROR!", KMsgBox::STOP);
-#endif
 	return;
 	}
     setDBHandle(db);
@@ -217,3 +229,9 @@ void PilotSerialDatabase::closeDatabase()
 	return;
     dlp_CloseDB(getPilotLink()->getCurrentPilotSocket(), getDBHandle());
     }
+
+
+// $Log: pilotSerialDatabase.cc,v $
+// Revision 1.8  2001/02/05 20:58:48  adridg
+// Fixed copyright headers for source releases. No code changed
+//
